@@ -279,6 +279,7 @@
 (require 'cc-mode)  ;; yorick-mode derives from c-mode
 (if (fboundp 'c-initialize-cc-mode) (c-initialize-cc-mode))
 (require 'comint)   ;; yoterm-mode derives from comint-mode
+(require 'easymenu)
 
 ;; ------------------------------------------------------------------------
 
@@ -304,36 +305,27 @@ Unnecessary if you use global-font-lock-mode function.")
   (define-key yorick-mode-map "\C-cd" 'yorick-show-help)
   (define-key yorick-mode-map "\C-x\C-e" 'yorick-eval-statement)
   (define-key yorick-mode-map "\e\C-x" 'yorick-eval-func)
-  ;; lose the c-mode menu
-  (define-key yorick-mode-map [menu-bar c] 'undefined)
-  (define-key yorick-mode-map [menu-bar C] 'undefined)
-  (define-key yorick-mode-map [menu-bar yorick]
-    (cons "Yorick" (make-sparse-keymap "Yorick")))
-  (define-key yorick-mode-map [menu-bar yorick toggle-font]
-    '("Toggle Syntax Hilite" . font-lock-mode))
-  (define-key yorick-mode-map [menu-bar yorick show-sep] '("--"))
-  (define-key yorick-mode-map [menu-bar yorick insert-doc]
-    '("Insert doc comment" . yorick-insert-doc))
-  (define-key yorick-mode-map [menu-bar yorick show-help]
-    '("Show doc comment" . yorick-show-help))
-  (define-key yorick-mode-map [menu-bar yorick show-info]
-    '("Show runtime info" . yorick-show-info))
-  (define-key yorick-mode-map [menu-bar yorick goto-sep] '("--"))
-  (define-key yorick-mode-map [menu-bar yorick goto-fend]
-    '("Goto func end" . end-of-defun))
-  (define-key yorick-mode-map [menu-bar yorick goto-ftop]
-    '("Goto func top" . beginning-of-defun))
-  (define-key yorick-mode-map [menu-bar yorick eval-sep] '("--"))
-  (define-key yorick-mode-map [menu-bar yorick eval-region]
-    '("Eval selection" . yorick-eval-region))
-  (define-key yorick-mode-map [menu-bar yorick eval-stmt]
-    '("Eval statement" . yorick-eval-statement))
-  (define-key yorick-mode-map [menu-bar yorick eval-func]
-    '("Eval func" . yorick-eval-func))
-  (define-key yorick-mode-map [menu-bar yorick include]
-    '("Save and Include" . yorick-include-file))
   )
 
+(defvar yorick-mode-menu nil)
+(easy-menu-define
+ yorick-mode-menu yorick-mode-map "Yorick Mode Commands"
+ (cons "Yorick"
+       `(["Toggle Syntax Hilite"  font-lock-mode t]
+	 "---"
+	 ["Insert doc comment"    yorick-insert-doc t]
+	 ["Show doc comment"      yorick-show-help t]
+	 ["Show runtime info"     yorick-show-info t]
+	 "---"
+	 ["Goto func end"         end-of-defun t]
+	 ["Goto func top"         beginning-of-defun t]
+	 "---"
+	 ["Eval selection"        yorick-eval-region t]
+	 ["Eval statement"        yorick-eval-statement t]
+	 ["Eval func"             yorick-eval-func t]
+	 ["Save and Include"      yorick-include-file t]
+	 )))
+
 (defvar yorick-mode-abbrev-table nil
   "Abbreviation table used in yorick-mode buffers.")
 (define-abbrev-table 'yorick-mode-abbrev-table ())
@@ -353,6 +345,14 @@ Unnecessary if you use global-font-lock-mode function.")
       (defvar font-lock-warning-face		'font-lock-reference-face
 	"Face name to use for things that should stand out.")))
 
+(defun xemacs-clean-flkwds (item)
+  (cond ((not item) nil)
+	((listp item) (mapcar xemacs-clean-flkwds item))
+	((eq 'font-lock-builtin-face item) 'font-lock-reference-face)
+	((eq 'font-lock-constant-face item) 'font-lock-reference-face)
+	(t item)))
+(setq xemacs-clean-flkwds (symbol-function 'xemacs-clean-flkwds))
+
 ;; by eric thiebaut (thiebaut@obs.univ-lyon1.fr).
 (defvar yorick-font-lock-keywords
   '(
@@ -389,7 +389,7 @@ Unnecessary if you use global-font-lock-mode function.")
     ;; Anders Lindgren <andersl@csd.uu.se> points out that it is quicker to use
     ;; MATCH-ANCHORED to effectively anchor the regexp on the left.
     ;; This must come after the one for keywords and targets.
-    (":" ("^[ \t]*\\(\\sw+\\)[ \t]*:" (beginning-of-line) (end-of-line)
+    (":" ("^[ \t]*\\(\\sw+\\)[ \t]*:" (forward-line 0) (end-of-line)
 	  (1 font-lock-constant-face)))
     ;;
     ;; Fontify Yorick's types/scope specifiers.
@@ -402,6 +402,10 @@ Unnecessary if you use global-font-lock-mode function.")
     ("\\<\\(avg\\|cum\\|dif\\|m\\(ax\\|in\\|nx\\|xx\\)\\|p\\(cen\\|sum\\|tp\\)\\|rms\\|sum\\|uncp\\|zcen\\)\\>" 1 font-lock-builtin-face)
     ))
 
+(if (string-match "XEmacs" emacs-version)
+    (setq yorick-font-lock-keywords
+	  (mapcar xemacs-clean-flkwds yorick-font-lock-keywords)))
+
 (defvar yorick-font-lock-defaults
   '((yorick-font-lock-keywords)
     nil nil ((?_ . "w")) beginning-of-defun
@@ -437,6 +441,7 @@ Key bindings:
 	mode-name "Yorick"
 	local-abbrev-table yorick-mode-abbrev-table)
   (use-local-map yorick-mode-map)
+  (easy-menu-add yorick-mode-menu)
   (make-local-variable 'font-lock-defaults)
   (setq c-conditional-key yorick-conditional-key
 	c-class-key yorick-class-key
@@ -500,7 +505,7 @@ Key bindings:
   (interactive)
   (end-of-line)
   (let ((pt (point)))
-    (beginning-of-line)
+    (forward-line 0)
     (cond ((and (looking-at "[ \\t]+") (= (match-end 0) pt))
 	   (end-of-line 0)
 	   (delete-region (point) pt)
@@ -587,38 +592,26 @@ Prefix argument means switch to the *yoterm* buffer afterwards."
   ;; note control , . ; ' are all available this way
   (define-key yoterm-mode-map [(control \.)] 'yofile-pop)
   (define-key yoterm-mode-map [(control \,)] 'yoterm-toggle-history)
-
-  ;; Menu bars:
-  (define-key yoterm-mode-map [menu-bar stop]
-    (cons "STOP" 'yoterm-interrupt))
-
-  ;; yorick
-  (define-key yoterm-mode-map [menu-bar yorick]
-    (cons "Yorick" (make-sparse-keymap "Yorick")))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-dbauto]
-    '("Toggle Auto dbug>" . yoterm-dbauto))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-dbexit]
-    '("Exit dbug>" . yoterm-dbexit))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-sep] '("--"))
-  (define-key yoterm-mode-map [menu-bar yorick history]
-    '("Toggle History" . yoterm-toggle-history))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-kill]
-    '("Kill output" . comint-kill-output))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-this]
-    '("Recall this" . yoterm-send-input))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-prev]
-    '("Recall prev" . yoterm-match-backward))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-next]
-    '("Recall next" . yoterm-match-forward))
-  (define-key yoterm-mode-map [menu-bar yorick yofile-pop]
-    '("Goto LINE/FILE" . yofile-pop))
-  (define-key yoterm-mode-map [menu-bar yorick yoterm-cd]
-    '("Change Directory..." . yoterm-cd))
-
-  (setq menu-bar-final-items
-	(append '(yorick stop) menu-bar-final-items))
   )
 
+(defvar yoterm-mode-menu nil)
+(easy-menu-define
+ yoterm-mode-menu yoterm-mode-map "Yorick Terminal Commands"
+ (cons "Yorick"
+       `(["STOP"                 yoterm-interrupt t]
+	 "---"
+	 ["Toggle Auto dbug>"    yoterm-dbauto t]
+	 ["Exit dbug>"           yoterm-dbexit t]
+	 "---"
+	 ["Toggle History"       yoterm-toggle-history t]
+	 ["Kill output"          comint-kill-output t]
+	 ["Recall this"          yoterm-send-input t]
+	 ["Recall prev"          yoterm-match-backward t]
+	 ["Recall next"          yoterm-match-forward t]
+	 ["Goto LINE/FILE"       yofile-pop t]
+	 ["Change Directory..."  yoterm-cd t]
+	 )))
+
 (defvar yohist-mode-map nil
   "Keymap used in yohist-mode buffers.")
 (if yohist-mode-map
@@ -665,6 +658,7 @@ Key bindings:
   (setq major-mode 'yoterm-mode)
   (setq mode-name "Y-Terminal")
   (use-local-map yoterm-mode-map)
+  (easy-menu-add yoterm-mode-menu)
   (set-process-sentinel (get-buffer-process (current-buffer)) 'yoterm-died)
   (setq comint-prompt-regexp yorick-prompt-pattern)
   (setq yoterm-prompt-regexp (substring yorick-prompt-pattern 1))
@@ -752,7 +746,7 @@ Key bindings:
 		     (get-buffer-process (current-buffer)) 2)
 		    (error "Yorick error or response too slow"))
 		(save-excursion
-		  (beginning-of-line)
+		  (forward-line 0)
 		  (setq got-prompt (looking-at comint-prompt-regexp))))))
 	  buf)
       (get-buffer bname))))
@@ -868,7 +862,7 @@ a series of lines to yorick.
 
 See also yoterm-match-forward and yoterm-match-backward."
   (interactive)
-  (beginning-of-line)
+  (forward-line 0)
   (let ((beg (point)))
     (end-of-line)
     (let ((win (get-buffer-window yoterm-termbuf t))
@@ -1014,7 +1008,7 @@ yoterm-send-input."
 (defun yoterm-bol ()
   "Goto beginning of line, except forward over any prompt string."
   (interactive)
-  (beginning-of-line)
+  (forward-line 0)
   (if (looking-at comint-prompt-regexp)
       (goto-char (match-end 0))))
 
@@ -1035,7 +1029,7 @@ yoterm-send-input."
     (setq yoterm-accepted-output t)
     (save-excursion
       (goto-char comint-last-output-start)
-      (beginning-of-line)
+      (forward-line 0)
       (setq beg (point))
       (goto-char pmark)
       (cond ((re-search-backward comint-prompt-regexp beg t)
@@ -1170,7 +1164,16 @@ pathnames; these are searched until a file of the given NAME is found."
 
 ;; ------------------------------------------------------------------------
 
-(defun yutil-query-replace (from-string to-string &optional arg)
+(if (< emacs-major-version 21)
+    (fset 'hacked-perform-replace (symbol-function `perform-replace))
+  (defun hacked-perform-replace (from-string replacements
+				 query-flag regexp-flag delimited-flag
+				 &optional repeat-count map)
+    (perform-replace from-string replacements nil nil
+		     query-flag regexp-flag delimited-flag
+		     repeat-count map)))
+
+(defun yutil-query-replace (from-string to-string &optional arg start end)
   "Like query-replace, but offers choices in menu bar."
   (interactive (query-replace-read-args "Query replace" nil))
   (let ((local-lookup-key (symbol-function 'lookup-key))
@@ -1195,7 +1198,7 @@ pathnames; these are searched until a file of the given NAME is found."
 		(overriding-terminal-local-map map)
 		(overriding-local-map-menu-flag t)
 		inhibit-local-menu-bar-menus)
-	    (perform-replace from-string to-string t nil arg)))
+	    (hacked-perform-replace from-string to-string t nil arg)))
       (fset 'lookup-key local-lookup-key)
       (force-mode-line-update))))
 
@@ -1399,7 +1402,7 @@ If you click outside the slider, the window scrolls one page up or down."
 		      (+ (point-min)
 			 (scroll-bar-scale pair
 					   (- (point-max) (point-min)))))
-		     (beginning-of-line)
+		     (forward-line 0)
 		     (forward-line (- winrow))
 		     (set-window-start window (point)))))))
 	      (t
@@ -1460,6 +1463,22 @@ hilite =      nil   syntax highlighting off by default
                     \(unnecessary if you set global-font-lock-mode\)
 
 Read yorick.el for examples."
+  (if hilite (setq yorick-syntax-hilite t)
+    (setq yorick-syntax-hilite nil))
+  (if (not (string-match "XEmacs" emacs-version))
+      (yutil-setup-1 buttons scrollbars mouse-mini mouse-qr)
+    (delete-selection-mode (if (not (equal buttons 1)) 1 -1))))
+
+;; these do not work in xemacs
+(defun yutil-setup-1 (buttons scrollbars mouse-mini mouse-qr)
+  (remove-hook 'mouse-leave-buffer-hook 'yutil-mouse-exit-minibuffer)
+  (if mouse-mini
+      (add-hook 'mouse-leave-buffer-hook 'yutil-mouse-exit-minibuffer))
+  (if mouse-qr
+      (substitute-key-definition 'query-replace 'yutil-query-replace
+				 global-map)
+      (substitute-key-definition 'yutil-query-replace 'query-replace
+				 global-map))
   (if (not (boundp 'mouse-sel-default-bindings))
       (setq mouse-sel-default-bindings 'interprogram-cut-paste))
   (require 'mouse-sel)
@@ -1542,17 +1561,7 @@ Read yorick.el for examples."
 		(global-set-key [vertical-scroll-bar down-mouse-3]
 				'yutil-shade-scroll-bar)
 		(global-unset-key [vertical-scroll-bar mouse-1])
-		(global-unset-key [vertical-scroll-bar drag-mouse-1])))))
-  (remove-hook 'mouse-leave-buffer-hook 'yutil-mouse-exit-minibuffer)
-  (if mouse-mini
-      (add-hook 'mouse-leave-buffer-hook 'yutil-mouse-exit-minibuffer))
-  (if mouse-qr
-      (substitute-key-definition 'query-replace 'yutil-query-replace
-				 global-map)
-      (substitute-key-definition 'yutil-query-replace 'query-replace
-				 global-map))
-  (if hilite (setq yorick-syntax-hilite t)
-    (setq yorick-syntax-hilite nil)))
+		(global-unset-key [vertical-scroll-bar drag-mouse-1]))))))
 
 ;; ------------------------------------------------------------------------
 ;; ysh and yssh are similar to ordinary shell-mode,
