@@ -215,7 +215,7 @@ static struct CGMAttributes cgmDefaults= {
       TX_RIGHT, TH_NORMAL, TV_NORMAL },           /* text attributes */
 
   {0, 0, 0, 0.0, 1.0, 1.0, 0.0, 1.0, 0.0, 2, 0}   /* non-Gist attributes,
-						     except pattern table */
+                                                     except pattern table */
   };
 
 /* pageDefaults represent cgmDefaults, as modified by the defaults
@@ -228,7 +228,7 @@ static struct CGMAttributes pageDefaults= {
       TX_RIGHT, TH_NORMAL, TV_NORMAL },           /* text attributes */
 
   {0, 0, 0, 0.0, 1.0, 1.0, 0.0, 1.0, 0.0, 2, 0}   /* non-Gist attributes,
-						     except pattern table */
+                                                     except pattern table */
   };
 
 /* current values of non-Gist attributes
@@ -264,9 +264,9 @@ static void NextName(char *filename)
 {
   int i, len= filename? strlen(filename) : 0;
   if (len>4 && (strcmp(filename+len-4, ".cgm")==0 ||
-		strcmp(filename+len-4, ".CGM")==0)) i= len-4;
+                strcmp(filename+len-4, ".CGM")==0)) i= len-4;
   else if (len>5 && (strcmp(filename+len-5, ".ncgm")==0 ||
-		     strcmp(filename+len-5, ".NCGM")==0)) i= len-5;
+                     strcmp(filename+len-5, ".NCGM")==0)) i= len-5;
   else i= len;
   while (i-- > 0) {
     if (filename[i]=='9') {
@@ -342,27 +342,27 @@ static int BeginCatalog(CGM *cgm)
     if (klass==0 && id==1) {
       bad= 0;
       for (;;) {
-	SkipParameters(nOctets);
-	nOctets= ReadElement(&klass, &id);
-	if (nOctets>=0) {
-	  if (klass==0) {
-	    if (id==3 || id==2) break;  /* begin picture or end metafile */
-	    else if (id!=0) {
-	      if (cgm->ncar)
-		Warning("bad class 0 element in metafile descriptor", "");
-	      bad= 1;
-	      break;
-	    }
-	  } else if (klass!=1 && klass!=6 && klass!=7) {
-	    if (cgm->ncar)
-	      Warning("bad element class in metafile descriptor", "");
-	    bad= 1;
-	    break;
-	  }
-	} else {
-	  bad= 1;
-	  break;
-	}
+        SkipParameters(nOctets);
+        nOctets= ReadElement(&klass, &id);
+        if (nOctets>=0) {
+          if (klass==0) {
+            if (id==3 || id==2) break;  /* begin picture or end metafile */
+            else if (id!=0) {
+              if (cgm->ncar)
+                Warning("bad class 0 element in metafile descriptor", "");
+              bad= 1;
+              break;
+            }
+          } else if (klass!=1 && klass!=6 && klass!=7) {
+            if (cgm->ncar)
+              Warning("bad element class in metafile descriptor", "");
+            bad= 1;
+            break;
+          }
+        } else {
+          bad= 1;
+          break;
+        }
       }
     } else {
       if (cgm->ncar) Warning("BEGIN METAFILE element missing", "");
@@ -373,9 +373,9 @@ static int BeginCatalog(CGM *cgm)
       int ncar = cgm->ncar;
       cgm->ncar = 1;
       if (ncar || n_fseek(cgm, 0L, 0)) {
-	currentCGM= oldCGM;
-	Warning(cgm->name, " is not a binary CGM, cannot open");
-	return 1;
+        currentCGM= oldCGM;
+        Warning(cgm->name, " is not a binary CGM, cannot open");
+        return 1;
       }
     }
   } while (bad);
@@ -411,9 +411,9 @@ int CatalogCGM(void)
     catalogCGM= NewCGM(catalogCGM->name, (void *)0, 256);
     if (!catalogCGM || BeginCatalog(catalogCGM)) {
       if (catalogCGM) {
-	p_fclose(catalogCGM->file);
-	DeleteCGM(catalogCGM);
-	catalogCGM= 0;
+        p_fclose(catalogCGM->file);
+        DeleteCGM(catalogCGM);
+        catalogCGM= 0;
       }
       return 0;
     }
@@ -427,38 +427,38 @@ int CatalogCGM(void)
     for (;;) {
       nOctets= ReadElement(&klass, &id);
       if (nOctets>=0) {
-	if (klass==0) {
-	  if (id==3 || id==2) break;  /* begin picture or end metafile */
-	}
-	SkipParameters(nOctets);
+        if (klass==0) {
+          if (id==3 || id==2) break;  /* begin picture or end metafile */
+        }
+        SkipParameters(nOctets);
       } else {
-	Warning("missing END METAFILE element in ", catalogCGM->name);
-	klass= 0;
-	id= 2;
-	break;
+        Warning("missing END METAFILE element in ", catalogCGM->name);
+        klass= 0;
+        id= 2;
+        break;
       }
     }
     currentCGM= cgm;
 
     if (id==3) {
       if (catalogCGM->maxPages==catalogCGM->nPages) {
-	long *pa= (long *)p_malloc(sizeof(long)*(catalogCGM->maxPages+256));
-	int i;
-	if (!pa) {
-	  catalogCGM->catalogEnd= -1;
-	  if (catalogCGM!=currentCGM) p_fclose(catalogCGM->file);
-	  catalogCGM= 0;
-	  Warning("memory manager failed cataloging ", catalogCGM->name);
-	  break;
-	}
-	for (i=0 ; i<catalogCGM->nPages ; i++)
-	  pa[i]= catalogCGM->pageAddress[i];
-	p_free(catalogCGM->pageAddress);
-	catalogCGM->pageAddress= pa;
-	catalogCGM->maxPages+= 256;
+        long *pa= (long *)p_malloc(sizeof(long)*(catalogCGM->maxPages+256));
+        int i;
+        if (!pa) {
+          catalogCGM->catalogEnd= -1;
+          if (catalogCGM!=currentCGM) p_fclose(catalogCGM->file);
+          catalogCGM= 0;
+          Warning("memory manager failed cataloging ", catalogCGM->name);
+          break;
+        }
+        for (i=0 ; i<catalogCGM->nPages ; i++)
+          pa[i]= catalogCGM->pageAddress[i];
+        p_free(catalogCGM->pageAddress);
+        catalogCGM->pageAddress= pa;
+        catalogCGM->maxPages+= 256;
       }
       catalogCGM->pageAddress[catalogCGM->nPages++]=
-	n_ftell(catalogCGM)-cgmCmdLen;
+        n_ftell(catalogCGM)-cgmCmdLen;
       currentCGM= catalogCGM;
       SkipParameters(nOctets);
       currentCGM= cgm;
@@ -469,19 +469,19 @@ int CatalogCGM(void)
       tmp= catalogCGM;
       tmp->catalogEnd= -1;
       if (tmp!=currentCGM) {
-	p_fclose(tmp->file);
-	tmp->file= 0;
+        p_fclose(tmp->file);
+        tmp->file= 0;
       }
       tmp= tmp->next= NewCGM(catalogCGM->name, (void *)0, 256);
       if (tmp) {
-	if (BeginCatalog(tmp)) {
-	  p_fclose(tmp->file);
-	  DeleteCGM(tmp);
-	  tmp= 0;
-	} else {
-	  tmp->prev= catalogCGM;
-	  tmp->firstPage= catalogCGM->firstPage+catalogCGM->nPages;
-	}
+        if (BeginCatalog(tmp)) {
+          p_fclose(tmp->file);
+          DeleteCGM(tmp);
+          tmp= 0;
+        } else {
+          tmp->prev= catalogCGM;
+          tmp->firstPage= catalogCGM->firstPage+catalogCGM->nPages;
+        }
       }
       catalogCGM= tmp;
       if (!tmp) return 0;
@@ -577,12 +577,12 @@ int ReadCGM(int *mPage, int *nPage, int *sPage, int nPageGroups)
     if (s>0) {
       while (currentCGM->next) currentCGM= currentCGM->next;
       while (currentCGM->nPages==0 && currentCGM->prev)
-	currentCGM= currentCGM->prev;
+        currentCGM= currentCGM->prev;
       offset= currentCGM->nPages-1;
     } else {
       while (currentCGM->prev) currentCGM= currentCGM->prev;
       while (currentCGM->nPages==0 && currentCGM->next)
-	currentCGM= currentCGM->next;
+        currentCGM= currentCGM->next;
       offset= 0;
     }
     if (currentCGM->nPages>0) {
@@ -607,8 +607,8 @@ void CGMinfo(void)
     char msg[80];
     while (last->next) last= last->next;
     sprintf(msg, "At page %d out of %s%d in CGM file ",
-	    currentPage, catalogCGM? ">=":"",
-	    last->firstPage+last->nPages-1);
+            currentPage, catalogCGM? ">=":"",
+            last->firstPage+last->nPages-1);
     p_stdout(msg);
     p_stdout(firstCGM->name);  /* name might be very long */
     p_stdout("\n");
@@ -799,13 +799,13 @@ static int EchoPage(int number, int inc)
   if (number>=cgm->firstPage+cgm->nPages) {
     if (cgm->catalogEnd>0) {
       if (!amBatch) {
-	p_stdout("gist: STANDBY -- still cataloging ");
-	p_stdout(cgm->name);
-	p_stdout("\n");
+        p_stdout("gist: STANDBY -- still cataloging ");
+        p_stdout(cgm->name);
+        p_stdout("\n");
       }
       while (CatalogCGM()) {
-	if (cgm->catalogEnd<0) cgm= cgm->next; /* cgm->next must be non-0! */
-	if (number<cgm->firstPage+cgm->nPages) break;
+        if (cgm->catalogEnd<0) cgm= cgm->next; /* cgm->next must be non-0! */
+        if (number<cgm->firstPage+cgm->nPages) break;
       }
     }
     if (number>=cgm->firstPage+cgm->nPages) {
@@ -829,8 +829,8 @@ static int EchoPage(int number, int inc)
     if (cgm!=catalogCGM) {
       cgm->file= p_fopen(cgm->name, "rb");
       if (!cgm->file) {
-	Warning("no longer able to open CGM ", cgm->name);
-	return 1;
+        Warning("no longer able to open CGM ", cgm->name);
+        return 1;
       }
     }
     if (currentCGM!=catalogCGM) {
@@ -856,8 +856,8 @@ static int EchoPage(int number, int inc)
       if (id==5) { DoClass0(id, nOctets); break; }
       if (id==0 || id==3 || id==4) DoClass0(id, nOctets);
       else {
-	Warning("misplaced delimiter element in CGM ", cgm->name);
-	break;
+        Warning("misplaced delimiter element in CGM ", cgm->name);
+        break;
       }
     } else if (klass==1) {
       Warning("ignoring misplaced class 1 element in CGM ", cgm->name);
@@ -944,36 +944,36 @@ static long ReadParameters(long nOctets, GpColor *colors, long maxColors)
 
     if (!colors) {
       if (nTot+n > maxParams) {
-	oldParams= paramList;
-	newSize= (1+(nTot+n-1)/blockSize)*blockSize;
-	paramList= (Octet *)p_malloc((sizeof(short)/2)*newSize);
-	if (!paramList) {
-	  Warning("memory manager failed in CGM read", "");
-	  return -2L;
-	}
-	maxParams= newSize;
-	for (i=0 ; i<nTot ; i++) paramList[i]= oldParams[i];
-	if (oldParams) p_free(oldParams);
+        oldParams= paramList;
+        newSize= (1+(nTot+n-1)/blockSize)*blockSize;
+        paramList= (Octet *)p_malloc((sizeof(short)/2)*newSize);
+        if (!paramList) {
+          Warning("memory manager failed in CGM read", "");
+          return -2L;
+        }
+        maxParams= newSize;
+        for (i=0 ; i<nTot ; i++) paramList[i]= oldParams[i];
+        if (oldParams) p_free(oldParams);
       }
       newParams= paramList;
     } else {
       if (nTot+n > maxColors) {
-	SkipParameters(nOctets);
-	return nTot;
+        SkipParameters(nOctets);
+        return nTot;
       }
     }
 
     if (nOctets>0) {
       if (cmdString) {
-	if (n>cmdLength) { n= cmdLength;  more= 0; }
-	memcpy(paramList+nTot, currentCmd, n);
-	currentCmd+= n;
-	cmdLength-= n;
+        if (n>cmdLength) { n= cmdLength;  more= 0; }
+        memcpy(paramList+nTot, currentCmd, n);
+        currentCmd+= n;
+        cmdLength-= n;
       } else {
-	if (n_fread(newParams+nTot, n, currentCGM)!=n) {
-	  Warning("fread failed on CGM file ", currentCGM->name);
-	  return -1L;
-	}
+        if (n_fread(newParams+nTot, n, currentCGM)!=n) {
+          Warning("fread failed on CGM file ", currentCGM->name);
+          return -1L;
+        }
       }
       nTot+= nOctets;  /* yes, may be 1 less than n */
     }
@@ -987,8 +987,8 @@ static long ReadParameters(long nOctets, GpColor *colors, long maxColors)
       cmdLength-= 2;
     } else {
       if (n_fread(cmd, 2L, currentCGM)!=2L) {
-	Warning("fread failed on CGM file ", currentCGM->name);
-	return -1L;
+        Warning("fread failed on CGM file ", currentCGM->name);
+        return -1L;
       }
     }
     nOctets= cmd[0]<<8 | cmd[1];
@@ -1009,14 +1009,14 @@ static int SkipParameters(long nOctets)
 
     if (nOctets>0) {
       if (cmdString) {
-	if (nOctets>cmdLength) { nOctets= cmdLength;  more= 0; }
-	currentCmd+= nOctets;
-	cmdLength-= nOctets;
+        if (nOctets>cmdLength) { nOctets= cmdLength;  more= 0; }
+        currentCmd+= nOctets;
+        cmdLength-= nOctets;
       } else {
-	if (n_fseek(currentCGM, nOctets, 1)) {
-	  Warning("fseek failed on CGM file ", currentCGM->name);
-	  return 1;
-	}
+        if (n_fseek(currentCGM, nOctets, 1)) {
+          Warning("fseek failed on CGM file ", currentCGM->name);
+          return 1;
+        }
       }
     }
 
@@ -1029,8 +1029,8 @@ static int SkipParameters(long nOctets)
       cmdLength-= 2;
     } else {
       if (n_fread(cmd, 2L, currentCGM)!=2L) {
-	Warning("fread failed (partition) on CGM file ", currentCGM->name);
-	return 1;
+        Warning("fread failed (partition) on CGM file ", currentCGM->name);
+        return 1;
       }
     }
     nOctets= cmd[0]<<8 | cmd[1];
@@ -1070,8 +1070,8 @@ static long ReadElement(int *klass, int *id)
       cmdLength-= 2;
     } else {
       if (n_fread(cmd, 2L, currentCGM)!=2L) {
-	Warning("fread failed (command) on CGM file ", currentCGM->name);
-	return -1L;
+        Warning("fread failed (command) on CGM file ", currentCGM->name);
+        return -1L;
       }
     }
     n= cmd[0]<<8 | cmd[1];
@@ -1189,16 +1189,16 @@ static char *PathifyText(char *text, int path)
     if (path!=3) {
       char tmp;
       for (i=0 ; i<len-1-i ; i++) {
-	tmp= cgmText[i];
-	cgmText[i]= cgmText[len-1-i];
-	cgmText[len-1-i]= tmp;
+        tmp= cgmText[i];
+        cgmText[i]= cgmText[len-1-i];
+        cgmText[len-1-i]= tmp;
       }
     }
     if (path!=1) {
       cgmText[2*len-1]= '\0';
       for (i=len-1 ; i>0 ; i--) {
-	cgmText[2*i]= cgmText[i];
-	cgmText[2*i-1]= '\n';
+        cgmText[2*i]= cgmText[i];
+        cgmText[2*i-1]= '\n';
       }
     }
   }
@@ -1365,17 +1365,17 @@ static void ResetPalette(int forPage)
        set palette on any new engines */
     for (i=0 ; i<8 ; i++) {
       if (outEngines[i]) {
-	refreshPalette= (cgmNColors>offset &&
-			 (alteredPalette ||
-			  outEngines[i]->palette!=cgmPalette+offset ||
-			  outEngines[i]->nColors!=cgmNColors-offset));
-	if (outTypes[i]==2) {
-	  setXPalette= refreshPalette;
-	} else {
-	  outEngines[i]->colorMode= 0;
-	  if (refreshPalette) GpSetPalette(outEngines[i], cgmPalette+offset,
-					   cgmNColors-offset);
-	}
+        refreshPalette= (cgmNColors>offset &&
+                         (alteredPalette ||
+                          outEngines[i]->palette!=cgmPalette+offset ||
+                          outEngines[i]->nColors!=cgmNColors-offset));
+        if (outTypes[i]==2) {
+          setXPalette= refreshPalette;
+        } else {
+          outEngines[i]->colorMode= 0;
+          if (refreshPalette) GpSetPalette(outEngines[i], cgmPalette+offset,
+                                           cgmNColors-offset);
+        }
       }
     }
     alteredPalette= 0;
@@ -1532,9 +1532,9 @@ static int DoClass1(int id, long nOctets)
   case 5:   /* REAL PRECISION */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if (nOctets!=3*nBytesInt || SnarfInteger(paramList)!=1 ||
-	SnarfInteger(paramList+nBytesInt)!=16 ||
-	SnarfInteger(paramList+2*nBytesInt)!=16) {
-      Warning("CGM partly illegible, not 32 bit fixed point reals", "");
+        SnarfInteger(paramList+nBytesInt)!=16 ||
+        SnarfInteger(paramList+2*nBytesInt)!=16) {
+      Warning("CGM may be partly illegible, not 32 bit fixed point reals", "");
       realIllegible= 1;
       return 1;
     }
@@ -1543,7 +1543,7 @@ static int DoClass1(int id, long nOctets)
   case 6:   /* INDEX PRECISION */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if (nOctets!=nBytesInt || SnarfInteger(paramList)!=16) {
-      Warning("CGM partly illegible, not 16 bit index precision", "");
+      Warning("CGM may be partly illegible, not 16 bit index precision", "");
       indexIllegible= 1;
       return 1;
     }
@@ -1552,8 +1552,9 @@ static int DoClass1(int id, long nOctets)
   case 7:   /* COLOR PRECISION */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if (nOctets!=nBytesInt ||
-	((cvalIllegible= SnarfInteger(paramList))!=8 && cvalIllegible!=16)) {
-      Warning("CGM partly illegible, not 8 or 16 bit color precision", "");
+        ((cvalIllegible= SnarfInteger(paramList))!=8 && cvalIllegible!=16)) {
+      Warning("CGM may be partly illegible, not 8 or 16 bit color precision",
+              "");
       cvalIllegible= 1;
       return 1;
     } else {
@@ -1567,10 +1568,11 @@ static int DoClass1(int id, long nOctets)
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     { int cip= 8;
       if (nOctets!=nBytesInt ||
-	  (cip= SnarfInteger(paramList))!=8) {
-	Warning("CGM partly illegible, not 8 bit color index precision", "");
-	cndxIllegible= cselIllegible= (cip==16? 16 : 1);
-	return 1;
+          (cip= SnarfInteger(paramList))!=8) {
+        Warning("CGM may be partly illegible, not 8 bit color index precision",
+                "");
+        cndxIllegible= cselIllegible= (cip==16? 16 : 1);
+        return 1;
       }
     }
     break;
@@ -1610,53 +1612,53 @@ static int DoClass1(int id, long nOctets)
     {
       nOctets= ReadParameters(nOctets, (void *)0, 0L);
       if (nOctets>0) {
-	int klass, id;
-	cmdString= (Octet *)p_malloc(sizeof(Octet)*nOctets);
-	if (!cmdString) {
-	  Warning("memory manager failed in DoClass1(DEFAULTS)", "");
-	  return 1;
-	}
-	memcpy(cmdString, paramList, nOctets);
-	currentCmd= cmdString;
-	cmdLength= nOctets;
-	while (cmdLength>0) {
-	  nOctets= ReadElement(&klass, &id);
-	  if (nOctets>=0) {
-	    switch (klass) {
-	    case 2:
-	      pictDesc= pageDesc;
-	      DoClass2(id, nOctets);
-	      pageDesc= pictDesc;
-	      break;
-	    case 3:
-	      pictControls= pageControls;
-	      DoClass3(id, nOctets);
-	      pageControls= pictControls;
-	      break;
-	    case 5:
-	      gistA.l= pageDefaults.l;
-	      gistA.m= pageDefaults.m;
-	      gistA.f= pageDefaults.f;
-	      gistA.t= pageDefaults.t;
-	      nonGistA= pageDefaults.ng;
-	      DoClass5(id, nOctets);
-	      pageDefaults.l= gistA.l;
-	      pageDefaults.m= gistA.m;
-	      pageDefaults.f= gistA.f;
-	      pageDefaults.t= gistA.t;
-	      pageDefaults.ng= nonGistA;
-	      break;
-	    case 6:
-	      DoClass6(id, nOctets);
-	      break;
-	    default:
-	      /* Other commands are illegal, but whining is pointless */
-	      break;
-	    }
-	  }
-	}
-	p_free(cmdString);
-	cmdString= 0;
+        int klass, id;
+        cmdString= (Octet *)p_malloc(sizeof(Octet)*nOctets);
+        if (!cmdString) {
+          Warning("memory manager failed in DoClass1(DEFAULTS)", "");
+          return 1;
+        }
+        memcpy(cmdString, paramList, nOctets);
+        currentCmd= cmdString;
+        cmdLength= nOctets;
+        while (cmdLength>0) {
+          nOctets= ReadElement(&klass, &id);
+          if (nOctets>=0) {
+            switch (klass) {
+            case 2:
+              pictDesc= pageDesc;
+              DoClass2(id, nOctets);
+              pageDesc= pictDesc;
+              break;
+            case 3:
+              pictControls= pageControls;
+              DoClass3(id, nOctets);
+              pageControls= pictControls;
+              break;
+            case 5:
+              gistA.l= pageDefaults.l;
+              gistA.m= pageDefaults.m;
+              gistA.f= pageDefaults.f;
+              gistA.t= pageDefaults.t;
+              nonGistA= pageDefaults.ng;
+              DoClass5(id, nOctets);
+              pageDefaults.l= gistA.l;
+              pageDefaults.m= gistA.m;
+              pageDefaults.f= gistA.f;
+              pageDefaults.t= gistA.t;
+              pageDefaults.ng= nonGistA;
+              break;
+            case 6:
+              DoClass6(id, nOctets);
+              break;
+            default:
+              /* Other commands are illegal, but whining is pointless */
+              break;
+            }
+          }
+        }
+        p_free(cmdString);
+        cmdString= 0;
       }
     }
     break;
@@ -1669,25 +1671,25 @@ static int DoClass1(int id, long nOctets)
       nOctets= ReadParameters(nOctets, (void *)0, 0L);
       pageDesc.nfonts= 0;
       do {
-	nPart= DePascalify(fontName, pasctxt, nOctets);
-	pasctxt+= nPart;
-	nOctets-= nPart;
-	for (i=0 ; i<N_GIST_FONTS ; i++)
-	  if (strcmp(fontName, gistFonts[i])==0) break;
-	if (i>=N_GIST_FONTS) i= 0;
-	if (pageDesc.nfonts>=pageDesc.maxFonts) {
-	  oldFonts= pageDesc.fonts;
-	  pageDesc.fonts= (int *)p_malloc(sizeof(int)*(pageDesc.nfonts+20));
-	  if (!pageDesc.fonts) {
-	    pageDesc.fonts= oldFonts;
-	    Warning("memory manager failed in DoClass1(FONT LIST)", "");
-	    return 2;
-	  }
-	  pageDesc.maxFonts= pageDesc.nfonts+20;
-	  for (i=0 ; i<pageDesc.nfonts ; i++) pageDesc.fonts[i]= oldFonts[i];
-	  if (oldFonts && oldFonts!=defaultNumbers) p_free(oldFonts);
-	}
-	pageDesc.fonts[pageDesc.nfonts++]= i;
+        nPart= DePascalify(fontName, pasctxt, nOctets);
+        pasctxt+= nPart;
+        nOctets-= nPart;
+        for (i=0 ; i<N_GIST_FONTS ; i++)
+          if (strcmp(fontName, gistFonts[i])==0) break;
+        if (i>=N_GIST_FONTS) i= 0;
+        if (pageDesc.nfonts>=pageDesc.maxFonts) {
+          oldFonts= pageDesc.fonts;
+          pageDesc.fonts= (int *)p_malloc(sizeof(int)*(pageDesc.nfonts+20));
+          if (!pageDesc.fonts) {
+            pageDesc.fonts= oldFonts;
+            Warning("memory manager failed in DoClass1(FONT LIST)", "");
+            return 2;
+          }
+          pageDesc.maxFonts= pageDesc.nfonts+20;
+          for (i=0 ; i<pageDesc.nfonts ; i++) pageDesc.fonts[i]= oldFonts[i];
+          if (oldFonts && oldFonts!=defaultNumbers) p_free(oldFonts);
+        }
+        pageDesc.fonts[pageDesc.nfonts++]= i;
       } while (nOctets>0);
     }
     break;
@@ -1728,7 +1730,7 @@ static int DoClass2(int id, long nOctets)
   case 2:   /* COLOR SELECTION MODE */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if (nOctets!=2 || paramList[1]) {
-      Warning("CGM partly illegible, not indexed color mode", "");
+      Warning("CGM may be partly illegible, not indexed color mode", "");
       cselIllegible= 1;
       return 1;
     } else cselIllegible= cndxIllegible;
@@ -1762,10 +1764,10 @@ static int DoClass2(int id, long nOctets)
       pictDesc.vdc[3]= vdc[3];
       SetVDC(pictDesc.vdc);
       if (pictControls.clipDefault) {
-	pictControls.clipBox[0]= vdc[0];
-	pictControls.clipBox[1]= vdc[1];
-	pictControls.clipBox[2]= vdc[2];
-	pictControls.clipBox[3]= vdc[3];
+        pictControls.clipBox[0]= vdc[0];
+        pictControls.clipBox[1]= vdc[1];
+        pictControls.clipBox[2]= vdc[2];
+        pictControls.clipBox[3]= vdc[3];
       }
     }
     break;
@@ -1775,37 +1777,37 @@ static int DoClass2(int id, long nOctets)
     {
       int red, green, blue;
       if (!cvalIllegible && nOctets==3) {
-	/* This is actually ignored... */
-	red= paramList[0];
-	green= paramList[1];
-	blue= paramList[2];
-	/* GpPutNTSC(1, &pictDesc.background); */
+        /* This is actually ignored... */
+        red= paramList[0];
+        green= paramList[1];
+        blue= paramList[2];
+        /* GpPutNTSC(1, &pictDesc.background); */
       } else if (cvalIllegible==16 && nOctets==6) {
-	/* This is actually ignored... */
-	red= Snarf16(paramList)>>8;
-	green= Snarf16(paramList+2)>>8;
-	blue= Snarf16(paramList+4)>>8;
-	/* GpPutNTSC(1, &pictDesc.background); */
+        /* This is actually ignored... */
+        red= Snarf16(paramList)>>8;
+        green= Snarf16(paramList+2)>>8;
+        blue= Snarf16(paramList+4)>>8;
+        /* GpPutNTSC(1, &pictDesc.background); */
       } else {
-	nOctets= 0;
-	red= green= blue= 0;
+        nOctets= 0;
+        red= green= blue= 0;
       }
       if (nOctets) {
-	if (pictDesc.background.red!=red ||
-	    pictDesc.background.green!=green ||
-	    pictDesc.background.blue!=blue) {
-	  char msg[80];
-	  /* One warning each time the bozo tries to change it... */
-	  sprintf(msg,
-		  "WARNING- BACKGROUND COLOR %02x%02x%02x not supported.\n",
-		  pictDesc.background.red, pictDesc.background.green,
-		  pictDesc.background.blue);
-	  p_stdout(msg);
-	  p_stdout("   You may want to set \"Gist*background:\" X resource.\n");
-	}
-	pictDesc.background.red= red;
-	pictDesc.background.green= green;
-	pictDesc.background.blue= blue;
+        if (pictDesc.background.red!=red ||
+            pictDesc.background.green!=green ||
+            pictDesc.background.blue!=blue) {
+          char msg[80];
+          /* One warning each time the bozo tries to change it... */
+          sprintf(msg,
+                  "WARNING- BACKGROUND COLOR %02x%02x%02x not supported.\n",
+                  pictDesc.background.red, pictDesc.background.green,
+                  pictDesc.background.blue);
+          p_stdout(msg);
+          p_stdout("   You may want to set \"Gist*background:\" X resource.\n");
+        }
+        pictDesc.background.red= red;
+        pictDesc.background.green= green;
+        pictDesc.background.blue= blue;
       }
     }
     break;
@@ -1867,9 +1869,9 @@ static int DoClass3(int id, long nOctets)
     if (nOctets==2) {
       int clipOn= Snarf16(paramList);
       if (clipOn!=pictControls.clipOn) {
-	pictControls.clipOn= clipOn;
-	if (clipOn) GSetClip(1);
-	else GSetClip(0);
+        pictControls.clipOn= clipOn;
+        if (clipOn) GSetClip(1);
+        else GSetClip(0);
       }
     }
     break;
@@ -1893,8 +1895,8 @@ static int DoClass4(int id, long nOctets)
     int i, offset= isGistCGM? 10 : (bg0fg1? 2 : 0);
     for (i=0 ; i<8 ; i++) {
       if (outEngines[i] && outTypes[i]!=2) {
-	outEngines[i]->colorMode= 1;
-	GpSetPalette(outEngines[i], cgmPalette+offset, cgmNColors-offset);
+        outEngines[i]->colorMode= 1;
+        GpSetPalette(outEngines[i], cgmPalette+offset, cgmNColors-offset);
       }
     }
     alteredPalette= 1;
@@ -1907,8 +1909,8 @@ static int DoClass4(int id, long nOctets)
     int i, offset= isGistCGM? 10 : (bg0fg1? 2 : 0);
     for (i=0 ; i<8 ; i++) {
       if (outEngines[i] && outTypes[i]==2) {
-	outEngines[i]->colorMode= alteredPalette;
-	GpSetPalette(outEngines[i], cgmPalette+offset, cgmNColors-offset);
+        outEngines[i]->colorMode= alteredPalette;
+        GpSetPalette(outEngines[i], cgmPalette+offset, cgmNColors-offset);
       }
     }
     setXPalette= 0;
@@ -1923,24 +1925,24 @@ static int DoClass4(int id, long nOctets)
       int (*Lines)(long, const GpReal *, const GpReal *);
 
       if (cgmSmoothing) {
-	long i;
-	gistA.dl.closed= 0;
-	gistA.dl.smooth= cgmSmoothing;
-	gistA.dl.marks= gistA.dl.rays= 0;
-	cgmSmoothing= 0;
-	nPoints= nPoints/3;
-	for (i=0 ; i<nPoints ; i++) {
-	  vdc[2*i]= vdc[6*i];
-	  vdc[2*i+1]= vdc[6*i+1];
-	}
-	Lines= &GaLines;
+        long i;
+        gistA.dl.closed= 0;
+        gistA.dl.smooth= cgmSmoothing;
+        gistA.dl.marks= gistA.dl.rays= 0;
+        cgmSmoothing= 0;
+        nPoints= nPoints/3;
+        for (i=0 ; i<nPoints ; i++) {
+          vdc[2*i]= vdc[6*i];
+          vdc[2*i+1]= vdc[6*i+1];
+        }
+        Lines= &GaLines;
       } else {
-	Lines= &GpLines;
+        Lines= &GpLines;
       }
 
       if (!CheckScratch(nPoints)) {
-	ConvertPoints(nPoints, vdc, ndcX, ndcY);
-	Lines(nPoints, ndcX, ndcY);
+        ConvertPoints(nPoints, vdc, ndcX, ndcY);
+        Lines(nPoints, ndcX, ndcY);
       }
     }
     break;
@@ -1952,14 +1954,14 @@ static int DoClass4(int id, long nOctets)
       short *vdc= CGM_WORDS(paramList, nPoints<<1);
 
       if (!CheckScratch(nPoints)) {
-	long i, nSegs= nPoints>>1;
-	for (i=0 ; i<nSegs ; i++) {
-	  ndcX[i]= cgmScaleX*(GpReal)vdc[4*i]+cgmOffsetX;
-	  ndcY[i]= cgmScaleY*(GpReal)vdc[4*i+1]+cgmOffsetY;
-	  ndcX[i+nSegs]= cgmScaleX*(GpReal)vdc[4*i+2]+cgmOffsetX;
-	  ndcY[i+nSegs]= cgmScaleY*(GpReal)vdc[4*i+3]+cgmOffsetY;
-	}
-	GpDisjoint(nSegs, ndcX, ndcY, ndcX+nSegs, ndcY+nSegs);
+        long i, nSegs= nPoints>>1;
+        for (i=0 ; i<nSegs ; i++) {
+          ndcX[i]= cgmScaleX*(GpReal)vdc[4*i]+cgmOffsetX;
+          ndcY[i]= cgmScaleY*(GpReal)vdc[4*i+1]+cgmOffsetY;
+          ndcX[i+nSegs]= cgmScaleX*(GpReal)vdc[4*i+2]+cgmOffsetX;
+          ndcY[i+nSegs]= cgmScaleY*(GpReal)vdc[4*i+3]+cgmOffsetY;
+        }
+        GpDisjoint(nSegs, ndcX, ndcY, ndcX+nSegs, ndcY+nSegs);
       }
     }
     break;
@@ -1970,8 +1972,8 @@ static int DoClass4(int id, long nOctets)
       long nPoints= nOctets>>2;
       short *vdc= CGM_WORDS(paramList, nPoints<<1);
       if (!CheckScratch(nPoints)) {
-	ConvertPoints(nPoints, vdc, ndcX, ndcY);
-	GpMarkers(nPoints, ndcX, ndcY);
+        ConvertPoints(nPoints, vdc, ndcX, ndcY);
+        GpMarkers(nPoints, ndcX, ndcY);
       }
     }
     break;
@@ -1988,8 +1990,8 @@ static int DoClass4(int id, long nOctets)
       final= Snarf16(paramList+4);
       text= SnarfText(paramList+6);
       if (final) {
-	GpText(x0, y0, PathifyText(text,nonGistA.path));
-	cgmTextLen= 0;
+        GpText(x0, y0, PathifyText(text,nonGistA.path));
+        cgmTextLen= 0;
       }
       else RememberPoint(x0, y0);
     }
@@ -2008,8 +2010,8 @@ static int DoClass4(int id, long nOctets)
       final= Snarf16(paramList+8);
       text= SnarfText(paramList+10);
       if (final) {
-	GpText(x0, y0, PathifyText(text,nonGistA.path));
-	cgmTextLen= 0;
+        GpText(x0, y0, PathifyText(text,nonGistA.path));
+        cgmTextLen= 0;
       }
       else RememberPoint(x0, y0);
     }
@@ -2032,19 +2034,19 @@ static int DoClass4(int id, long nOctets)
       long nPoints= nOctets>>2;
       short *vdc= CGM_WORDS(paramList, nPoints<<1);
       if (!CheckScratch(nPoints)) {
-	int type= gistA.e.type;
-	if (!nonGistA.eVisible) gistA.e.type= L_NONE;
-	ConvertPoints(nPoints, vdc, ndcX, ndcY);
-	if (gistA.f.style!=F_EMPTY) {
-	  GpFill(nPoints, ndcX, ndcY);
-	} else if (gistA.e.type!=L_NONE) {
-	  gistA.dl.closed= 1;
-	  gistA.dl.smooth= 0;
-	  gistA.dl.marks= gistA.dl.rays= 0;
-	  GaLines(nPoints, ndcX, ndcY);
-	  gistA.dl.closed= 0;
-	}
-	gistA.e.type= type;
+        int type= gistA.e.type;
+        if (!nonGistA.eVisible) gistA.e.type= L_NONE;
+        ConvertPoints(nPoints, vdc, ndcX, ndcY);
+        if (gistA.f.style!=F_EMPTY) {
+          GpFill(nPoints, ndcX, ndcY);
+        } else if (gistA.e.type!=L_NONE) {
+          gistA.dl.closed= 1;
+          gistA.dl.smooth= 0;
+          gistA.dl.marks= gistA.dl.rays= 0;
+          GaLines(nPoints, ndcX, ndcY);
+          gistA.dl.closed= 0;
+        }
+        gistA.e.type= type;
       }
     }
     break;
@@ -2055,7 +2057,7 @@ static int DoClass4(int id, long nOctets)
 
   case 9:   /* CELL ARRAY */
     if (!cselIllegible && !vdcIllegible &&
-	(nOctets&0x7fff)>=14+3*nBytesInt && !(nBytesInt&1)) {
+        (nOctets&0x7fff)>=14+3*nBytesInt && !(nBytesInt&1)) {
       long width, height;
       int colorPrec, mode;
       short pqr[6];
@@ -2073,28 +2075,28 @@ static int DoClass4(int id, long nOctets)
       mode= Snarf16(paramList+12+3*nBytesInt);
 
       if (mode==1 && (colorPrec==0 || colorPrec==8) &&
-	  pqr[4]==pqr[2] && pqr[5]==pqr[1]) {
-	long nColumns= width&1? width+1 : width;
-	long nCells= nColumns*height;
-	GpReal pqx[2], pqy[2];
-	GpColor *colors= (GpColor *)p_malloc(sizeof(GpColor)*nCells);
-	if (colors) {
-	  if (ReadParameters(nOctets, colors, nCells)==nCells) {
-	    if (isGistCGM) {
-	      long i;
-	      for (i=0 ; i<nCells ; i++) colors[i]-= 10;
-	    }  /* bg0fg1 ignored here */
-	    ConvertPoints(2L, pqr, pqx, pqy);
-	    GpCells(pqx[0], pqy[0], pqx[1], pqy[1], width, height,
-		    nColumns, colors);
-	  }
-	  p_free(colors);
-	} else {
-	  SkipParameters(nOctets);
-	  Warning("memory manager failed in DoClass4(CELL ARRAY)", "");
-	}
+          pqr[4]==pqr[2] && pqr[5]==pqr[1]) {
+        long nColumns= width&1? width+1 : width;
+        long nCells= nColumns*height;
+        GpReal pqx[2], pqy[2];
+        GpColor *colors= (GpColor *)p_malloc(sizeof(GpColor)*nCells);
+        if (colors) {
+          if (ReadParameters(nOctets, colors, nCells)==nCells) {
+            if (isGistCGM) {
+              long i;
+              for (i=0 ; i<nCells ; i++) colors[i]-= 10;
+            }  /* bg0fg1 ignored here */
+            ConvertPoints(2L, pqr, pqx, pqy);
+            GpCells(pqx[0], pqy[0], pqx[1], pqy[1], width, height,
+                    nColumns, colors);
+          }
+          p_free(colors);
+        } else {
+          SkipParameters(nOctets);
+          Warning("memory manager failed in DoClass4(CELL ARRAY)", "");
+        }
       } else {
-	SkipParameters(nOctets);
+        SkipParameters(nOctets);
       }
     } else {
       SkipParameters(nOctets);
@@ -2169,9 +2171,9 @@ static int DoClass5(int id, long nOctets)
   case 3:   /* LINE WIDTH */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if ((pictDesc.lwidth==ABSOLUTE && !vdcIllegible && nOctets==2) ||
-	(pictDesc.lwidth==SCALED && !realIllegible && nOctets==4))
+        (pictDesc.lwidth==SCALED && !realIllegible && nOctets==4))
       gistA.l.width= SnarfSA(paramList, pictDesc.lwidth,
-			     DEFAULT_LINE_WIDTH);
+                             DEFAULT_LINE_WIDTH);
     break;
 
   case 4:   /* LINE COLOR */
@@ -2194,9 +2196,9 @@ static int DoClass5(int id, long nOctets)
   case 7:   /* MARKER SIZE */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if ((pictDesc.msize==ABSOLUTE && !vdcIllegible && nOctets==2) ||
-	(pictDesc.msize==SCALED && !realIllegible && nOctets==4))
+        (pictDesc.msize==SCALED && !realIllegible && nOctets==4))
       gistA.m.size= SnarfSA(paramList, pictDesc.msize,
-			    DEFAULT_MARKER_SIZE);
+                            DEFAULT_MARKER_SIZE);
     break;
 
   case 8:   /* MARKER COLOR */
@@ -2215,7 +2217,7 @@ static int DoClass5(int id, long nOctets)
     if (gistA.t.font<0 || gistA.t.font>=pageDesc.nfonts) {
       if (gistA.t.font<0) gistA.t.font= -gistA.t.font;
       if (gistA.t.font>=pageDesc.nfonts)
-	gistA.t.font= gistA.t.font%pageDesc.nfonts;
+        gistA.t.font= gistA.t.font%pageDesc.nfonts;
     }
     gistA.t.font= pageDesc.fonts[gistA.t.font];
     break;
@@ -2246,8 +2248,8 @@ static int DoClass5(int id, long nOctets)
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if (!vdcIllegible && nOctets==2) {
       /* Point size is somewhat greater than CGM "character height"--
-	 use the same factor of 0.8 used by the Gist CGMEngine to assure
-	 that, at least, Gist-produced text is rendered correctly.  */
+         use the same factor of 0.8 used by the Gist CGMEngine to assure
+         that, at least, Gist-produced text is rendered correctly.  */
       gistA.t.height= (1.0/0.8)*cgmScale*((GpReal)Snarf16(paramList));
     }
     break;
@@ -2259,15 +2261,19 @@ static int DoClass5(int id, long nOctets)
       vdc[0]= Snarf16(paramList);
       vdc[1]= Snarf16(paramList+2);
       ConvertPoints(1L, vdc, &nonGistA.upX, &nonGistA.upY);
+      nonGistA.upX -= cgmOffsetX;
+      nonGistA.upY -= cgmOffsetY;
       vdc[0]= Snarf16(paramList+4);
       vdc[1]= Snarf16(paramList+6);
       ConvertPoints(1L, vdc, &nonGistA.baseX, &nonGistA.baseY);
+      nonGistA.baseX -= cgmOffsetX;
+      nonGistA.baseY -= cgmOffsetY;
       if (nonGistA.baseX>nonGistA.baseY) {
-	if (nonGistA.baseX>-nonGistA.baseY) gistA.t.orient= TX_RIGHT;
-	else gistA.t.orient= TX_DOWN;
+        if (nonGistA.baseX>-nonGistA.baseY) gistA.t.orient= TX_RIGHT;
+        else gistA.t.orient= TX_DOWN;
       } else {
-	if (nonGistA.baseX>-nonGistA.baseY) gistA.t.orient= TX_UP;
-	else gistA.t.orient= TX_LEFT;
+        if (nonGistA.baseX>-nonGistA.baseY) gistA.t.orient= TX_UP;
+        else gistA.t.orient= TX_LEFT;
       }
     }
     break;
@@ -2332,7 +2338,7 @@ static int DoClass5(int id, long nOctets)
   case 28:  /* EDGE WIDTH */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if ((pictDesc.ewidth==ABSOLUTE && !vdcIllegible && nOctets==2) ||
-	(pictDesc.ewidth==SCALED && !realIllegible && nOctets==4))
+        (pictDesc.ewidth==SCALED && !realIllegible && nOctets==4))
       gistA.e.width= SnarfSA(paramList, pictDesc.ewidth, DEFAULT_LINE_WIDTH);
     break;
 
@@ -2383,8 +2389,8 @@ static int DoClass5(int id, long nOctets)
   case 34:  /* COLOR TABLE */
     nOctets= ReadParameters(nOctets, (void *)0, 0L);
     if ((!cndxIllegible || cndxIllegible==16) &&
-	((!cvalIllegible && nOctets>=4) ||
-	 (cvalIllegible==16 && nOctets>=7))) {
+        ((!cvalIllegible && nOctets>=4) ||
+         (cvalIllegible==16 && nOctets>=7))) {
       int i, begin= (cndxIllegible? paramList[1] : paramList[0]);
       int i0= (cndxIllegible? 2 : 1);
       int nColors= cvalIllegible? (nOctets-i0)/6 : (nOctets-i0)/3;
@@ -2402,23 +2408,23 @@ static int DoClass5(int id, long nOctets)
 #define COLOR_16(i,n) (255L*(((unsigned int)(n))-mins[i]))/deltas[i]
       if (begin+nColors>cgmNColMax) nColors= cgmNColMax-begin;
       for (i=0 ; i<nColors ; i++) {
-	if (!cvalIllegible) {
+        if (!cvalIllegible) {
           r = COLOR_8(0,paramList[3*i+i0]);
           g = COLOR_8(1,paramList[3*i+i0+1]);
           b = COLOR_8(2,paramList[3*i+i0+2]);
-	} else {
-	  r = COLOR_16(0,Snarf16(paramList+6*i+i0));
-	  g = COLOR_16(1,Snarf16(paramList+6*i+i0+2));
-	  b = COLOR_16(2,Snarf16(paramList+6*i+i0+4));
-	}
+        } else {
+          r = COLOR_16(0,Snarf16(paramList+6*i+i0));
+          g = COLOR_16(1,Snarf16(paramList+6*i+i0+2));
+          b = COLOR_16(2,Snarf16(paramList+6*i+i0+4));
+        }
         cgmPalette[i+begin] = P_RGB(r, g, b);
       }
       if (nColors>0) {
-	int offset= isGistCGM? 10 : (bg0fg1? 2 : 0);
-	GpPutNTSC(nColors, cgmPalette+begin);
-	if (!cgmColorChange || cgmNColors<begin+nColors)
-	  cgmNColors= begin+nColors;
-	if (cgmNColors>offset) cgmColorChange= 1;
+        int offset= isGistCGM? 10 : (bg0fg1? 2 : 0);
+        GpPutNTSC(nColors, cgmPalette+begin);
+        if (!cgmColorChange || cgmNColors<begin+nColors)
+          cgmNColors= begin+nColors;
+        if (cgmNColors>offset) cgmColorChange= 1;
       }
     }
     break;
