@@ -35,8 +35,8 @@ static void DefaultClearArea(Engine *engine, GpBox *box)
   engine->damaged= engine->inhibit= 0;
 }
 
-Engine *GpNewEngine(long size, char *name, char *type,
-		    GpTransform *transform, int landscape,
+Engine *GpNewEngine(long size, char *name, g_callbacks *on,
+                    GpTransform *transform, int landscape,
   void (*Kill)(Engine*), int (*Clear)(Engine*,int), int (*Flush)(Engine*),
   void (*ChangeMap)(Engine*), int (*ChangePalette)(Engine*),
   int (*DrawLines)(Engine*,long,const GpReal*,const GpReal*,int,int),
@@ -44,9 +44,9 @@ Engine *GpNewEngine(long size, char *name, char *type,
   int (*DrwText)(Engine*e,GpReal,GpReal,const char*),
   int (*DrawFill)(Engine*,long,const GpReal*,const GpReal*),
   int (*DrawCells)(Engine*,GpReal,GpReal,GpReal,GpReal,
-		   long,long,long,const GpColor*),
+                   long,long,long,const GpColor*),
   int (*DrawDisjoint)(Engine*,long,const GpReal*,const GpReal*,
-		      const GpReal*,const GpReal*))
+                      const GpReal*,const GpReal*))
 {
   long lname= name? strlen(name) : 0;
   Engine *engine;
@@ -64,7 +64,7 @@ Engine *GpNewEngine(long size, char *name, char *type,
   engine->nextActive= 0;
   engine->name= (char *)engine + size;
   strcpy(name? engine->name : "", name);
-  engine->type= type;
+  engine->on = on;
   engine->active= 0;
   engine->marked= 0;
 
@@ -253,7 +253,7 @@ void GpSetMap(const GpBox *src, const GpBox *dst, GpXYMap *map)
 void GpDeviceMap(Engine *engine)
 {
   GpSetMap(&engine->transform.viewport, &engine->transform.window,
-	   &engine->devMap);
+           &engine->devMap);
 }
 
 void GpComposeMap(Engine *engine)
@@ -264,12 +264,12 @@ void GpComposeMap(Engine *engine)
   GpMap *mapy= &engine->map.y;
   mapx->scale=
     devx->scale*(gistT.viewport.xmax-gistT.viewport.xmin)/
-	        (gistT.window.xmax-gistT.window.xmin);
+                (gistT.window.xmax-gistT.window.xmin);
   mapx->offset= devx->offset + devx->scale*gistT.viewport.xmin -
                 mapx->scale*gistT.window.xmin;
   mapy->scale=
     devy->scale*(gistT.viewport.ymax-gistT.viewport.ymin)/
-	        (gistT.window.ymax-gistT.window.ymin);
+                (gistT.window.ymax-gistT.window.ymin);
   mapy->offset= devy->offset + devy->scale*gistT.viewport.ymin -
                 mapy->scale*gistT.window.ymin;
 }
@@ -297,7 +297,7 @@ static void MoreScratch(long np, long ns)
 }
 
 long GpIntPoints(const GpXYMap *map, long maxPoints, long n,
-		 const GpReal *x, const GpReal *y, GpPoint **result)
+                 const GpReal *x, const GpReal *y, GpPoint **result)
 {
   GpReal scalx= map->x.scale, offx= map->x.offset;
   GpReal scaly= map->y.scale, offy= map->y.offset;
@@ -316,8 +316,8 @@ long GpIntPoints(const GpXYMap *map, long maxPoints, long n,
 }
 
 long GpIntSegs(const GpXYMap *map, long maxSegs, long n,
-	       const GpReal *x1, const GpReal *y1,
-	       const GpReal *x2, const GpReal *y2, GpSegment **result)
+               const GpReal *x1, const GpReal *y1,
+               const GpReal *x2, const GpReal *y2, GpSegment **result)
 {
   GpReal scalx= map->x.scale, offx= map->x.offset;
   GpReal scaly= map->y.scale, offy= map->y.offset;
@@ -404,7 +404,7 @@ int GpDumpColors(Engine *engine, int colorMode)
 /* ------------------------------------------------------------------------ */
 
 long GpClipCells(GpMap *map, GpReal *px, GpReal *qx,
-		 GpReal xmin, GpReal xmax, long ncells, long *off)
+                 GpReal xmin, GpReal xmax, long ncells, long *off)
 {
   long imin, imax;
   GpReal p, q, dx;
@@ -434,39 +434,39 @@ long GpClipCells(GpMap *map, GpReal *px, GpReal *qx,
     }
     if (imax-imin<2) {
       if (imax==imin) {
-	if (p<xmin) p= xmin;
-	if (q>xmax) q= xmax;
+        if (p<xmin) p= xmin;
+        if (q>xmax) q= xmax;
       } else {
-	if (p<xmin && q>xmax) {
-	  if (q-xmax > xmin-p) { q-= xmin-p;  p= xmin; }
-	  else { p+= q-xmax;  q= xmax; }
-	}
+        if (p<xmin && q>xmax) {
+          if (q-xmax > xmin-p) { q-= xmin-p;  p= xmin; }
+          else { p+= q-xmax;  q= xmax; }
+        }
       }
     }
   } else if (p>q && p>=xmin && q<=xmax) {
     dx= (p-q)/(GpReal)ncells;
     if (q<xmin) {
-      imin= (long)((xmin-q)/dx);
-      q+= dx*(GpReal)imin;
-    } else {
-      imin= 0;
-    }
-    if (p>xmax) {
-      imax= (long)((p-xmax)/dx);
-      p-= dx*(GpReal)imax;
+      imax= (long)((xmin-q)/dx);
+      q+= dx*(GpReal)imax;
       imax= ncells-imax;
     } else {
       imax= ncells;
     }
+    if (p>xmax) {
+      imin= (long)((p-xmax)/dx);
+      p-= dx*(GpReal)imin;
+    } else {
+      imin= 0;
+    }
     if (imax-imin<2) {
       if (imax==imin) {
-	if (q<xmin) q= xmin;
-	if (p>xmax) p= xmax;
+        if (q<xmin) q= xmin;
+        if (p>xmax) p= xmax;
       } else {
-	if (q<xmin && p>xmax) {
-	  if (p-xmax > xmin-q) { p-= xmin-q;  q= xmin; }
-	  else { q+= p-xmax;  p= xmax; }
-	}
+        if (q<xmin && p>xmax) {
+          if (p-xmax > xmin-q) { p-= xmin-q;  q= xmin; }
+          else { q+= p-xmax;  p= xmax; }
+        }
       }
     }
   } else {
@@ -534,30 +534,30 @@ int GdBeginDr(Drauing *drawing, GpBox *damage, int landscape)
   for (eng=GpNextActive(0) ; eng ; eng=GpNextActive(eng)) {
     if (eng->drawing!=drawing) {
       /* This engine is not marked as interested in this drawing.
-	 Mark it, and reset damaged and lastDrawn flags so that no
-	 elements will be inhibited.  */
+         Mark it, and reset damaged and lastDrawn flags so that no
+         elements will be inhibited.  */
       eng->drawing= drawing;
       eng->lastDrawn= -1;
       eng->damaged= 0;
       if (landscape != eng->landscape) {
-	eng->landscape= landscape;
-	/* This change will be detected and acted upon by the first call
-	   to the ChangeMap method (GpSetTrans).  */
+        eng->landscape= landscape;
+        /* This change will be detected and acted upon by the first call
+           to the ChangeMap method (GpSetTrans).  */
       }
       /* The semantics here are subtle --
-	 After a ClearDrawing, GdDetach zeroes eng->drawing in order to
-	 communicate that the drawing has been cleared.  Thus, the code
-	 gets here on a GdDraw after the drawing has been cleared, so
-	 the time has come to carry out the deferred clearing of this
-	 engine's plotting surface.  */
+         After a ClearDrawing, GdDetach zeroes eng->drawing in order to
+         communicate that the drawing has been cleared.  Thus, the code
+         gets here on a GdDraw after the drawing has been cleared, so
+         the time has come to carry out the deferred clearing of this
+         engine's plotting surface.  */
       GpClear(eng, CONDITIONALLY);
       needToRedraw= 1;
 
     } else if (eng->damaged) {
       /* This engine was interested in the drawing, which has been
-	 damaged.  Clear damaged area in preparation for repair work.
-	 (This is redundant if the damage was due to an X windows
-	  expose event, but the resulting inefficiency is very small.)  */
+         damaged.  Clear damaged area in preparation for repair work.
+         (This is redundant if the damage was due to an X windows
+          expose event, but the resulting inefficiency is very small.)  */
       eng->ClearArea(eng, &eng->damage);
       needToRedraw= 1;
 
@@ -571,7 +571,7 @@ int GdBeginDr(Drauing *drawing, GpBox *damage, int landscape)
 }
 
 int GdBeginSy(GpBox *tickOut, GpBox *tickIn, GpBox *viewport,
-	      int number, int sysIndex)
+              int number, int sysIndex)
 {
   Engine *eng;
   int value= 0;
@@ -599,18 +599,18 @@ int GdBeginSy(GpBox *tickOut, GpBox *tickIn, GpBox *viewport,
 
     } else if (eng->damaged && GpIntersect(tickOut, &eng->damage)) {
       /* engine damage touches this coordinate system--
-	 redraw ticks if region between tickIn and tickOut damaged,
-	 redraw elements if viewport damaged */
+         redraw ticks if region between tickIn and tickOut damaged,
+         redraw elements if viewport damaged */
       if (!tickIn || !GpContains(tickIn, &eng->damage)) {
-	value|= 2;
-	eng->inhibit= 0;
+        value|= 2;
+        eng->inhibit= 0;
       } else eng->inhibit= 1;
       if (number>eng->lastDrawn || GpIntersect(viewport, &eng->damage))
-	value|= 1;
+        value|= 1;
 
     } else {
       /* engine undamaged or damage doesn't touch this system--
-	 redraw elements if any new ones, don't redraw ticks */
+         redraw elements if any new ones, don't redraw ticks */
       eng->inhibit= 1;
       if (number>eng->lastDrawn) value|= 1;
     }
@@ -633,11 +633,11 @@ int GdBeginEl(GpBox *box, int number)
       eng->inhibit= 0;
       value= 1;
       if (eng->damaged && gdMaxRendered<=eng->lastDrawn) {
-	/* If this is the first new element, the damage flag
-	   must be reset, and ChangeMap must be called to set the
-	   clip rectangle back to its undamaged boundary.  */
-	eng->damaged= 0;
-	eng->ChangeMap(eng);
+        /* If this is the first new element, the damage flag
+           must be reset, and ChangeMap must be called to set the
+           clip rectangle back to its undamaged boundary.  */
+        eng->damaged= 0;
+        eng->ChangeMap(eng);
       }
 
     } else if (box && eng->damaged && GpIntersect(box, &eng->damage)) {
