@@ -25,6 +25,9 @@ extern char *strcpy(char *, const char *);
 
 void (*GdFree)(void *)= 0;
 
+void (*g_stdout)(char *msg) = 0;
+void (*g_on_keyline)(char *msg) = 0;
+
 /* Font for character occasional markers on curves */
 #define MARKER_FONT T_HELVETICA
 
@@ -61,33 +64,33 @@ static int GetScratch(long n);
 static char SwapTextMark(void);
 static void SwapMarkText(void);
 static void SwapNormMap(GpReal *scalx, GpReal *offx,
-			GpReal *scaly, GpReal *offy);
+                        GpReal *scaly, GpReal *offy);
 static void SwapMapNorm(void);
 static void ClipArrow(GpReal x[3], GpReal y[3]);
 static GpReal TrueNorm(GpReal dx, GpReal dy);
 static GpReal OctagNorm(GpReal dx, GpReal dy);
 static void DecorateLines(long n, const GpReal *px, const GpReal *py,
-			  int closed);
+                          int closed);
 static int MeshRowF(long iMax, long ijMax, int *ireg, int region,
-		    long *ii, long *k);
+                    long *ii, long *k);
 static int MeshColF(long iMax, long ijMax, int *ireg, int region,
-		    GpReal *x, GpReal *y, long *jj, long *kk);
+                    GpReal *x, GpReal *y, long *jj, long *kk);
 static int MeshRowR(long iMax, long ijMax, int *ireg, int region,
-		    long *ii, long *k);
+                    long *ii, long *k);
 static int MeshColR(long iMax, long ijMax, int *ireg, int region,
-		    GpReal *x, GpReal *y, long *jj, long *kk);
+                    GpReal *x, GpReal *y, long *jj, long *kk);
 static int MeshRowB(long iMax, long ijMax, int *ireg, int region,
-		    long *ii, long *k);
+                    long *ii, long *k);
 static int MeshColB(long iMax, long ijMax, int *ireg, int region,
-		    GpReal *x, GpReal *y, long *jj, long *kk);
+                    GpReal *x, GpReal *y, long *jj, long *kk);
 static int *NewReg(long iMax, long ijMax);
 static void FreeTmpReg(void);
 static int DoSaddle(long zone, long step, long ij, long inc);
 static void DoSmoothing(long *n, const GpReal **px, const GpReal **py,
-			int closed, int smooth, GpReal scalx, GpReal offx,
-			GpReal scaly, GpReal offy);
+                        int closed, int smooth, GpReal scalx, GpReal offx,
+                        GpReal scaly, GpReal offy);
 static int SmoothLines(long n, const GpReal *px, const GpReal *py,
-		       int closed, int smooth, int clip);
+                       int closed, int smooth, int clip);
 
 /* ------------------------------------------------------------------------ */
 
@@ -103,7 +106,7 @@ static void InitializeClip(void)
   gpClipInit= 0;
   if (!already && gistClip) {
     ClipSetup(gistT.window.xmin, gistT.window.xmax,
-	      gistT.window.ymin, gistT.window.ymax);
+              gistT.window.ymin, gistT.window.ymax);
   }
 }
 
@@ -124,11 +127,11 @@ int GpLines(long n, const GpReal *px, const GpReal *py)
   if (!clip || ClipBegin(px, py, n, closed)) {
     for (engine=GpNextActive(0) ; engine ; engine=GpNextActive(engine))
       if (!engine->inhibit)
-	value|= engine->DrawLines(engine, n, px, py, closed, smooth);
+        value|= engine->DrawLines(engine, n, px, py, closed, smooth);
   } else while ((n=ClipMore())) {
     for (engine=GpNextActive(0) ; engine ; engine=GpNextActive(engine))
       if (!engine->inhibit)
-	value|= engine->DrawLines(engine, n, xClip, yClip, 0, smooth);
+        value|= engine->DrawLines(engine, n, xClip, yClip, 0, smooth);
   }
 
   return value;
@@ -191,8 +194,8 @@ int GpFill(long n, const GpReal *px, const GpReal *py)
 }
 
 int GpCells(GpReal px, GpReal py, GpReal qx, GpReal qy,
-	    long width, long height, long nColumns,
-	    const GpColor *colors)
+            long width, long height, long nColumns,
+            const GpColor *colors)
 {
   int value= 0;
   Engine *engine;
@@ -200,13 +203,13 @@ int GpCells(GpReal px, GpReal py, GpReal qx, GpReal qy,
   for (engine=GpNextActive(0) ; engine ; engine=GpNextActive(engine))
     if (!engine->inhibit)
       value|= engine->DrawCells(engine, px, py, qx, qy,
-				width, height, nColumns, colors);
+                                width, height, nColumns, colors);
 
   return value;
 }
 
 int GpDisjoint(long n, const GpReal *px, const GpReal *py,
-	       const GpReal *qx, const GpReal *qy)
+               const GpReal *qx, const GpReal *qy)
 {
   int value= 0;
   Engine *engine;
@@ -235,7 +238,7 @@ int GpDisjoint(long n, const GpReal *px, const GpReal *py,
      GaMesh - needs jMax GpReal points to gather columns
      GaContourInit - needs #edges GpReal points for contours
                      needs ijMax short array for edge markers
-		     may need ijMax short array for triangulation
+                     may need ijMax short array for triangulation
      GaTicks - needs a bunch
      GpLines - needs 3*n real points for smoothing (can't overlap
                with contour scratch space)
@@ -349,7 +352,7 @@ static void SwapMarkText(void)
 static GpBox windowSave;
 
 static void SwapNormMap(GpReal *scalx, GpReal *offx,
-			GpReal *scaly, GpReal *offy)
+                        GpReal *scaly, GpReal *offy)
 {
   windowSave= gistT.window;
 
@@ -436,7 +439,7 @@ static GpReal OctagNorm(GpReal dx, GpReal dy)
 }
 
 static void DecorateLines(long n, const GpReal *px, const GpReal *py,
-			  int closed)
+                          int closed)
 {
   GpReal dx, dy, x1, y1, x0, y0, x00= *px, y00= *py;
   GpReal len, trueLen, xL, yL, xW, yW, x[3], y[3];
@@ -484,40 +487,40 @@ static void DecorateLines(long n, const GpReal *px, const GpReal *py,
     if (marks) {
       markPhase+= len;
       while (markPhase>=markSpacing) {
-	markPhase-= markSpacing;
-	frac= markPhase/len;   /* 0<=frac<1, pt=pt0*frac+pt1*(1-frac) */
-	/* Since the point is guaranteed to be inside current window,
-	   no floating point clip is required here.  Rays are harder.  */
-	GpText(x1*scalx+offx-dx*frac, y1*scaly+offy-dy*frac, markText);
+        markPhase-= markSpacing;
+        frac= markPhase/len;   /* 0<=frac<1, pt=pt0*frac+pt1*(1-frac) */
+        /* Since the point is guaranteed to be inside current window,
+           no floating point clip is required here.  Rays are harder.  */
+        GpText(x1*scalx+offx-dx*frac, y1*scaly+offy-dy*frac, markText);
       }
     }
 
     if (rays) {
       rayPhase+= len;
       if (rayPhase>=raySpacing) {
-	trueLen= TrueNorm(dx, dy);
-	xL= dx/trueLen;
-	yW= -arrowW*xL;
-	xL*= -arrowL;
-	yL= dy/trueLen;
-	xW= arrowW*yL;
-	yL*= -arrowL;
-	while (rayPhase>=raySpacing) {
-	  rayPhase-= raySpacing;
-	  frac= rayPhase/len;   /* 0<=frac<1, pt=pt0*frac+pt1*(1-frac) */
-	  x[1]= x1*scalx+offx-dx*frac;
-	  y[1]= y1*scaly+offy-dy*frac;
-	  x[0]= x[1]+xL+xW;
-	  y[0]= y[1]+yL+yW;
-	  x[2]= x[1]+xL-xW;
-	  y[2]= y[1]+yL-yW;
-	  /* Guaranteed that point of arrow (x[1],y[1]) is inside window,
-	     but points may hang outside.  Clipping is tricky because
-	     this routine is called from inside a clipping loop.  */
-	  ClipArrow(x,y);
-	  gpClipDone= 1;
-	  GpLines(3, x, y);
-	}
+        trueLen= TrueNorm(dx, dy);
+        xL= dx/trueLen;
+        yW= -arrowW*xL;
+        xL*= -arrowL;
+        yL= dy/trueLen;
+        xW= arrowW*yL;
+        yL*= -arrowL;
+        while (rayPhase>=raySpacing) {
+          rayPhase-= raySpacing;
+          frac= rayPhase/len;   /* 0<=frac<1, pt=pt0*frac+pt1*(1-frac) */
+          x[1]= x1*scalx+offx-dx*frac;
+          y[1]= y1*scaly+offy-dy*frac;
+          x[0]= x[1]+xL+xW;
+          y[0]= y[1]+yL+yW;
+          x[2]= x[1]+xL-xW;
+          y[2]= y[1]+yL-yW;
+          /* Guaranteed that point of arrow (x[1],y[1]) is inside window,
+             but points may hang outside.  Clipping is tricky because
+             this routine is called from inside a clipping loop.  */
+          ClipArrow(x,y);
+          gpClipDone= 1;
+          GpLines(3, x, y);
+        }
       }
     }
     x0= x1;
@@ -552,7 +555,7 @@ int GpPseudoMark(Engine *engine, long n, const GpReal *px, const GpReal *py)
 
 int GaLines(long n, const GpReal *px, const GpReal *py)
      /* Like GpLines, but includes GaAttributes fancy line attributes
-	as well as the line attributes from GpAttributes.  */
+        as well as the line attributes from GpAttributes.  */
 {
   int value= 0;
 
@@ -592,7 +595,7 @@ int GaLines(long n, const GpReal *px, const GpReal *py)
 
 /* ARGSUSED */
 static int MeshRowF(long iMax, long ijMax, int *ireg, int region,
-		    long *ii, long *k)
+                    long *ii, long *k)
 {
   long i= *ii;
   while (++i<ijMax)   /* scan till edge exists */
@@ -607,7 +610,7 @@ static int MeshRowF(long iMax, long ijMax, int *ireg, int region,
 
 /* ARGSUSED */
 static int MeshColF(long iMax, long ijMax, int *ireg, int region,
-		    GpReal *x, GpReal *y, long *jj, long *kk)
+                    GpReal *x, GpReal *y, long *jj, long *kk)
 {
   long k, j= *jj;
   while ((j+=iMax)<ijMax)   /* scan till edge exists */
@@ -630,7 +633,7 @@ static int MeshColF(long iMax, long ijMax, int *ireg, int region,
 }
 
 static int MeshRowR(long iMax, long ijMax, int *ireg, int region,
-		    long *ii, long *k)
+                    long *ii, long *k)
 {
   long i= *ii;
   while (++i<ijMax)   /* scan till edge exists */
@@ -644,7 +647,7 @@ static int MeshRowR(long iMax, long ijMax, int *ireg, int region,
 }
 
 static int MeshColR(long iMax, long ijMax, int *ireg, int region,
-		    GpReal *x, GpReal *y, long *jj, long *kk)
+                    GpReal *x, GpReal *y, long *jj, long *kk)
 {
   long k, j= *jj;
   while ((j+=iMax)<ijMax)   /* scan till edge exists */
@@ -667,7 +670,7 @@ static int MeshColR(long iMax, long ijMax, int *ireg, int region,
 }
 
 static int MeshRowB(long iMax, long ijMax, int *ireg, int region,
-		    long *ii, long *k)
+                    long *ii, long *k)
 {
   long i= *ii;
   while (++i<ijMax)   /* scan till edge exists */
@@ -681,7 +684,7 @@ static int MeshRowB(long iMax, long ijMax, int *ireg, int region,
 }
 
 static int MeshColB(long iMax, long ijMax, int *ireg, int region,
-		    GpReal *x, GpReal *y, long *jj, long *kk)
+                    GpReal *x, GpReal *y, long *jj, long *kk)
 {
   long k, j= *jj;
   while ((j+=iMax)<ijMax)   /* scan till edge exists */
@@ -781,9 +784,9 @@ int GaMesh(GaQuadMesh *mesh, int region, int boundary, int inhibit)
     for (i=0 ; i<iMax ; i++) {
       j= i;
       for (;;) {
-	if (MeshCol(iMax, ijMax, ireg, region, x, y, &j, &k)) break;
-	value|= GpLines(k, gaxScratch, gayScratch);
-	if (j>=ijMax) break;
+        if (MeshCol(iMax, ijMax, ireg, region, x, y, &j, &k)) break;
+        value|= GpLines(k, gaxScratch, gayScratch);
+        if (j>=ijMax) break;
       }
     }
   }
@@ -797,7 +800,7 @@ int GaMesh(GaQuadMesh *mesh, int region, int boundary, int inhibit)
 #define EXISTS(ij) (region? ireg[ij]==region : ireg[ij])
 
 int GaFillMesh(GaQuadMesh *mesh, int region, const GpColor *colors,
-	       long nColumns)
+               long nColumns)
 {
   int value= 0;
   long iMax= mesh->iMax;
@@ -848,7 +851,7 @@ int GaFillMesh(GaQuadMesh *mesh, int region, const GpColor *colors,
 }
 
 int GaFillMarker(long n, const GpReal *px, const GpReal *py,
-		 GpReal x0, GpReal y0)
+                 GpReal x0, GpReal y0)
 {
   int value= 0;
   Engine *engine;
@@ -885,7 +888,7 @@ int GaFillMarker(long n, const GpReal *px, const GpReal *py,
   if (n>=2) {
     for (engine=GpNextActive(0) ; engine ; engine=GpNextActive(engine))
       if (!engine->inhibit)
-	value|= engine->DrawFill(engine, n, px, py);
+        value|= engine->DrawFill(engine, n, px, py);
   }
 
   SwapMapNorm();
@@ -895,7 +898,7 @@ int GaFillMarker(long n, const GpReal *px, const GpReal *py,
 /* ------------------------------------------------------------------------ */
 
 int GaVectors(GaQuadMesh *mesh, int region,
-	      const GpReal *u, const GpReal *v, GpReal scale)
+              const GpReal *u, const GpReal *v, GpReal scale)
 {
   int value= 0;
   long iMax= mesh->iMax;
@@ -943,11 +946,11 @@ int GaVectors(GaQuadMesh *mesh, int region,
       vy[2]= yc - dy + aspect*dx;
 
       if (hollow) {
-	gpCloseNext= gpClipInit= 1;
-	value|= GpLines(3, vx, vy);
+        gpCloseNext= gpClipInit= 1;
+        value|= GpLines(3, vx, vy);
       } else {
-	gpClipInit= 1;
-	value|= GpFill(3, vx, vy);
+        gpClipInit= 1;
+        value|= GpFill(3, vx, vy);
       }
     }
   }
@@ -967,7 +970,7 @@ int GaVectors(GaQuadMesh *mesh, int region,
         gistA.dl= linestyle[i];
         if (GaContourInit(mesh, 0, z, level[i]))
           while (GaContour(&n, &px, &py, &gistA.dl.closed))
-	    GaLines(n, px, py);    **( loop on disjoint parts )**
+            GaLines(n, px, py);    **( loop on disjoint parts )**
       }
  */
 
@@ -981,23 +984,23 @@ static short *iedges, *jedges;
 static int keepLeft;
 
 int GaContourInit(GaQuadMesh *msh, int regn,
-		  const GpReal *zz, GpReal lev)
+                  const GpReal *zz, GpReal lev)
        /* Find the edges cut by the current contour, remembering
-	  z, triangle, and level for the GaContour routine, which
-	  actually walks the contour.  The z array represents function
-	  values on the mesh msh.  If triangle!=0,
-	  it represents the initial value of the triangulation array,
-	  which determines the behavior of GaContour in saddle zones.
-	    triangle[j][i]= 1, -1, or 0 as the zone bounded by
-	      [j-1][i-1], [j-1][i], [j][i], and [j][i-1]
-	      has been triangulated from (-1,-1) to (0,0),
-	      from (-1,0) to (0,-1), or has not yet been
-	      triangulated.
-	  The msh->triangle array is updated by GaContour.
-	  If a contour passes through an untriangulated saddle zone,
-	  GaContour chooses a triangulation and marks the triangle
-	  array approriately, so that subsequent calls to GaContour
-	  will never produce intersecting contour curves.  */
+          z, triangle, and level for the GaContour routine, which
+          actually walks the contour.  The z array represents function
+          values on the mesh msh.  If triangle!=0,
+          it represents the initial value of the triangulation array,
+          which determines the behavior of GaContour in saddle zones.
+            triangle[j][i]= 1, -1, or 0 as the zone bounded by
+              [j-1][i-1], [j-1][i], [j][i], and [j][i-1]
+              has been triangulated from (-1,-1) to (0,0),
+              from (-1,0) to (0,-1), or has not yet been
+              triangulated.
+          The msh->triangle array is updated by GaContour.
+          If a contour passes through an untriangulated saddle zone,
+          GaContour chooses a triangulation and marks the triangle
+          array approriately, so that subsequent calls to GaContour
+          will never produce intersecting contour curves.  */
 {
   long iMax= msh->iMax;
   long ijMax= iMax*msh->jMax;
@@ -1030,11 +1033,11 @@ int GaContourInit(GaQuadMesh *msh, int regn,
   for (ij=1 ; ij<ijMax ; ij++) {
     if ((iedges[ij]^iedges[ij-1]) && (EXISTS(ij)||EXISTS(ij+iMax))) {
       if ((ireg[ij]==region) ^ (ireg[ij+iMax]==region)) {
-	jedges[ij]= 2;  /* contour enters mesh here */
-	njb++;
+        jedges[ij]= 2;  /* contour enters mesh here */
+        njb++;
       } else {
-	jedges[ij]= 1;  /* interior edge */
-	nj++;
+        jedges[ij]= 1;  /* interior edge */
+        nj++;
       }
     } else {
       jedges[ij]= 0;
@@ -1047,11 +1050,11 @@ int GaContourInit(GaQuadMesh *msh, int regn,
   for (ij=ijMax-1 ; ij>=iMax ; ij--) {
     if ((iedges[ij]^iedges[ij-iMax]) && (EXISTS(ij)||EXISTS(ij+1))) {
       if ((ireg[ij]==region) ^ (ireg[ij+1]==region)) {
-	iedges[ij]= 2;  /* contour enters mesh here */
-	nib++;
+        iedges[ij]= 2;  /* contour enters mesh here */
+        nib++;
       } else {
-	iedges[ij]= 1;  /* interior edge */
-	ni++;
+        iedges[ij]= 1;  /* interior edge */
+        ni++;
       }
     } else {
       iedges[ij]= 0;
@@ -1096,14 +1099,14 @@ static int DoSaddle(long zone, long step, long ij, long inc)
 
 int GaContour(long *cn, GpReal **cx, GpReal **cy, int *closed)
        /* After a call to GaContourInit, GaContour must be called
-	  repeatedly to generate the sequence of curves obtained by
-	  walking the edges cut by the contour level plane.  GaContour
-	  returns 1 until there are no more contours to be plotted,
-	  when it returns 0.  GaContour signals an error by returning
-	  0, but setting *cn!=0.  The curve coordinates (*cx,*cy)
-	  use internal scratch space and the associated storage must
-	  not be freed.  (*cx, *cy) are valid only until the next
-	  GaContour or GaMesh call.  */
+          repeatedly to generate the sequence of curves obtained by
+          walking the edges cut by the contour level plane.  GaContour
+          returns 1 until there are no more contours to be plotted,
+          when it returns 0.  GaContour signals an error by returning
+          0, but setting *cn!=0.  The curve coordinates (*cx,*cy)
+          use internal scratch space and the associated storage must
+          not be freed.  (*cx, *cy) are valid only until the next
+          GaContour or GaMesh call.  */
 {
   long iMax= mesh->iMax;
   long ijMax= iMax*mesh->jMax;
@@ -1171,45 +1174,45 @@ int GaContour(long *cn, GpReal **cx, GpReal **cy, int *closed)
     /* Find exit from current zone */
     if (inc==1) { /* this is a j=const edge */
       if (jedges[ij+step] && !iedges[zone]) {
-	/* step, inc unchanged */
-	ij+= step;
+        /* step, inc unchanged */
+        ij+= step;
       } else if (iedges[zone] &&
-		 (!iedges[zone-1] || DoSaddle(zone, step, ij, inc))) {
-	ij= zone;
-	if (step>0) keepLeft= 1;  /* just turned right */
-	else keepLeft= 0;
-	step= 1;
-	inc= iMax;
+                 (!iedges[zone-1] || DoSaddle(zone, step, ij, inc))) {
+        ij= zone;
+        if (step>0) keepLeft= 1;  /* just turned right */
+        else keepLeft= 0;
+        step= 1;
+        inc= iMax;
       } else if (iedges[zone-1]) {
-	ij= zone-1;
-	if (step>0) keepLeft= 0;  /* just turned left */
-	else keepLeft= 1;
-	step= -1;
-	inc= iMax;
+        ij= zone-1;
+        if (step>0) keepLeft= 0;  /* just turned left */
+        else keepLeft= 1;
+        step= -1;
+        inc= iMax;
       } else {
-	isClosed= 1;  /* end of a closed contour */
-	break;
+        isClosed= 1;  /* end of a closed contour */
+        break;
       }
     } else {      /* this is a i=const edge */
       if (iedges[ij+step] && !jedges[zone]) {
-	/* step, inc unchanged */
-	ij+= step;
+        /* step, inc unchanged */
+        ij+= step;
       } else if (jedges[zone] &&
-		 (!jedges[zone-iMax] || DoSaddle(zone, step, ij, inc))) {
-	ij= zone;
-	if (step>0) keepLeft= 0;  /* just turned left */
-	else keepLeft= 1;
-	step= iMax;
-	inc= 1;
+                 (!jedges[zone-iMax] || DoSaddle(zone, step, ij, inc))) {
+        ij= zone;
+        if (step>0) keepLeft= 0;  /* just turned left */
+        else keepLeft= 1;
+        step= iMax;
+        inc= 1;
       } else if (jedges[zone-iMax]) {
-	ij= zone-iMax;
-	if (step>0) keepLeft= 1;  /* just turned right */
-	else keepLeft= 0;
-	step= -iMax;
-	inc= 1;
+        ij= zone-iMax;
+        if (step>0) keepLeft= 1;  /* just turned right */
+        else keepLeft= 0;
+        step= -iMax;
+        inc= 1;
       } else {
-	isClosed= 1;  /* end of a closed contour */
-	break;
+        isClosed= 1;  /* end of a closed contour */
+        break;
       }
     }
 
@@ -1227,17 +1230,17 @@ int GaContour(long *cn, GpReal **cx, GpReal **cy, int *closed)
       mark= jedges[ij];
       jedges[ij]= 0;
       if (mark==2) { /* end of an open contour */
-	njb--;
-	if (!njb) jbegin= 1;
+        njb--;
+        if (!njb) jbegin= 1;
         break;
       } else nj--;
     } else {
       mark= iedges[ij];
       iedges[ij]= 0;
       if (mark==2) { /* end of an open contour */
-	nib--;
-	if (!nib) ibegin= iMax;
-	break;
+        nib--;
+        if (!nib) ibegin= iMax;
+        break;
       }
       else ni--;
     }
@@ -1260,14 +1263,14 @@ int GaContour(long *cn, GpReal **cx, GpReal **cy, int *closed)
 /* ------------------------------------------------------------------------ */
 
 static void DoSmoothing(long *n, const GpReal **px, const GpReal **py,
-			int closed, int smooth, GpReal scalx, GpReal offx,
-			GpReal scaly, GpReal offy)
+                        int closed, int smooth, GpReal scalx, GpReal offx,
+                        GpReal scaly, GpReal offy)
      /* Each point is "split" into three colinear points:
-	The central point of each triad is the original point, and
-	the other two lie along the direction bisecting the original turn
-	at the center point.  For open curves, the first and last points
-	are simply duplicated.  Each group of 4 points is suitable as
-	the initial, two control, and final points of a Bezier curve.  */
+        The central point of each triad is the original point, and
+        the other two lie along the direction bisecting the original turn
+        at the center point.  For open curves, the first and last points
+        are simply duplicated.  Each group of 4 points is suitable as
+        the initial, two control, and final points of a Bezier curve.  */
 {
   long nn= *n;
   const GpReal *x= *px,  *y= *py;
@@ -1379,7 +1382,7 @@ static void DoSmoothing(long *n, const GpReal **px, const GpReal **py,
 }
 
 static int SmoothLines(long n, const GpReal *px, const GpReal *py,
-		       int closed, int smooth, int clip)
+                       int closed, int smooth, int clip)
 {
   int value= 0;
   Engine *engine;
@@ -1398,14 +1401,14 @@ static int SmoothLines(long n, const GpReal *px, const GpReal *py,
     /* Note: if closed, n= 3*n+1, last point same as first */
     for (engine=GpNextActive(0) ; engine ; engine=GpNextActive(engine))
       if (!engine->inhibit)
-	value|= engine->DrawLines(engine, n, px, py, 0, smooth);
+        value|= engine->DrawLines(engine, n, px, py, 0, smooth);
   } else while ((n=ClipMore())) {
     px= xClip;
     py= yClip;
     DoSmoothing(&n, &px, &py, 0, smooth, scalx, offx, scaly, offy);
     for (engine=GpNextActive(0) ; engine ; engine=GpNextActive(engine))
       if (!engine->inhibit)
-	value|= engine->DrawLines(engine, n, px, py, 0, smooth);
+        value|= engine->DrawLines(engine, n, px, py, 0, smooth);
   }
 
   SwapMapNorm();
