@@ -23,7 +23,7 @@ extern p_file *GistOpen(const char *name);  /* from gread.c */
 #define CREATE_PS(name) p_fopen(name, "w")
 #endif
 
-static char *psType= "PostScript";
+static g_callbacks g_ps_on = { "gist PSEngine", 0, 0, 0, 0, 0, 0, 0, 0 };
 
 static char line[80];  /* no lines longer than 78 characters! */
 
@@ -39,7 +39,7 @@ static void InitBB(GpsBBox *bb);
 static void SetPageDefaults(PSEngine *psEngine);
 static void SetPSTransform(GpTransform *toPixels, int landscape);
 static void GetEPSFBox(int landscape, GpsBBox *bb,
-		  int *xll, int *yll, int *xur, int *yur);
+                  int *xll, int *yll, int *xur, int *yur);
 static int PutLine(PSEngine *psEngine);
 static int Append(PSEngine *psEngine, const char *s);
 static int BeginPage(PSEngine *psEngine);
@@ -47,7 +47,7 @@ static int EndClip(PSEngine *psEngine);
 static int BeginClip(PSEngine *psEngine, GpTransform *trans);
 static int EndPage(PSEngine *psEngine);
 static int PutPoints(PSEngine *psEngine, GpPoint *points, long nPoints,
-		     int margin);
+                     int margin);
 static int ChangePalette(Engine *engine);
 static void Kill(Engine *engine);
 static int Clear(Engine *engine, int always);
@@ -56,24 +56,35 @@ static int SetupColor(PSEngine *psEngine, unsigned long color);
 static int SetupLine(PSEngine *psEngine, GpLineAttribs *gistAl);
 static int CheckClip(PSEngine *psEngine);
 static int DrawLines(Engine *engine, long n, const GpReal *px,
-		     const GpReal *py, int closed, int smooth);
+                     const GpReal *py, int closed, int smooth);
 static int SetupFont(PSEngine *psEngine, GpReal height);
 static int DrawMarkers(Engine *engine, long n, const GpReal *px,
-		       const GpReal *py);
+                       const GpReal *py);
 static int SetupText(PSEngine *psEngine);
 static int DrwText(Engine *engine, GpReal x0, GpReal y0, const char *text);
 static int DrawFill(Engine *engine, long n, const GpReal *px,
-		    const GpReal *py);
+                    const GpReal *py);
 static int DrawCells(Engine *engine, GpReal px, GpReal py, GpReal qx,
-		     GpReal qy, long width, long height, long nColumns,
-		     const GpColor *colors);
+                     GpReal qy, long width, long height, long nColumns,
+                     const GpColor *colors);
 static int DrawDisjoint(Engine *engine, long n, const GpReal *px,
-			const GpReal *py, const GpReal *qx, const GpReal *qy);
+                        const GpReal *py, const GpReal *qx, const GpReal *qy);
+
+static int ps_fputs(p_file *file, char *buf);
 
 /* ------------------------------------------------------------------------ */
 
 static const char *titleIs;
 static int needUser, needDate;
+static void *pf_stdout = &needUser;  /* any non-zero address will do */
+
+static int
+ps_fputs(p_file *file, char *buf)
+{
+  if (file != pf_stdout) return p_fputs(file, buf);
+  if (g_stdout) g_stdout(buf);
+  return 0;
+}
 
 static int PutPrologLine(p_file *file)
 {
@@ -98,13 +109,13 @@ static int PutPrologLine(p_file *file)
     strcat(line, st? st : "\n");
     needDate= 0;
   }
-  return p_fputs(file, line);
+  return ps_fputs(file, line);
 }
 
 static p_file *CopyProlog(const char *name, const char *title)
 {
   p_file *psps= GistOpen("ps.ps");
-  p_file *file= strcmp(name, "*stdout*")? CREATE_PS(name) : 0;
+  p_file *file= strcmp(name, "*stdout*")? CREATE_PS(name) : pf_stdout;
   if (!psps) strcpy(gistError, "unable to open PostScript prolog ps.ps");
   if (!file) strcpy(gistError, "unable to create PostScript output file");
 
@@ -113,16 +124,16 @@ static p_file *CopyProlog(const char *name, const char *title)
     needUser= needDate= 1;
     for (;;) {
       if (!p_fgets(psps, line, 79) || PutPrologLine(file)<0) {
-	p_fclose(file);
-	file= 0;
-	strcpy(gistError, "bad PostScript prolog format in ps.ps??");
-	break;
+        if (file!=pf_stdout) p_fclose(file);
+        file= 0;
+        strcpy(gistError, "bad PostScript prolog format in ps.ps??");
+        break;
       }
       if (strncmp(line, "%%EndSetup", 10L)==0) break;
     }
 
   } else if (file) {
-    p_fclose(file);
+    if (file!=pf_stdout) p_fclose(file);
     file= 0;
   }
 
@@ -140,7 +151,7 @@ static void SetPageDefaults(PSEngine *psEngine)
 {
   /* Set current state to match state set by GI procedure in ps.ps */
   psEngine->curClip= 0;
-  psEngine->curColor= FG_COLOR;
+  psEngine->curColor= P_FG;
   psEngine->curType= L_SOLID;
   psEngine->curWidth= 1.0;
   psEngine->curFont= T_COURIER;
@@ -168,7 +179,7 @@ static void SetPSTransform(GpTransform *toPixels, int landscape)
 }
 
 static void GetEPSFBox(int landscape, GpsBBox *bb,
-		  int *xll, int *yll, int *xur, int *yur)
+                       int *xll, int *yll, int *xur, int *yur)
 {
   /* Transform bounding box to
      Document Structure Comment coordinates for use as EPSF file */
@@ -214,8 +225,8 @@ static int PutLine(PSEngine *psEngine)
 
   line[nchars++]= '\n';
   line[nchars]= '\0';
-  if (p_fputs(file, line)<0) {
-    p_fclose(file);
+  if (ps_fputs(file, line)<0) {
+    if (file!=pf_stdout) p_fclose(file);
     psEngine->file= 0;
     psEngine->closed= 1;
     strcpy(gistError, "p_fputs failed writing PostScript file");
@@ -275,7 +286,7 @@ static int BeginPage(PSEngine *psEngine)
   }
   if (psEngine->landscape) {
     if (Append(psEngine, "LAND") ||
-	PutLine(psEngine)) return 1;
+        PutLine(psEngine)) return 1;
   }
 
   if (psEngine->e.colorMode && psEngine->e.palette &&
@@ -308,7 +319,7 @@ static int EndClip(PSEngine *psEngine)
 {
   if (psEngine->curClip) {
     if ((psEngine->nchars && PutLine(psEngine)) ||
-	Append(psEngine, "CLOF")) return 1;
+        Append(psEngine, "CLOF")) return 1;
     psEngine->curClip= 0;
     /* Restore state at time of CLON */
     psEngine->curColor= psEngine->clipColor;
@@ -332,7 +343,7 @@ static int BeginClip(PSEngine *psEngine, GpTransform *trans)
 
   if (psEngine->curClip) {
     if (port->xmin==box->xmin && port->xmax==box->xmax &&
-	port->ymin==box->ymin && port->ymax==box->ymax) return 0;
+        port->ymin==box->ymin && port->ymax==box->ymax) return 0;
     if (EndClip(psEngine)) return 1;
   }
 
@@ -386,7 +397,7 @@ static int EndPage(PSEngine *psEngine)
   if (Append(psEngine, "%%PageTrailer") || PutLine(psEngine)) return 1;
 
   GetEPSFBox(psEngine->e.landscape, &psEngine->pageBB,
-	     &xll, &yll, &xur, &yur);
+             &xll, &yll, &xur, &yur);
   if (xll < psEngine->docBB.xll) psEngine->docBB.xll= xll;
   if (yll < psEngine->docBB.yll) psEngine->docBB.yll= yll;
   if (xur > psEngine->docBB.xur) psEngine->docBB.xur= xur;
@@ -397,14 +408,14 @@ static int EndPage(PSEngine *psEngine)
   psEngine->currentPage++;
   psEngine->e.marked= 0;
   SetPageDefaults(psEngine);
-  p_fflush(psEngine->file);
+  if (psEngine->file!=pf_stdout) p_fflush(psEngine->file);
   return 0;
 }
 
 static char hexChar[17]= "0123456789abcdef";
 
 static int PutPoints(PSEngine *psEngine, GpPoint *points, long nPoints,
-		     int margin)
+                     int margin)
 {
   int ix, iy, i;
   int xll= 0x7ff0, yll= 0x7ff0, xur= 0, yur= 0;
@@ -542,14 +553,14 @@ static void Kill(Engine *engine)
     strcpy(line, "%%DocumentFonts: ");
     for (i=0 ; i<N_PSFONTS ; i++) {
       if ((1<<i) & fonts) {
-	strcat(line, psFontNames[i]);
-	if (!bad) bad= Append(psEngine, line);
-	if (!bad) bad= PutLine(psEngine);
-	strcpy(line, "%%+ ");
+        strcat(line, psFontNames[i]);
+        if (!bad) bad= Append(psEngine, line);
+        if (!bad) bad= PutLine(psEngine);
+        strcpy(line, "%%+ ");
       }
     }
 
-    p_fclose(psEngine->file);
+    if (psEngine->file!=pf_stdout) p_fclose(psEngine->file);
   }
   GpDelEngine(engine);
 }
@@ -565,14 +576,16 @@ static int Clear(Engine *engine, int always)
 static int Flush(Engine *engine)
 {
   PSEngine *psEngine= (PSEngine *)engine;
-  if (psEngine->file) p_fflush(psEngine->file);
+  if (psEngine->file && psEngine->file!=pf_stdout)
+    p_fflush(psEngine->file);
   return 0;
 }
 
 /* ------------------------------------------------------------------------ */
 
-static char *colorCommands[10]= {
-  "BG", "FG", "BLK", "WHT", "RED", "GRN", "BLU", "CYA", "MAG", "YEL" };
+static char *colorCommands[14]= {
+  "BG", "FG", "BLK", "WHT", "RED", "GRN", "BLU", "CYA", "MAG", "YEL",
+  "GYD", "GYC", "GYB", "GYA" };
 
 static int SetupColor(PSEngine *psEngine, unsigned long color)
 {
@@ -601,7 +614,7 @@ static int SetupColor(PSEngine *psEngine, unsigned long color)
     if (Append(psEngine, line)) return 1;
   } else if (color<256UL) {
     /* standard color command FG, RED, etc. */
-    if (color<YELLOW_COLOR) color= FG_COLOR;
+    if (color<P_GRAYA) color= P_FG;
     if (Append(psEngine, colorCommands[255UL-color])) return 1;
   } else {
     sprintf(line, "16#%lx C", color);
@@ -652,7 +665,7 @@ static int CheckClip(PSEngine *psEngine)
 }
 
 static int DrawLines(Engine *engine, long n, const GpReal *px,
-		     const GpReal *py, int closed, int smooth)
+                     const GpReal *py, int closed, int smooth)
 {
   PSEngine *psEngine= (PSEngine *)engine;
   GpXYMap *map= &engine->map;
@@ -679,15 +692,15 @@ static int DrawLines(Engine *engine, long n, const GpReal *px,
   if (Append(psEngine, line) || PutLine(psEngine)) return 1;
 
   while ((nPoints=
-	  GpIntPoints(map, maxPoints, n, px, py, &points))) {
+          GpIntPoints(map, maxPoints, n, px, py, &points))) {
     if (closed) {
       if (firstPass) {
-	firstPoint= points[0];
-	firstPass= 0;
+        firstPoint= points[0];
+        firstPass= 0;
       }
       if (n==nPoints) {
-	n++;
-	points[nPoints++]= firstPoint;
+        n++;
+        points[nPoints++]= firstPoint;
       }
     }
     if (PutPoints(psEngine, points, nPoints, size)) return 1;
@@ -732,7 +745,7 @@ static int SetupFont(PSEngine *psEngine, GpReal height)
 }
 
 static int DrawMarkers(Engine *engine, long n, const GpReal *px,
-		       const GpReal *py)
+                       const GpReal *py)
 {
   PSEngine *psEngine= (PSEngine *)engine;
   GpXYMap *map= &engine->map;
@@ -775,7 +788,7 @@ static int DrawMarkers(Engine *engine, long n, const GpReal *px,
   if (Append(psEngine, line) || PutLine(psEngine)) return 1;
 
   while ((nPoints=
-	  GpIntPoints(map, maxPoints, n, px, py, &points))) {
+          GpIntPoints(map, maxPoints, n, px, py, &points))) {
     if (PutPoints(psEngine, points, nPoints, size)) return 1;
     if (n==nPoints) break;
     n-= nPoints;
@@ -841,6 +854,9 @@ static int DrwText(Engine *engine, GpReal x0, GpReal y0, const char *text)
   const char *t;
   int state= 0;
 
+  /* zero size text can confuse postscript interpreters */
+  if ((int)(gistA.t.height*NDC_TO_PS+0.5) <= 0) return 0;
+
   if (CheckClip(psEngine) || SetupText(psEngine)) return 1;
   alignH= psEngine->curAlignH;
   alignV= psEngine->curAlignV;
@@ -864,10 +880,10 @@ static int DrwText(Engine *engine, GpReal x0, GpReal y0, const char *text)
   else { ymin= wind->ymax; ymax= wind->ymin; }
   if (gistA.t.orient==TX_RIGHT || gistA.t.orient==TX_LEFT) {
     if (x0<xmin-width || x0>xmax+width ||
-	y0<ymin-height || y0>ymax+height) return 0;
+        y0<ymin-height || y0>ymax+height) return 0;
   } else {
     if (x0<xmin-height || x0>xmax+height ||
-	y0<ymin-width || y0>ymax+width) return 0;
+        y0<ymin-width || y0>ymax+width) return 0;
   }
 
   /* Adjust y0 (or x0) to represent topmost line */
@@ -953,90 +969,90 @@ static int DrwText(Engine *engine, GpReal x0, GpReal y0, const char *text)
 
       c= *text;
       if (c>=32 && c<127) {
-	if (gtDoEscapes) {
-	  if (c=='!' && count) {
-	    c= text[1];  /* peek at next char */
-	    if (c=='!' || c=='^' || c=='_') {
-	      count--;
-	      text++;
-	      goto normal;
-	    }
-	    if (nchars>68 &&
-		break_line_now(psEngine, &now, &nchars)) return 1;
-	    strcpy(now, "\\024");  /* DC4 is ps.ps escape char */
-	    now+= 4;
-	    nchars+= 4;
-	    psEngine->fonts|= (1<<T_SYMBOL);  /* symbol font used */
-	    if (c==']') {
-	      *now++= '^';         /* !] means ^ (perp) in symbol font */
-	      nchars++;
-	      text+= 2;
-	      count--;
-	      continue;
-	    }
-	    goto escape;
-	  } else if (c=='^') {
-	    if (state!=0) {
-	      /* terminate current super or subscript escape */
-	      strcpy(now, "\\021");  /* DC1 is ps.ps escape char */
-	      now+= 4;
-	      nchars+= 4;
-	    }
-	    if (state!=1) {
-	      /* intialize superscript escape */
-	      if (nchars>64 &&
-		  break_line_now(psEngine, &now, &nchars)) return 1;
-	      strcpy(now, "\\021\\022");  /* DC1DC2 is ps.ps escape seq */
-	      now+= 8;
-	      nchars+= 8;
-	      state= 1;
-	    } else {
-	      state= 0;
-	    }
-	    goto escape;
-	  } else if (c=='_') {
-	    if (state!=0) {
-	      /* terminate current super or subscript escape */
-	      if (nchars>68 &&
-		  break_line_now(psEngine, &now, &nchars)) return 1;
-	      strcpy(now, "\\021");  /* DC1 is ps.ps escape char */
-	      now+= 4;
-	      nchars+= 4;
-	    }
-	    if (state!=2) {
-	      /* intialize subscript escape */
-	      if (nchars>64 &&
-		  break_line_now(psEngine, &now, &nchars)) return 1;
-	      strcpy(now, "\\021\\023");  /* DC1DC3 is ps.ps escape seq */
-	      now+= 8;
-	      nchars+= 8;
-	      state= 2;
-	    } else {
-	      state= 0;
-	    }
-	    goto escape;
-	  }
-	}
-	/* ordinary printing character */
-	if (c=='(' || c==')' || c=='\\') {
-	  *now++= '\\';
-	  nchars++;
-	}
+        if (gtDoEscapes) {
+          if (c=='!' && count) {
+            c= text[1];  /* peek at next char */
+            if (c=='!' || c=='^' || c=='_') {
+              count--;
+              text++;
+              goto normal;
+            }
+            if (nchars>68 &&
+                break_line_now(psEngine, &now, &nchars)) return 1;
+            strcpy(now, "\\024");  /* DC4 is ps.ps escape char */
+            now+= 4;
+            nchars+= 4;
+            psEngine->fonts|= (1<<T_SYMBOL);  /* symbol font used */
+            if (c==']') {
+              *now++= '^';         /* !] means ^ (perp) in symbol font */
+              nchars++;
+              text+= 2;
+              count--;
+              continue;
+            }
+            goto escape;
+          } else if (c=='^') {
+            if (state!=0) {
+              /* terminate current super or subscript escape */
+              strcpy(now, "\\021");  /* DC1 is ps.ps escape char */
+              now+= 4;
+              nchars+= 4;
+            }
+            if (state!=1) {
+              /* intialize superscript escape */
+              if (nchars>64 &&
+                  break_line_now(psEngine, &now, &nchars)) return 1;
+              strcpy(now, "\\021\\022");  /* DC1DC2 is ps.ps escape seq */
+              now+= 8;
+              nchars+= 8;
+              state= 1;
+            } else {
+              state= 0;
+            }
+            goto escape;
+          } else if (c=='_') {
+            if (state!=0) {
+              /* terminate current super or subscript escape */
+              if (nchars>68 &&
+                  break_line_now(psEngine, &now, &nchars)) return 1;
+              strcpy(now, "\\021");  /* DC1 is ps.ps escape char */
+              now+= 4;
+              nchars+= 4;
+            }
+            if (state!=2) {
+              /* intialize subscript escape */
+              if (nchars>64 &&
+                  break_line_now(psEngine, &now, &nchars)) return 1;
+              strcpy(now, "\\021\\023");  /* DC1DC3 is ps.ps escape seq */
+              now+= 8;
+              nchars+= 8;
+              state= 2;
+            } else {
+              state= 0;
+            }
+            goto escape;
+          }
+        }
+        /* ordinary printing character */
+        if (c=='(' || c==')' || c=='\\') {
+          *now++= '\\';
+          nchars++;
+        }
       normal:
-	*now++= c;
-	nchars++;
+        *now++= c;
+        nchars++;
       } else {
-	/* non-printing characters rendered as \ooo */
-	if (c=='\t') {
-	  *now++= '\\';
-	  *now++= 't';
-	  nchars+= 2;
-	} else if (c<'\021' || c>'\024') {
-	  /* DC1 through DC4 have special meaning in ps.ps, skip them */
-	  sprintf(now, "\\%03o", (int)((unsigned char)c));
-	  now+= 4;
-	  nchars+= 4;
-	}
+        /* non-printing characters rendered as \ooo */
+        if (c=='\t') {
+          *now++= '\\';
+          *now++= 't';
+          nchars+= 2;
+        } else if (c<'\021' || c>'\024') {
+          /* DC1 through DC4 have special meaning in ps.ps, skip them */
+          sprintf(now, "\\%03o", (int)((unsigned char)c));
+          now+= 4;
+          nchars+= 4;
+        }
       }
     escape:
       text++;
@@ -1083,7 +1099,7 @@ static int break_line_now(PSEngine *psEngine, char **nw, int *nchs)
 /* ------------------------------------------------------------------------ */
 
 static int DrawFill(Engine *engine, long n, const GpReal *px,
-		    const GpReal *py)
+                    const GpReal *py)
 {
   PSEngine *psEngine= (PSEngine *)engine;
   GpXYMap *map= &engine->map;
@@ -1109,7 +1125,7 @@ static int DrawFill(Engine *engine, long n, const GpReal *px,
   if (Append(psEngine, line) || PutLine(psEngine)) return 1;
 
   while ((nPoints=
-	  GpIntPoints(map, maxPoints, n, px, py, &points))) {
+          GpIntPoints(map, maxPoints, n, px, py, &points))) {
     if (PutPoints(psEngine, points, nPoints, 0)) return 1;
     if (n==nPoints) break;
     n-= nPoints;
@@ -1133,8 +1149,8 @@ static int DrawFill(Engine *engine, long n, const GpReal *px,
 /* ------------------------------------------------------------------------ */
 
 static int DrawCells(Engine *engine, GpReal px, GpReal py, GpReal qx,
-		     GpReal qy, long width, long height, long nColumns,
-		     const GpColor *colors)
+                     GpReal qy, long width, long height, long nColumns,
+                     const GpColor *colors)
 {
   PSEngine *psEngine= (PSEngine *)engine;
   GpXYMap *map= &psEngine->e.map;
@@ -1254,10 +1270,10 @@ static int DrawCells(Engine *engine, GpReal px, GpReal py, GpReal qx,
   while (nLines--) {
     for (nc=0 ; nc<ncmax ; ) {
       if (i>=width) {
-	height--;
-	if (height<=0) break;
-	i= 0;
-	j+= nColumns;
+        height--;
+        if (height<=0) break;
+        i= 0;
+        j+= nColumns;
       }
       if (gistA.rgb) {
         const GpColor *ccell = &colors[3*(i+j)];
@@ -1296,7 +1312,7 @@ static int DrawCells(Engine *engine, GpReal px, GpReal py, GpReal qx,
 /* ------------------------------------------------------------------------ */
 
 static int DrawDisjoint(Engine *engine, long n, const GpReal *px,
-			const GpReal *py, const GpReal *qx, const GpReal *qy)
+                        const GpReal *py, const GpReal *qx, const GpReal *qy)
 {
   PSEngine *psEngine= (PSEngine *)engine;
   GpXYMap *map= &engine->map;
@@ -1321,7 +1337,7 @@ static int DrawDisjoint(Engine *engine, long n, const GpReal *px,
   if (Append(psEngine, line) || PutLine(psEngine)) return 1;
 
   while ((nSegs=
-	  GpIntSegs(map, maxSegs, n, px, py, qx, qy, &segs))) {
+          GpIntSegs(map, maxSegs, n, px, py, qx, qy, &segs))) {
     /* This cast from GpPoint to GpSegment is lazy programming,
        but I don't know of any platforms it will not work on... */
     if (PutPoints(psEngine, (GpPoint *)segs, 2*nSegs, size)) return 1;
@@ -1354,11 +1370,11 @@ Engine *GpPSEngine(char *name, int landscape, int mode, char *file)
   SetPSTransform(&toPixels, landscape);
 
   psEngine=
-    (PSEngine *)GpNewEngine(engineSize, name, psType, &toPixels, landscape,
-			    &Kill, &Clear, &Flush, &GpComposeMap,
-			    &ChangePalette, &DrawLines, &DrawMarkers,
-			    &DrwText, &DrawFill, &DrawCells,
-			    &DrawDisjoint);
+    (PSEngine *)GpNewEngine(engineSize, name, &g_ps_on, &toPixels, landscape,
+                            &Kill, &Clear, &Flush, &GpComposeMap,
+                            &ChangePalette, &DrawLines, &DrawMarkers,
+                            &DrwText, &DrawFill, &DrawCells,
+                            &DrawDisjoint);
 
   if (!psEngine) {
     strcpy(gistError, "memory manager failed in GpPSEngine");
@@ -1398,7 +1414,7 @@ Engine *GpPSEngine(char *name, int landscape, int mode, char *file)
 
 PSEngine *GisPSEngine(Engine *engine)
 {
-  return (engine && engine->type==psType)? (PSEngine *)engine : 0;
+  return (engine && engine->on==&g_ps_on)? (PSEngine *)engine : 0;
 }
 
 /* ------------------------------------------------------------------------ */
