@@ -15,7 +15,19 @@
 
 #include <string.h>
 
-static char *xType= "PLAY Window";
+static void g_on_expose(void *c, int *xy);
+static void g_on_destroy(void *c);
+static void g_on_resize(void *c,int w,int h);
+static void g_on_focus(void *c,int in);
+static void g_on_key(void *c,int k,int md);
+static void g_on_click(void *c,int b,int md,int x,int y, unsigned long ms);
+static void g_on_motion(void *c,int md,int x,int y);
+static void g_on_deselect(void *c);
+static void g_on_panic(p_scr *screen);
+
+static g_callbacks g_x_on = {
+  "gist XEngine", g_on_expose, g_on_destroy, g_on_resize, g_on_focus,
+  g_on_key, g_on_click, g_on_motion, g_on_deselect };
 
 static int ChangePalette(Engine *engine);
 static GpReal TextWidth(const char *text, int nc, const GpTextAttribs *t);
@@ -33,22 +45,22 @@ static void ChangeMap(Engine *engine);
 static void chk_clipping(XEngine *xeng);
 static int SetupLine(XEngine *xeng, GpLineAttribs *gistAl, int join);
 static int DrawLines(Engine *engine, long n, const GpReal *px,
-		     const GpReal *py, int closed, int smooth);
+                     const GpReal *py, int closed, int smooth);
 static int DrawMarkers(Engine *engine, long n, const GpReal *px,
-		       const GpReal *py);
+                       const GpReal *py);
 static int DrwText(Engine *engine, GpReal x0, GpReal y0, const char *text);
 static int DrawFill(Engine *engine, long n, const GpReal *px,
-		    const GpReal *py);
+                    const GpReal *py);
 static int GetCells(GpMap *map, GpReal xmin, GpReal xmax,
                     GpReal px, GpReal qx, long width,
                     int *i0, int *di, int *ncols, int *x0, int *x1);
 static int DrawCells(Engine *engine, GpReal px, GpReal py, GpReal qx,
-		     GpReal qy, long width, long height, long nColumns,
-		     const GpColor *colors);
+                     GpReal qy, long width, long height, long nColumns,
+                     const GpColor *colors);
 static int DrawDisjoint(Engine *engine, long n, const GpReal *px,
-			const GpReal *py, const GpReal *qx, const GpReal *qy);
+                        const GpReal *py, const GpReal *qx, const GpReal *qy);
 static void GetVisibleNDC(XEngine *xeng,
-			  GpReal *xn, GpReal *xx, GpReal *yn, GpReal *yx);
+                          GpReal *xn, GpReal *xx, GpReal *yn, GpReal *yx);
 
 /* Hook for hlevel.c error handling.  */
 extern void (*HLevelHook)(Engine *engine);
@@ -117,31 +129,31 @@ TextWidth(const char *text, int nc, const GpTextAttribs *t)
     for ( ; nc-- ; text++) {
       c= text[0];
       if ((nc && c=='!') || c=='^' || c=='_') {
-	if (txt<text)
+        if (txt<text)
           width += p_txwidth(current_scr, txt, (int)(text-txt),
                              gistA.t.font, current_fsize);
-	if (firstChunk) {
-	  nChunk= (int)(text-txt);
-	  chunkWidth= width;
-	  firstChunk= 0;
-	}
-	txt= text+1;
-	if (c=='!') {
-	  /* process single character escapes immediately */
-	  text= txt;
-	  nc--;
-	  c= txt[0];
-	  if (c!='!' && c!='^' && c!='_') {
-	    if (c==']') c= '^';
+        if (firstChunk) {
+          nChunk= (int)(text-txt);
+          chunkWidth= width;
+          firstChunk= 0;
+        }
+        txt= text+1;
+        if (c=='!') {
+          /* process single character escapes immediately */
+          text= txt;
+          nc--;
+          c= txt[0];
+          if (c!='!' && c!='^' && c!='_') {
+            if (c==']') c= '^';
             width += p_txwidth(current_scr, &c, 1,
                                current_fsym, current_fsize);
-	    txt++;
-	  }
-	} else if (c=='^') {
-	  supersub|= 1;
-	} else {
-	  supersub|= 2;
-	}
+            txt++;
+          }
+        } else if (c=='^') {
+          supersub|= 1;
+        } else {
+          supersub|= 2;
+        }
       }
     }
     if (txt<text)
@@ -286,8 +298,8 @@ GxJustifyNext(const char **text, int *ix, int *iy)
     /* scan for end of first chunk */
     if (gtDoEscapes) {
       for (nChunk=0 ; nChunk<nChars ; nChunk++) {
-	c= txt[nChunk];
-	if ((nChunk+1<nChars && c=='!') || c=='^' || c=='_') break;
+        c= txt[nChunk];
+        if ((nChunk+1<nChars && c=='!') || c=='^' || c=='_') break;
       }
     } else {
       nChunk= nChars;
@@ -337,52 +349,52 @@ GxJustifyNext(const char **text, int *ix, int *iy)
       nChunk= 1;
       c= txt[0];
       if (c=='!' || c=='^' || c=='_') {
-	/* chunk is just ordinary text */
-	for ( ; nChunk<nChars ; nChunk++) {
-	  c= txt[nChunk];
-	  if ((nChunk+1<nChars && c=='!') || c=='^' || c=='_') break;
-	}
+        /* chunk is just ordinary text */
+        for ( ; nChunk<nChars ; nChunk++) {
+          c= txt[nChunk];
+          if ((nChunk+1<nChars && c=='!') || c=='^' || c=='_') break;
+        }
         p_font(current_win, gistA.t.font, current_fsize, gistA.t.orient);
-	current_state&= 3;
+        current_state&= 3;
       } else {
-	/* chunk is single symbol char */
+        /* chunk is single symbol char */
         p_font(current_win, current_fsym, current_fsize, gistA.t.orient);
-	current_state|= 4;
+        current_state|= 4;
       }
 
     } else {
       for (nChunk=0 ; nChunk<nChars ; nChunk++) {
-	c= txt[nChunk];
-	if ((nChunk+1<nChars && c=='!') || c=='^' || c=='_') break;
+        c= txt[nChunk];
+        if ((nChunk+1<nChars && c=='!') || c=='^' || c=='_') break;
       }
       if (nChunk)
         p_font(current_win, gistA.t.font, current_fsize, gistA.t.orient);
       if (c1=='^') {
-	if (current_state&1) {
-	  yadj+= dy_super;  /* return from super to normal */
-	  current_state= 0;
-	} else {
-	  if (current_state&2) yadj-= dy_sub;
-	  yadj-= dy_super;  /* move to superscript */
-	  current_state= 1;
-	}
+        if (current_state&1) {
+          yadj+= dy_super;  /* return from super to normal */
+          current_state= 0;
+        } else {
+          if (current_state&2) yadj-= dy_sub;
+          yadj-= dy_super;  /* move to superscript */
+          current_state= 1;
+        }
       } else if (c1=='_') {
-	if (current_state&2) {
-	  yadj-= dy_sub;  /* return from sub to normal */
-	  current_state= 0;
-	} else {
-	  if (current_state&1) yadj+= dy_super;
-	  yadj+= dy_sub;  /* move to subscript */
-	  current_state= 2;
-	}
+        if (current_state&2) {
+          yadj-= dy_sub;  /* return from sub to normal */
+          current_state= 0;
+        } else {
+          if (current_state&1) yadj+= dy_super;
+          yadj+= dy_sub;  /* move to subscript */
+          current_state= 2;
+        }
       } else {
-	/* just finished a symbol char */
-	current_state&= 3;
+        /* just finished a symbol char */
+        current_state&= 3;
       }
     }
 
     if (nChunk &&
-	(nChunk<nChars || alignH!=TH_LEFT || gistA.t.orient!=TX_RIGHT)) {
+        (nChunk<nChars || alignH!=TH_LEFT || gistA.t.orient!=TX_RIGHT)) {
       char caret= '^';
       if (nChunk==1 && (current_state&4) && txt[0]==']') txt= &caret;
       chunkWidth = p_txwidth(current_scr, txt, nChunk,
@@ -430,17 +442,9 @@ GxJustifyNext(const char **text, int *ix, int *iy)
  *       the g_on_destroy() in the event-driven case
  *       -- thus, the p_disconnect must take place on the next
  *          event, which is during the GhBeforeWait hlevel.c function
- *       -- unfortunately, in the meantime, a new window could
- *          have been created on that screen,
- *          hence the g_test_pending() routine
- *       -- the mess is further compounded by the fact that there
- *          could be an unlimited number of different screens with
- *          pending disconnections, after the 4th one, the current
- *          code simply gives up and forgets about disconnecting
  */
 extern void (*g_pending_task)(void);
 void (*g_pending_task)(void) = 0;
-static void g_test_pending(p_scr *s);
 
 static void
 Kill(Engine *engine)
@@ -1030,21 +1034,9 @@ DrawDisjoint(Engine *engine, long n, const GpReal *px,
 
 /* ------------------------------------------------------------------------ */
 
-static void g_on_expose(void *c, int *xy);
-static void g_on_destroy(void *c);
-static void g_on_resize(void *c,int w,int h);
-static void g_on_focus(void *c,int in);
-static void g_on_key(void *c,int k,int md);
-static void g_on_click(void *c,int b,int md,int x,int y, unsigned long ms);
-static void g_on_motion(void *c,int md,int x,int y);
-static void g_on_deselect(void *c);
-static void g_on_panic(p_scr *screen);
-
 static Engine *waiting_for = 0;
 static void (*wait_callback)(void) = 0;
 
-extern int gist_expose_wait(Engine *eng, void (*e_callback)(void));
-
 int
 gist_expose_wait(Engine *eng, void (*e_callback)(void))
 {
@@ -1053,6 +1045,9 @@ gist_expose_wait(Engine *eng, void (*e_callback)(void))
     wait_callback = 0;
     return 1;
   } else {
+    XEngine *xeng = GisXEngine(eng);
+    if (!xeng || !xeng->w) return 1;
+    if (xeng->mapped) return 2;
     waiting_for = eng;
     wait_callback = e_callback;
     return 0;
@@ -1063,71 +1058,104 @@ static void
 g_on_expose(void *c, int *xy)
 {
   XEngine *xeng = c;
-  if (c && c == waiting_for) {
-    waiting_for = 0;
-    if (wait_callback) wait_callback();
-    wait_callback = 0;
+  if (xeng->e.on==&g_x_on) {
+    if (c && c == waiting_for) {
+      waiting_for = 0;
+      if (wait_callback) wait_callback();
+      wait_callback = 0;
+    }
+    if (!xeng->w) return;
+    xeng->mapped = 1;
+    if (xeng->HandleExpose)
+      /* the alternate handler should probably call GxExpose */
+      xeng->HandleExpose(&xeng->e, xeng->e.drawing, xy);
+    else
+      GxExpose(&xeng->e, xeng->e.drawing, xy);
+  } else if (xeng->e.on && xeng->e.on->expose) {
+    xeng->e.on->expose(c, xy);
   }
-  if (!xeng->w) return;
-  xeng->mapped = 1;
-  if (xeng->HandleExpose)
-    /* the alternate handler should probably call GxExpose */
-    xeng->HandleExpose(&xeng->e, xeng->e.drawing, xy);
-  else
-    GxExpose(&xeng->e, xeng->e.drawing, xy);
 }
 
 static void
 g_on_click(void *c,int b,int md,int x,int y, unsigned long ms)
 {
   XEngine *xeng = c;
-  if (!xeng->w) return;
-  if (xeng->HandleClick)
-    xeng->HandleClick(&xeng->e, b, md, x, y, ms);
+  if (xeng->e.on==&g_x_on) {
+    if (!xeng->w) return;
+    if (xeng->HandleClick)
+      xeng->HandleClick(&xeng->e, b, md, x, y, ms);
+  } else if (xeng->e.on && xeng->e.on->click) {
+    xeng->e.on->click(c, b, md, x, y, ms);
+  }
 }
 
 static void
 g_on_motion(void *c,int md,int x,int y)
 {
   XEngine *xeng = c;
-  if (!xeng->w) return;
-  if (xeng->HandleMotion)
-    xeng->HandleMotion(&xeng->e, md, x, y);
+  if (xeng->e.on==&g_x_on) {
+    if (!xeng->w) return;
+    if (xeng->HandleMotion)
+      xeng->HandleMotion(&xeng->e, md, x, y);
+  } else if (xeng->e.on && xeng->e.on->motion) {
+    xeng->e.on->motion(c, md, x, y);
+  }
 }
 
 static void
 g_on_destroy(void *c)
 {
   XEngine *xeng = c;
-  /* if xeng->win==0, assume ShutDown already called */
-  if (xeng->win) ShutDown(xeng);
+  if (xeng->e.on==&g_x_on) {
+    /* if xeng->win==0, assume ShutDown already called */
+    if (xeng->win) ShutDown(xeng);
+  } else if (xeng->e.on && xeng->e.on->destroy) {
+    xeng->e.on->destroy(c);
+  }
 }
 
 static void
 g_on_resize(void *c,int w,int h)
 {
   XEngine *xeng = c;
-  if (xeng->w) GxRecenter(xeng, w, h);
+  if (xeng->e.on==&g_x_on) {
+    if (xeng->w) GxRecenter(xeng, w, h);
+  } else if (xeng->e.on && xeng->e.on->resize) {
+    xeng->e.on->resize(c, w, h);
+  }
 }
 
 static void
 g_on_focus(void *c,int in)
 {
   XEngine *xeng = c;
-  if (xeng->w && xeng->HandleMotion && in==2)
-    xeng->HandleMotion(&xeng->e, 0, -1, -1);
+  if (xeng->e.on==&g_x_on) {
+    if (xeng->w && xeng->HandleMotion && in==2)
+      xeng->HandleMotion(&xeng->e, 0, -1, -1);
+  } else if (xeng->e.on && xeng->e.on->focus) {
+    xeng->e.on->focus(c, in);
+  }
 }
 
 static void
 g_on_key(void *c,int k,int md)
 {
   XEngine *xeng = c;
-  if (xeng->w && xeng->HandleKey)
-    xeng->HandleKey(&xeng->e, k, md);
+  if (xeng->e.on==&g_x_on) {
+    if (xeng->w && xeng->HandleKey)
+      xeng->HandleKey(&xeng->e, k, md);
+  } else if (xeng->e.on && xeng->e.on->key) {
+    xeng->e.on->key(c, k , md);
+  }
 }
 
 static void g_on_deselect(void *c)
 {
+  XEngine *xeng = c;
+  if (xeng->e.on==&g_x_on) {
+  } else if (xeng->e.on && xeng->e.on->deselect) {
+    xeng->e.on->deselect(c);
+  }
 }
 
 void
@@ -1262,7 +1290,6 @@ g_connect(char *displayName)
     if (i0<0) s = p_connect(displayName);
     else s = p_multihead(g_screens[i0].s, number);
     if (!s) return s;
-    g_test_pending(s);
     for (i=0 ; i<n_screens ; i++) if (!g_screens[i].s) break;
     if (i==n_screens && !(i & (i-1))) {
       int n = i? 2*i : 1;
@@ -1277,6 +1304,9 @@ g_connect(char *displayName)
   return s;
 }
 
+/* hack to disconnect if last engine destroyed (see GhBeforeWait) */
+static void g_do_disconnect(void);
+
 void
 g_disconnect(p_scr *s)
 {
@@ -1292,6 +1322,8 @@ g_disconnect(p_scr *s)
       }
     }
     p_disconnect(s);
+  } else {
+    g_do_disconnect();
   }
 }
 
@@ -1327,11 +1359,11 @@ GxEngine(p_scr *s, char *name, GpTransform *toPixels,
   gx_translate(&toPixels->window, x+leftMargin, y+topMargin);
 
   xEngine =
-    (XEngine *)GpNewEngine(engineSize, name, xType, toPixels, width>height,
-			   &Kill, &Clear, &Flush, &ChangeMap,
-			   &ChangePalette, &DrawLines, &DrawMarkers,
-			   &DrwText, &DrawFill, &DrawCells,
-			   &DrawDisjoint);
+    (XEngine *)GpNewEngine(engineSize, name, &g_x_on, toPixels, width>height,
+                           &Kill, &Clear, &Flush, &ChangeMap,
+                           &ChangePalette, &DrawLines, &DrawMarkers,
+                           &DrwText, &DrawFill, &DrawCells,
+                           &DrawDisjoint);
   if (!xEngine) {
     strcpy(gistError, "memory manager failed in GxEngine");
     return 0;
@@ -1433,7 +1465,7 @@ GxInput(Engine *engine,
 XEngine *
 GisXEngine(Engine *engine)
 {
-  return (engine && engine->type==xType)? (XEngine *)engine : 0;
+  return (engine && engine->on==&g_x_on)? (XEngine *)engine : 0;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1590,39 +1622,20 @@ GxDirect(Engine *engine)
 
 void (*HLevelHook)(Engine *engine)= 0;
 
-/* hack to disconnect if last engine destroyed (see GhBeforeWait) */
-#define G_N_PENDING 4
-static p_scr *g_pending_scr[G_N_PENDING];
-static void g_do_disconnect(void);
 static void
 g_do_disconnect(void)
 {
-  p_scr *s;
-  int i;
-  for (i=0 ; i<=G_N_PENDING ; i++) {
-    s = g_pending_scr[i];
-    g_pending_scr[i] = 0;
-    if (s) g_disconnect(s);
+  if (g_screens) {
+    p_scr *s;
+    int i;
+    for (i=n_screens-1 ; i>=0 ; i--) {
+      s = g_screens[i].s;
+      if (s && !p_wincount(s)) g_disconnect(s);
+    }
   }
   g_pending_task = 0;
 }
 
-static void
-g_test_pending(p_scr *s)
-{
-  int i;
-  if (g_pending_task == g_do_disconnect) {
-    for (i=0 ; i<=G_N_PENDING ; i++)
-      if (g_pending_scr[i] == s) {
-        g_pending_scr[i] = 0;
-        break;
-      }
-  } else {
-    g_pending_task = 0;
-    for (i=0 ; i<=G_N_PENDING ; i++) g_pending_scr[i] = 0;
-  }
-}
-
 static void
 ShutDown(XEngine *xeng)
 {
@@ -1630,35 +1643,18 @@ ShutDown(XEngine *xeng)
   p_win *w = xeng->w;
   p_win *win = xeng->win;
   xeng->mapped= 0;
+  /* turn off all event callbacks (probably unnecessary) */
+  xeng->e.on = 0;
   /* destroy any hlevel references without further ado */
   if (HLevelHook) HLevelHook((Engine *)xeng);
   xeng->w = xeng->win = 0;
   xeng->s = 0;
+  /* note that p_destroy and GpDelEngine call on_destroy in Windows */
   if (w && w!=win) p_destroy(w);
   GpDelEngine(&xeng->e);
   if (s) {
-    Engine *eng;
-    XEngine *xe2;
-    for (eng=GpNextEngine(0) ; eng ; eng=GpNextEngine(eng)) {
-      xe2 = GisXEngine(eng);
-      if (xe2 && xe2->s==s) break;
-    }
-    if (!eng) {
-      int i;
-      if (g_pending_task == g_do_disconnect) {
-        for (i=0 ; i<=G_N_PENDING ; i++)
-          if (g_pending_scr[i] == s) break;
-        if (i >= G_N_PENDING) {
-          for (i=0 ; i<=G_N_PENDING ; i++)
-            if (!g_pending_scr[i]) break;
-          if (i < G_N_PENDING) g_pending_scr[i] = s;
-        }
-      } else {
-        g_pending_scr[0] = s;
-        for (i=1 ; i<=G_N_PENDING ; i++) g_pending_scr[i] = 0;
-        g_pending_task = g_do_disconnect;
-      }
-    }
+    if (!p_wincount(s))
+      g_pending_task = g_do_disconnect;
   }
 }
 
