@@ -10,37 +10,28 @@
 
 /*-----prototypes of functions defined here-----*/
 extern void dlacon( long n, double v[], double x[], long isgn[],
-		   double *est, long *kase );
+                   double *est, long *kase );
 extern void dlamc5( long beta, long p, long emin, int ieee,
-		   long *emax, double *rmax );
+                   long *emax, double *rmax );
 extern void dlamc4( long *emin, double start, long base );
 extern double   dlamc3( double a, double b );
 extern void dlamc2( long *beta, long *t, int *rnd, double *eps,
-		   long *emin, double *rmin, long *emax, double *rmax );
+                   long *emin, double *rmin, long *emax, double *rmax );
 extern void dlamc1( long *beta, long *t, int *rnd, int *ieee1 );
 extern double   dlamch( char cmach );
 extern void dlatrs( char uplo, char trans, char diag, char normin, long n,
-		   double a[], long lda, double x[], double *scale,
-		   double cnorm[], long *info );
+                   double a[], long lda, double x[], double *scale,
+                   double cnorm[], long *info );
 extern void dlabad( double *small, double *large );
 extern void drscl( long n, double sa, double sx[], long incx );
 extern void dgecon( char norm, long n, double a[], long lda, double anorm,
-		   double *rcond, double work[], long iwork[],long *info );
+                   double *rcond, double work[], long iwork[],long *info );
 /*-----end of prototypes-----*/
 
 
 
 /*---blas routines---*/
-extern void  ydcopy(long n,double dx[],long incx,double dy[],long incy);
-extern double   ydasum(long n,double dx[],long incx);
-extern long  yidamax(long n,double dx[],long incx);
-extern void ydaxpy(long n,double da,double dx[],long incx,
-		  double dy[],long incy);
-extern void  ydscal(long n,double da,double dx[],long incx);
-extern void ydtrsv ( char uplo, char trans, char diag, long n,
-		   double a[], long lda, double x[], long incx );
-extern double   yddot(long n,double dx[],long incx,double dy[],long incy);
-extern void  ydscal(long n,double da,double dx[],long incx);
+/* ddot dcopy dasum idamax daxpy dscal dtrsv */
 
 
 
@@ -68,7 +59,7 @@ extern double log10(double);
 
 
 void dgecon( char norm, long n, double a[], long lda, double anorm,
-	    double *rcond, double work[], long iwork[],long *info )
+            double *rcond, double work[], long iwork[],long *info )
 {
   /**
    *  -- LAPACK routine (version 1.1) --
@@ -206,23 +197,23 @@ void dgecon( char norm, long n, double a[], long lda, double anorm,
        *           Multiply by inv(L).
        **/
       dlatrs( 'l'/*ower*/, 'n'/*o transpose*/, 'u'/*nit*/, normin, n, a,
-	     lda, work, &sl, &work_1( 2*n+1 ), info );
+             lda, work, &sl, &work_1( 2*n+1 ), info );
       /**
        *           Multiply by inv(U).
        **/
       dlatrs( 'u'/*pper*/, 'n'/*o transpose*/, 'n'/*on-unit*/, normin, n,
-	     a, lda, work, &su, &work_1( 3*n+1 ), info );
+             a, lda, work, &su, &work_1( 3*n+1 ), info );
     } else {
       /**
        *           Multiply by inv(U').
        **/
       dlatrs( 'u'/*pper*/, 't'/*ranspose*/, 'n'/*on-unit*/, normin, n, a,
-	     lda, work, &su, &work_1( 3*n+1 ), info );
+             lda, work, &su, &work_1( 3*n+1 ), info );
       /**
        *           Multiply by inv(L').
        **/
       dlatrs( 'l'/*ower*/, 't'/*ranspose*/, 'u'/*nit*/, normin, n, a,
-	     lda, work, &sl, &work_1( 2*n+1 ), info );
+             lda, work, &sl, &work_1( 2*n+1 ), info );
     }
     /**
      *        Divide X by 1/(SL*SU) if doing so will not cause overflow.
@@ -230,9 +221,9 @@ void dgecon( char norm, long n, double a[], long lda, double anorm,
     scale = sl*su;
     normin = 'y';
     if( scale!=one ) {
-      ix = yidamax( n, work, 1 );
+      ix = 1+cblas_idamax( n, work, 1 );
       if( scale<abs( work_1( ix ) )*smlnum || scale==zero )
-	goto L_20;
+        goto L_20;
       drscl( n, scale, work, 1 );
     }
     goto L_10;
@@ -355,7 +346,7 @@ void drscl( long n, double sa, double sx[], long incx )
   /**
    *     Scale the vector X by MUL
    **/
-  ydscal( n, mul, sx, incx );
+  cblas_dscal( n, mul, sx, incx );
 
   if( !done )
     goto L_10;
@@ -430,8 +421,8 @@ void dlabad( double *small, double *large )
 
 
 void dlatrs( char uplo, char trans, char diag, char normin, long n,
-	    double a[], long lda, double x[], double *scale,
-	    double cnorm[], long *info )
+            double a[], long lda, double x[], double *scale,
+            double cnorm[], long *info )
 {
   /**
    *  -- LAPACK auxiliary routine (version 1.1) --
@@ -462,7 +453,7 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
    *  n-element vectors, and s is a scaling factor, usually less than
    *  or equal to 1, chosen so that the components of x will be less than
    *  the overflow threshold.  If the unscaled problem will not cause
-   *  overflow, the Level 2 BLAS routine YDTRSV is called.  If the matrix A
+   *  overflow, the Level 2 BLAS routine DTRSV is called.  If the matrix A
    *  is singular (A_2(j,j) = 0 for some j), then s is set to 0 and a
    *  non-trivial solution to A*x = 0 is returned.
    *
@@ -536,7 +527,7 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
    *  Further Details
    *  ======= =======
    *
-   *  A rough bound on x is computed; if that is less than overflow, YDTRSV
+   *  A rough bound on x is computed; if that is less than overflow, DTRSV
    *  is called, otherwise, specific code is used which checks for possible
    *  overflow or divide-by-zero at every operation.
    *
@@ -569,7 +560,7 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
    *     |x_1(j)| <= ( G(0) / |A_2(j,j)| ) product ( 1 + CNORM_1(i) / |A_2(i,i)| )
    *                                   1<=i< j
    *
-   *  Since |x_1(j)| <= M(j), we use the Level 2 BLAS routine YDTRSV if the
+   *  Since |x_1(j)| <= M(j), we use the Level 2 BLAS routine DTRSV if the
    *  reciprocal of the largest M(j), j=1,..,n, is larger than
    *  max(underflow, 1/overflow).
    *
@@ -599,7 +590,7 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
    *            <= M(0) * product ( ( 1 + CNORM_1(i) ) / |A_2(i,i)| )
    *                      1<=i<=j
    *
-   *  and we can safely call YDTRSV if 1/M(n) and 1/G(n) are both greater
+   *  and we can safely call DTRSV if 1/M(n) and 1/G(n) are both greater
    *  than max(underflow, 1/overflow).
    *
    *  =====================================================================
@@ -635,12 +626,12 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
   if( !upper && !lsame( uplo, 'l' ) ) {
     *info = -1;
   } else if( !notran && !lsame( trans, 't' ) && !
-	    lsame( trans, 'c' ) ) {
+            lsame( trans, 'c' ) ) {
     *info = -2;
   } else if( !nounit && !lsame( diag, 'u' ) ) {
     *info = -3;
   } else if( !lsame( normin, 'y' ) && !
-	    lsame( normin, 'n' ) ) {
+            lsame( normin, 'n' ) ) {
     *info = -4;
   } else if( n<0 ) {
     *info = -5;
@@ -672,14 +663,14 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
        *           A is upper triangular.
        **/
       for (j=1 ; j<=n ; j+=1) {
-	cnorm_1( j ) = ydasum( j-1, &a_2( 1, j ), 1 );
+        cnorm_1( j ) = cblas_dasum( j-1, &a_2( 1, j ), 1 );
       }
     } else {
       /**
        *           A is lower triangular.
        **/
       for (j=1 ; j<=n - 1 ; j+=1) {
-	cnorm_1( j ) = ydasum( n-j, &a_2( j+1, j ), 1 );
+        cnorm_1( j ) = cblas_dasum( n-j, &a_2( j+1, j ), 1 );
       }
       cnorm_1( n ) = zero;
     }
@@ -688,19 +679,19 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
    *     Scale the column norms by TSCAL if the maximum entry in CNORM is
    *     greater than BIGNUM.
    **/
-  imax = yidamax( n, cnorm, 1 );
+  imax = 1+cblas_idamax( n, cnorm, 1 );
   tmax = cnorm_1( imax );
   if( tmax<=bignum ) {
     tscal = one;
   } else {
     tscal = one / ( smlnum*tmax );
-    ydscal( n, tscal, cnorm, 1 );
+    cblas_dscal( n, tscal, cnorm, 1 );
   }
   /**
    *     Compute a bound on the computed solution vector to see if the
-   *     Level 2 BLAS routine YDTRSV can be used.
+   *     Level 2 BLAS routine DTRSV can be used.
    **/
-  j = yidamax( n, x, 1 );
+  j = 1+cblas_idamax( n, x, 1 );
   xmax = abs( x_1( j ) );
   xbnd = xmax;
   if( notran ) {
@@ -732,27 +723,27 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
       grow = one / max( xbnd, smlnum );
       xbnd = grow;
       for (j=jfirst ; jinc>0?j<=jlast:j>=jlast ; j+=jinc) {
-	/**
-	 *              Exit the loop if the growth factor is too small.
-	 **/
-	if( grow<=smlnum )
-	  goto L_50;
-	/**
-	 *              M(j) = G(j-1) / abs(A_2(j,j))
-	 **/
-	tjj = abs( a_2( j, j ) );
-	xbnd = min( xbnd, min( one, tjj )*grow );
-	if( tjj+cnorm_1( j )>=smlnum ) {
-	  /**
-	   *                 G(j) = G(j-1)*( 1 + CNORM_1(j) / abs(A_2(j,j)) )
-	   **/
-	  grow = grow*( tjj / ( tjj+cnorm_1( j ) ) );
-	} else {
-	  /**
-	   *                 G(j) could overflow, set GROW to 0.
-	   **/
-	  grow = zero;
-	}
+        /**
+         *              Exit the loop if the growth factor is too small.
+         **/
+        if( grow<=smlnum )
+          goto L_50;
+        /**
+         *              M(j) = G(j-1) / abs(A_2(j,j))
+         **/
+        tjj = abs( a_2( j, j ) );
+        xbnd = min( xbnd, min( one, tjj )*grow );
+        if( tjj+cnorm_1( j )>=smlnum ) {
+          /**
+           *                 G(j) = G(j-1)*( 1 + CNORM_1(j) / abs(A_2(j,j)) )
+           **/
+          grow = grow*( tjj / ( tjj+cnorm_1( j ) ) );
+        } else {
+          /**
+           *                 G(j) could overflow, set GROW to 0.
+           **/
+          grow = zero;
+        }
       }
       grow = xbnd;
     } else {
@@ -763,15 +754,15 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
        **/
       grow = min( one, one / max( xbnd, smlnum ) );
       for (j=jfirst ; jinc>0?j<=jlast:j>=jlast ; j+=jinc) {
-	/**
-	 *              Exit the loop if the growth factor is too small.
-	 **/
-	if( grow<=smlnum )
-	  goto L_50;
-	/**
-	 *              G(j) = G(j-1)*( 1 + CNORM_1(j) )
-	 **/
-	grow = grow*( one / ( one+cnorm_1( j ) ) );
+        /**
+         *              Exit the loop if the growth factor is too small.
+         **/
+        if( grow<=smlnum )
+          goto L_50;
+        /**
+         *              G(j) = G(j-1)*( 1 + CNORM_1(j) )
+         **/
+        grow = grow*( one / ( one+cnorm_1( j ) ) );
       }
     }
   L_50:;
@@ -805,22 +796,22 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
       grow = one / max( xbnd, smlnum );
       xbnd = grow;
       for (j=jfirst ; jinc>0?j<=jlast:j>=jlast ; j+=jinc) {
-	/**
-	 *              Exit the loop if the growth factor is too small.
-	 **/
-	if( grow<=smlnum )
-	  goto L_80;
-	/**
-	 *              G(j) = max( G(j-1), M(j-1)*( 1 + CNORM_1(j) ) )
-	 **/
-	xj = one + cnorm_1( j );
-	grow = min( grow, xbnd / xj );
-	/**
-	 *              M(j) = M(j-1)*( 1 + CNORM_1(j) ) / abs(A_2(j,j))
-	 **/
-	tjj = abs( a_2( j, j ) );
-	if( xj>tjj )
-	  xbnd = xbnd*( tjj / xj );
+        /**
+         *              Exit the loop if the growth factor is too small.
+         **/
+        if( grow<=smlnum )
+          goto L_80;
+        /**
+         *              G(j) = max( G(j-1), M(j-1)*( 1 + CNORM_1(j) ) )
+         **/
+        xj = one + cnorm_1( j );
+        grow = min( grow, xbnd / xj );
+        /**
+         *              M(j) = M(j-1)*( 1 + CNORM_1(j) ) / abs(A_2(j,j))
+         **/
+        tjj = abs( a_2( j, j ) );
+        if( xj>tjj )
+          xbnd = xbnd*( tjj / xj );
       }
       grow = min( grow, xbnd );
     } else {
@@ -831,16 +822,16 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
        **/
       grow = min( one, one / max( xbnd, smlnum ) );
       for (j=jfirst ; jinc>0?j<=jlast:j>=jlast ; j+=jinc) {
-	/**
-	 *              Exit the loop if the growth factor is too small.
-	 **/
-	if( grow<=smlnum )
-	  goto L_80;
-	/**
-	 *              G(j) = ( 1 + CNORM_1(j) )*G(j-1)
-	 **/
-	xj = one + cnorm_1( j );
-	grow = grow / xj;
+        /**
+         *              Exit the loop if the growth factor is too small.
+         **/
+        if( grow<=smlnum )
+          goto L_80;
+        /**
+         *              G(j) = ( 1 + CNORM_1(j) )*G(j-1)
+         **/
+        xj = one + cnorm_1( j );
+        grow = grow / xj;
       }
     }
   L_80:;
@@ -851,7 +842,9 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
      *        Use the Level 2 BLAS solve if the reciprocal of the bound on
      *        elements of X is not too small.
      **/
-    ydtrsv( uplo, trans, diag, n, a, lda, x, 1 );
+    cblas_dtrsv(CblasColMajor, upper? CblasUpper : CblasLower,
+                notran? CblasNoTrans : CblasTrans,
+                nounit? CblasNonUnit : CblasUnit, n, a, lda, x, 1 );
   } else {
     /**
      *        Use a Level 1 BLAS solve, scaling intermediate results.
@@ -862,7 +855,7 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
        *           BIGNUM in absolute value.
        **/
       *scale = bignum / xmax;
-      ydscal( n, *scale, x, 1 );
+      cblas_dscal( n, *scale, x, 1 );
       xmax = bignum;
     }
 
@@ -871,117 +864,117 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
        *           Solve A * *x = b
        **/
       for (j=jfirst ; jinc>0?j<=jlast:j>=jlast ; j+=jinc) {
-	/**
-	 *              Compute x_1(j) = b(j) / A_2(j,j), scaling x if necessary.
-	 **/
-	xj = abs( x_1( j ) );
-	if( nounit ) {
-	  tjjs = a_2( j, j )*tscal;
-	} else {
-	  tjjs = tscal;
-	  if( tscal==one )
-	    goto L_100;
-	}
-	tjj = abs( tjjs );
-	if( tjj>smlnum ) {
-	  /**
-	   *                    abs(A_2(j,j)) > SMLNUM:
-	   **/
-	  if( tjj<one ) {
-	    if( xj>tjj*bignum ) {
-	      /**
-	       *                          Scale x by 1/b(j).
-	       **/
-	      rec = one / xj;
-	      ydscal( n, rec, x, 1 );
-	      *scale = *scale*rec;
-	      xmax = xmax*rec;
-	    }
-	  }
-	  x_1( j ) = x_1( j ) / tjjs;
-	  xj = abs( x_1( j ) );
-	} else if( tjj>zero ) {
-	  /**
-	   *                    0 < abs(A_2(j,j)) <= SMLNUM:
-	   **/
-	  if( xj>tjj*bignum ) {
-	    /**
-	     *                       Scale x by (1/abs(x_1(j)))*abs(A_2(j,j))*BIGNUM
-	     *                       to avoid overflow when dividing by A_2(j,j).
-	     **/
-	    rec = ( tjj*bignum ) / xj;
-	    if( cnorm_1( j )>one ) {
-	      /**
-	       *                          Scale by 1/CNORM_1(j) to avoid overflow when
-	       *                          multiplying x_1(j) times column j.
-	       **/
-	      rec = rec / cnorm_1( j );
-	    }
-	    ydscal( n, rec, x, 1 );
-	    *scale = *scale*rec;
-	    xmax = xmax*rec;
-	  }
-	  x_1( j ) = x_1( j ) / tjjs;
-	  xj = abs( x_1( j ) );
-	} else {
-	  /**
-	   *                    A_2(j,j) = 0:  Set x_1(1:n) = 0, x_1(j) = 1, and
-	   *                    *scale = 0, and compute a solution to A**x = 0.
-	   **/
-	  for (i=1 ; i<=n ; i+=1) {
-	    x_1( i ) = zero;
-	  }
-	  x_1( j ) = one;
-	  xj = one;
-	  *scale = zero;
-	  xmax = zero;
-	}
+        /**
+         *              Compute x_1(j) = b(j) / A_2(j,j), scaling x if necessary.
+         **/
+        xj = abs( x_1( j ) );
+        if( nounit ) {
+          tjjs = a_2( j, j )*tscal;
+        } else {
+          tjjs = tscal;
+          if( tscal==one )
+            goto L_100;
+        }
+        tjj = abs( tjjs );
+        if( tjj>smlnum ) {
+          /**
+           *                    abs(A_2(j,j)) > SMLNUM:
+           **/
+          if( tjj<one ) {
+            if( xj>tjj*bignum ) {
+              /**
+               *                          Scale x by 1/b(j).
+               **/
+              rec = one / xj;
+              cblas_dscal( n, rec, x, 1 );
+              *scale = *scale*rec;
+              xmax = xmax*rec;
+            }
+          }
+          x_1( j ) = x_1( j ) / tjjs;
+          xj = abs( x_1( j ) );
+        } else if( tjj>zero ) {
+          /**
+           *                    0 < abs(A_2(j,j)) <= SMLNUM:
+           **/
+          if( xj>tjj*bignum ) {
+            /**
+             *                       Scale x by (1/abs(x_1(j)))*abs(A_2(j,j))*BIGNUM
+             *                       to avoid overflow when dividing by A_2(j,j).
+             **/
+            rec = ( tjj*bignum ) / xj;
+            if( cnorm_1( j )>one ) {
+              /**
+               *                          Scale by 1/CNORM_1(j) to avoid overflow when
+               *                          multiplying x_1(j) times column j.
+               **/
+              rec = rec / cnorm_1( j );
+            }
+            cblas_dscal( n, rec, x, 1 );
+            *scale = *scale*rec;
+            xmax = xmax*rec;
+          }
+          x_1( j ) = x_1( j ) / tjjs;
+          xj = abs( x_1( j ) );
+        } else {
+          /**
+           *                    A_2(j,j) = 0:  Set x_1(1:n) = 0, x_1(j) = 1, and
+           *                    *scale = 0, and compute a solution to A**x = 0.
+           **/
+          for (i=1 ; i<=n ; i+=1) {
+            x_1( i ) = zero;
+          }
+          x_1( j ) = one;
+          xj = one;
+          *scale = zero;
+          xmax = zero;
+        }
       L_100:
-	/**
-	 *              Scale x if necessary to avoid overflow when adding a
-	 *              multiple of column j of A.
-	 **/
-	if( xj>one ) {
-	  rec = one / xj;
-	  if( cnorm_1( j )>( bignum-xmax )*rec ) {
-	    /**
-	     *                    Scale x by 1/(2*abs(x_1(j))).
-	     **/
-	    rec = rec*half;
-	    ydscal( n, rec, x, 1 );
-	    *scale = *scale*rec;
-	  }
-	} else if( xj*cnorm_1( j )>( bignum-xmax ) ) {
-	  /**
-	   *                 Scale x by 1/2.
-	   **/
-	  ydscal( n, half, x, 1 );
-	  *scale = *scale*half;
-	}
+        /**
+         *              Scale x if necessary to avoid overflow when adding a
+         *              multiple of column j of A.
+         **/
+        if( xj>one ) {
+          rec = one / xj;
+          if( cnorm_1( j )>( bignum-xmax )*rec ) {
+            /**
+             *                    Scale x by 1/(2*abs(x_1(j))).
+             **/
+            rec = rec*half;
+            cblas_dscal( n, rec, x, 1 );
+            *scale = *scale*rec;
+          }
+        } else if( xj*cnorm_1( j )>( bignum-xmax ) ) {
+          /**
+           *                 Scale x by 1/2.
+           **/
+          cblas_dscal( n, half, x, 1 );
+          *scale = *scale*half;
+        }
 
-	if( upper ) {
-	  if( j>1 ) {
-	    /**
-	     *                    Compute the update
-	     *                       x_1(1:j-1) := x_1(1:j-1) - x_1(j) * A_2(1:j-1,j)
-	     **/
-	    ydaxpy( j-1, -x_1( j )*tscal, &a_2( 1, j ), 1, x,
-		  1 );
-	    i = yidamax( j-1, x, 1 );
-	    xmax = abs( x_1( i ) );
-	  }
-	} else {
-	  if( j<n ) {
-	    /**
-	     *                    Compute the update
-	     *                       x_1(j+1:n) := x_1(j+1:n) - x_1(j) * A_2(j+1:n,j)
-	     **/
-	    ydaxpy( n-j, -x_1( j )*tscal, &a_2( j+1, j ), 1,
-		  &x_1( j+1 ), 1 );
-	    i = j + yidamax( n-j, &x_1( j+1 ), 1 );
-	    xmax = abs( x_1( i ) );
-	  }
-	}
+        if( upper ) {
+          if( j>1 ) {
+            /**
+             *                    Compute the update
+             *                       x_1(1:j-1) := x_1(1:j-1) - x_1(j) * A_2(1:j-1,j)
+             **/
+            cblas_daxpy( j-1, -x_1( j )*tscal, &a_2( 1, j ), 1, x,
+                  1 );
+            i = 1+cblas_idamax( j-1, x, 1 );
+            xmax = abs( x_1( i ) );
+          }
+        } else {
+          if( j<n ) {
+            /**
+             *                    Compute the update
+             *                       x_1(j+1:n) := x_1(j+1:n) - x_1(j) * A_2(j+1:n,j)
+             **/
+            cblas_daxpy( n-j, -x_1( j )*tscal, &a_2( j+1, j ), 1,
+                  &x_1( j+1 ), 1 );
+            i = j + 1+cblas_idamax( n-j, &x_1( j+1 ), 1 );
+            xmax = abs( x_1( i ) );
+          }
+        }
       }
 
     } else {
@@ -989,133 +982,133 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
        *           Solve A' * *x = b
        **/
       for (j=jfirst ; jinc>0?j<=jlast:j>=jlast ; j+=jinc) {
-	/**
-	 *              Compute x_1(j) = b(j) - sum A_2(k,j)*x_1(k).
-	 *                                    k<>j
-	 **/
-	xj = abs( x_1( j ) );
-	uscal = tscal;
-	rec = one / max( xmax, one );
-	if( cnorm_1( j )>( bignum-xj )*rec ) {
-	  /**
-	   *                 If x_1(j) could overflow, scale x by 1/(2*XMAX).
-	   **/
-	  rec = rec*half;
-	  if( nounit ) {
-	    tjjs = a_2( j, j )*tscal;
-	  } else {
-	    tjjs = tscal;
-	  }
-	  tjj = abs( tjjs );
-	  if( tjj>one ) {
-	    /**
-	     *                       Divide by A_2(j,j) when scaling x if A_2(j,j) > 1.
-	     **/
-	    rec = min( one, rec*tjj );
-	    uscal = uscal / tjjs;
-	  }
-	  if( rec<one ) {
-	    ydscal( n, rec, x, 1 );
-	    *scale = *scale*rec;
-	    xmax = xmax*rec;
-	  }
-	}
+        /**
+         *              Compute x_1(j) = b(j) - sum A_2(k,j)*x_1(k).
+         *                                    k<>j
+         **/
+        xj = abs( x_1( j ) );
+        uscal = tscal;
+        rec = one / max( xmax, one );
+        if( cnorm_1( j )>( bignum-xj )*rec ) {
+          /**
+           *                 If x_1(j) could overflow, scale x by 1/(2*XMAX).
+           **/
+          rec = rec*half;
+          if( nounit ) {
+            tjjs = a_2( j, j )*tscal;
+          } else {
+            tjjs = tscal;
+          }
+          tjj = abs( tjjs );
+          if( tjj>one ) {
+            /**
+             *                       Divide by A_2(j,j) when scaling x if A_2(j,j) > 1.
+             **/
+            rec = min( one, rec*tjj );
+            uscal = uscal / tjjs;
+          }
+          if( rec<one ) {
+            cblas_dscal( n, rec, x, 1 );
+            *scale = *scale*rec;
+            xmax = xmax*rec;
+          }
+        }
 
-	sumj = zero;
-	if( uscal==one ) {
-	  /**
-	   *                 If the scaling needed for A in the dot product is 1,
-	   *                 call YDDOT to perform the dot product.
-	   **/
-	  if( upper ) {
-	    sumj = yddot( j-1, &a_2( 1, j ), 1, x, 1 );
-	  } else if( j<n ) {
-	    sumj = yddot( n-j, &a_2( j+1, j ), 1, &x_1( j+1 ), 1 );
-	  }
-	} else {
-	  /**
-	   *                 Otherwise, use in-line code for the dot product.
-	   **/
-	  if( upper ) {
-	    for (i=1 ; i<=j - 1 ; i+=1) {
-	      sumj = sumj + ( a_2( i, j )*uscal )*x_1( i );
-	    }
-	  } else if( j<n ) {
-	    for (i=j + 1 ; i<=n ; i+=1) {
-	      sumj = sumj + ( a_2( i, j )*uscal )*x_1( i );
-	    }
-	  }
-	}
+        sumj = zero;
+        if( uscal==one ) {
+          /**
+           *                 If the scaling needed for A in the dot product is 1,
+           *                 call CBLAS_DDOT to perform the dot product.
+           **/
+          if( upper ) {
+            sumj = cblas_ddot( j-1, &a_2( 1, j ), 1, x, 1 );
+          } else if( j<n ) {
+            sumj = cblas_ddot( n-j, &a_2( j+1, j ), 1, &x_1( j+1 ), 1 );
+          }
+        } else {
+          /**
+           *                 Otherwise, use in-line code for the dot product.
+           **/
+          if( upper ) {
+            for (i=1 ; i<=j - 1 ; i+=1) {
+              sumj = sumj + ( a_2( i, j )*uscal )*x_1( i );
+            }
+          } else if( j<n ) {
+            for (i=j + 1 ; i<=n ; i+=1) {
+              sumj = sumj + ( a_2( i, j )*uscal )*x_1( i );
+            }
+          }
+        }
 
-	if( uscal==tscal ) {
-	  /**
-	   *                 Compute x_1(j) := ( x_1(j) - sumj ) / A_2(j,j) if 1/A_2(j,j)
-	   *                 was not used to scale the dotproduct.
-	   **/
-	  x_1( j ) = x_1( j ) - sumj;
-	  xj = abs( x_1( j ) );
-	  if( nounit ) {
-	    tjjs = a_2( j, j )*tscal;
-	  } else {
-	    tjjs = tscal;
-	    if( tscal==one )
-	      goto L_150;
-	  }
-	  /**
-	   *                    Compute x_1(j) = x_1(j) / A_2(j,j), scaling if necessary.
-	   **/
-	  tjj = abs( tjjs );
-	  if( tjj>smlnum ) {
-	    /**
-	     *                       abs(A_2(j,j)) > SMLNUM:
-	     **/
-	    if( tjj<one ) {
-	      if( xj>tjj*bignum ) {
-		/**
-		 *                             Scale X by 1/abs(x_1(j)).
-		 **/
-		rec = one / xj;
-		ydscal( n, rec, x, 1 );
-		*scale = *scale*rec;
-		xmax = xmax*rec;
-	      }
-	    }
-	    x_1( j ) = x_1( j ) / tjjs;
-	  } else if( tjj>zero ) {
-	    /**
-	     *                       0 < abs(A_2(j,j)) <= SMLNUM:
-	     **/
-	    if( xj>tjj*bignum ) {
-	      /**
-	       *                          Scale x by (1/abs(x_1(j)))*abs(A_2(j,j))*BIGNUM.
-	       **/
-	      rec = ( tjj*bignum ) / xj;
-	      ydscal( n, rec, x, 1 );
-	      *scale = *scale*rec;
-	      xmax = xmax*rec;
-	    }
-	    x_1( j ) = x_1( j ) / tjjs;
-	  } else {
-	    /**
-	     *                       A_2(j,j) = 0:  Set x_1(1:n) = 0, x_1(j) = 1, and
-	     *                       *scale = 0, and compute a solution to A'**x = 0.
-	     **/
-	    for (i=1 ; i<=n ; i+=1) {
-	      x_1( i ) = zero;
-	    }
-	    x_1( j ) = one;
-	    *scale = zero;
-	    xmax = zero;
-	  }
+        if( uscal==tscal ) {
+          /**
+           *                 Compute x_1(j) := ( x_1(j) - sumj ) / A_2(j,j) if 1/A_2(j,j)
+           *                 was not used to scale the dotproduct.
+           **/
+          x_1( j ) = x_1( j ) - sumj;
+          xj = abs( x_1( j ) );
+          if( nounit ) {
+            tjjs = a_2( j, j )*tscal;
+          } else {
+            tjjs = tscal;
+            if( tscal==one )
+              goto L_150;
+          }
+          /**
+           *                    Compute x_1(j) = x_1(j) / A_2(j,j), scaling if necessary.
+           **/
+          tjj = abs( tjjs );
+          if( tjj>smlnum ) {
+            /**
+             *                       abs(A_2(j,j)) > SMLNUM:
+             **/
+            if( tjj<one ) {
+              if( xj>tjj*bignum ) {
+                /**
+                 *                             Scale X by 1/abs(x_1(j)).
+                 **/
+                rec = one / xj;
+                cblas_dscal( n, rec, x, 1 );
+                *scale = *scale*rec;
+                xmax = xmax*rec;
+              }
+            }
+            x_1( j ) = x_1( j ) / tjjs;
+          } else if( tjj>zero ) {
+            /**
+             *                       0 < abs(A_2(j,j)) <= SMLNUM:
+             **/
+            if( xj>tjj*bignum ) {
+              /**
+               *                          Scale x by (1/abs(x_1(j)))*abs(A_2(j,j))*BIGNUM.
+               **/
+              rec = ( tjj*bignum ) / xj;
+              cblas_dscal( n, rec, x, 1 );
+              *scale = *scale*rec;
+              xmax = xmax*rec;
+            }
+            x_1( j ) = x_1( j ) / tjjs;
+          } else {
+            /**
+             *                       A_2(j,j) = 0:  Set x_1(1:n) = 0, x_1(j) = 1, and
+             *                       *scale = 0, and compute a solution to A'**x = 0.
+             **/
+            for (i=1 ; i<=n ; i+=1) {
+              x_1( i ) = zero;
+            }
+            x_1( j ) = one;
+            *scale = zero;
+            xmax = zero;
+          }
         L_150:;
-	} else {
-	  /**
-	   *                 Compute x_1(j) := x_1(j) / A_2(j,j)  - sumj if the dot
-	   *                 product has already been divided by 1/A_2(j,j).
-	   **/
-	  x_1( j ) = x_1( j ) / tjjs - sumj;
-	}
-	xmax = max( xmax, abs( x_1( j ) ) );
+        } else {
+          /**
+           *                 Compute x_1(j) := x_1(j) / A_2(j,j)  - sumj if the dot
+           *                 product has already been divided by 1/A_2(j,j).
+           **/
+          x_1( j ) = x_1( j ) / tjjs - sumj;
+        }
+        xmax = max( xmax, abs( x_1( j ) ) );
       }
     }
     *scale = *scale / tscal;
@@ -1124,7 +1117,7 @@ void dlatrs( char uplo, char trans, char diag, char normin, long n,
    *     Scale the column norms by 1/TSCAL for return.
    **/
   if( tscal!=one ) {
-    ydscal( n, one / tscal, cnorm, 1 );
+    cblas_dscal( n, one / tscal, cnorm, 1 );
   }
 
   return;
@@ -1446,7 +1439,7 @@ void dlamc1( long *beta, long *t, int *rnd, int *ieee1 )
 
 
 void dlamc2( long *beta, long *t, int *rnd, double *eps,
-	    long *emin, double *rmin, long *emax, double *rmax )
+            long *emin, double *rmin, long *emax, double *rmax )
 {
   /**
    *  -- LAPACK auxiliary routine (version 1.1) --
@@ -1602,41 +1595,41 @@ void dlamc2( long *beta, long *t, int *rnd, double *eps,
 
     if( ( ngpmin==ngnmin ) && ( gpmin==gnmin ) ) {
       if( ngpmin==gpmin ) {
-	lemin = ngpmin;
-	/**            ( Non twos-complement machines, no gradual underflow;
-	 *              e.g.,  VAX )*/
+        lemin = ngpmin;
+        /**            ( Non twos-complement machines, no gradual underflow;
+         *              e.g.,  VAX )*/
       } else if( ( gpmin-ngpmin )==3 ) {
-	lemin = ngpmin - 1 + lt;
-	ieee = 1;
-	/**            ( Non twos-complement machines, with gradual underflow;
-	 *              e.g., IEEE standard followers )*/
+        lemin = ngpmin - 1 + lt;
+        ieee = 1;
+        /**            ( Non twos-complement machines, with gradual underflow;
+         *              e.g., IEEE standard followers )*/
       } else {
-	lemin = min( ngpmin, gpmin );
-	/**            ( A guess; no known machine )*/
-	/* iwarn = 1; */
+        lemin = min( ngpmin, gpmin );
+        /**            ( A guess; no known machine )*/
+        /* iwarn = 1; */
       }
 
     } else if( ( ngpmin==gpmin ) && ( ngnmin==gnmin ) ) {
       if( abs( ngpmin-ngnmin )==1 ) {
-	lemin = max( ngpmin, ngnmin );
-	/**            ( Twos-complement machines, no gradual underflow;
-	 *              e.g., CYBER 205 )*/
+        lemin = max( ngpmin, ngnmin );
+        /**            ( Twos-complement machines, no gradual underflow;
+         *              e.g., CYBER 205 )*/
       } else {
-	lemin = min( ngpmin, ngnmin );
-	/**            ( A guess; no known machine )*/
-	/* iwarn = 1; */
+        lemin = min( ngpmin, ngnmin );
+        /**            ( A guess; no known machine )*/
+        /* iwarn = 1; */
       }
 
     } else if( ( abs( ngpmin-ngnmin )==1 ) &&
-	      ( gpmin==gnmin ) ) {
+              ( gpmin==gnmin ) ) {
       if( ( gpmin-min( ngpmin, ngnmin ) )==3 ) {
-	lemin = max( ngpmin, ngnmin ) - 1 + lt;
-	/**            ( Twos-complement machines with gradual underflow;
-	 *              no known machine )*/
+        lemin = max( ngpmin, ngnmin ) - 1 + lt;
+        /**            ( Twos-complement machines with gradual underflow;
+         *              no known machine )*/
       } else {
-	lemin = min( ngpmin, ngnmin );
-	/**            ( A guess; no known machine )*/
-	/* iwarn = 1; */
+        lemin = min( ngpmin, ngnmin );
+        /**            ( A guess; no known machine )*/
+        /* iwarn = 1; */
       }
 
     } else {
@@ -1787,7 +1780,7 @@ void dlamc4( long *emin, double start, long base )
 
 
 void dlamc5( long beta, long p, long emin, int ieee,
-	    long *emax, double *rmax )
+            long *emax, double *rmax )
 {
   /**
    *  -- LAPACK auxiliary routine (version 1.1) --
@@ -1948,7 +1941,7 @@ void dlamc5( long beta, long p, long emin, int ieee,
 
 
 void dlacon( long n, double v[], double x[], long isgn[],
-	    double *est, long *kase )
+            double *est, long *kase )
 {
   /**
    *  -- LAPACK auxiliary routine (version 1.1) --
@@ -2061,7 +2054,7 @@ void dlacon( long n, double v[], double x[], long isgn[],
     /**        ... QUIT*/
     goto L_150;
   }
-  *est = ydasum( n, x, 1 );
+  *est = cblas_dasum( n, x, 1 );
 
   for (i=1 ; i<=n ; i+=1) {
     x_1( i ) = sign( one, x_1( i ) );
@@ -2075,7 +2068,7 @@ void dlacon( long n, double v[], double x[], long isgn[],
    *     FIRST ITERATION.  X HAS BEEN OVERWRITTEN BY TRANDPOSE(A)*X.
    **/
  L_40:
-  j = yidamax( n, x, 1 );
+  j = 1+cblas_idamax( n, x, 1 );
   iter = 2;
   /**
    *     MAIN LOOP - ITERATIONS 2,3,...,ITMAX.
@@ -2093,9 +2086,9 @@ void dlacon( long n, double v[], double x[], long isgn[],
    *     X HAS BEEN OVERWRITTEN BY A*X.
    **/
  L_70:
-  ydcopy( n, x, 1, v, 1 );
+  cblas_dcopy( n, x, 1, v, 1 );
   estold = *est;
-  *est = ydasum( n, v, 1 );
+  *est = cblas_dasum( n, v, 1 );
   for (i=1 ; i<=n ; i+=1) {
     if( nint( sign( one, x_1( i ) ) )!=isgn_1( i ) )
       goto L_90;
@@ -2121,7 +2114,7 @@ void dlacon( long n, double v[], double x[], long isgn[],
    **/
  L_110:
   jlast = j;
-  j = yidamax( n, x, 1 );
+  j = 1+cblas_idamax( n, x, 1 );
   if( ( x_1( jlast )!=abs( x_1( j ) ) ) && ( iter<itmax ) ) {
     iter = iter + 1;
     goto L_50;
@@ -2143,9 +2136,9 @@ void dlacon( long n, double v[], double x[], long isgn[],
    *     X HAS BEEN OVERWRITTEN BY A*X.
    **/
  L_140:
-  temp = two*( ydasum( n, x, 1 ) / dble( 3*n ) );
+  temp = two*( cblas_dasum( n, x, 1 ) / dble( 3*n ) );
   if( temp>*est ) {
-    ydcopy( n, x, 1, v, 1 );
+    cblas_dcopy( n, x, 1, v, 1 );
     *est = temp;
   }
 
