@@ -10,8 +10,8 @@
 
 /*-----prototypes of functions defined here-----*/
 extern void dgelss( long m, long n, long nrhs, double a[], long lda,
-		   double b[], long ldb, double s[], double rcond,
-		   long *rank,double work[], long lwork, long *info );
+                   double b[], long ldb, double s[], double rcond,
+                   long *rank,double work[], long lwork, long *info );
 /*-----end of prototypes-----*/
 
 
@@ -19,52 +19,46 @@ extern void dgelss( long m, long n, long nrhs, double a[], long lda,
 
 /*---other lapack routines---*/
 extern double   dlange( char norm, long m, long n, double a[], long lda,
-		       double work[] );
+                       double work[] );
 extern double   dlamch( char cmach );
 extern void dlabad( double *small, double *large );
 extern long ilaenv( long ispec, char *name, char *opts,
-		   long n1, long n2, long n3,long n4 );
+                   long n1, long n2, long n3,long n4 );
 
 extern void drscl( long n, double sa, double sx[], long incx );
 extern void dormqr( char side, char trans, long m, long n, long k,
-		   double a[], long lda, double tau[], double c[], long ldc,
-		   double work[], long lwork, long *info );
+                   double a[], long lda, double tau[], double c[], long ldc,
+                   double work[], long lwork, long *info );
 extern void dormlq( char side, char trans, long m, long n, long k,
-		   double a[], long lda, double tau[], double c[], long ldc,
-		   double work[], long lwork, long *info );
+                   double a[], long lda, double tau[], double c[], long ldc,
+                   double work[], long lwork, long *info );
 extern void dgelqf( long m, long n, double a[], long lda, double tau[],
-		   double work[], long lwork, long *info );
+                   double work[], long lwork, long *info );
 extern void dgeqrf( long m, long n, double a[], long lda, double tau[],
-		   double work[], long lwork, long *info );
+                   double work[], long lwork, long *info );
 extern void dlaset( char uplo, long m, long n, double alpha, double beta,
-		   double a[], long lda );
+                   double a[], long lda );
 extern void dlacpy( char uplo, long m, long n, double a[], long lda,
-		   double b[], long ldb );
+                   double b[], long ldb );
 extern void dlascl( char type, long kl, long ku, double cfrom, double cto,
-		   long m, long n, double a[], long lda, long *info );
+                   long m, long n, double a[], long lda, long *info );
 extern void dgebrd( long m, long n, double a[], long lda,
-		   double d[], double e[], double tauq[], double taup[],
-		   double work[], long lwork,long *info );
+                   double d[], double e[], double tauq[], double taup[],
+                   double work[], long lwork,long *info );
 extern void dormbr( char vect, char side, char trans, long m, long n, long k,
-		   double a[], long lda, double tau[], double c[],long ldc,
-		   double work[], long lwork, long *info );
+                   double a[], long lda, double tau[], double c[],long ldc,
+                   double work[], long lwork, long *info );
 extern void dorgbr( char vect, long m, long n, long k, double a[], long lda,
-		   double tau[], double work[], long lwork, long *info );
+                   double tau[], double work[], long lwork, long *info );
 extern void dbdsqr( char uplo, long n, long ncvt, long nru, long ncc,
-		   double d[], double e[], double vt[], long ldvt,
-		   double u[],long ldu, double c[], long ldc,
-		   double work[], long *info );
+                   double d[], double e[], double vt[], long ldvt,
+                   double u[],long ldu, double c[], long ldc,
+                   double work[], long *info );
 
 
 
 /*---blas routines---*/
-extern void ydgemv ( char trans, long m, long n, double alpha,
-		   double a[], long lda, double x[], long incx,
-		   double beta, double y[], long incy );
-extern void ydgemm ( char transa, char transb, long m, long n, long k,
-		   double alpha, double a[], long lda, double b[], long ldb,
-		   double beta, double c[], long ldc );
-extern void  ydcopy(long n,double dx[],long incx,double dy[],long incy);
+/* dcopy dgemv dgemm */
 
 
 
@@ -80,8 +74,8 @@ extern void xerbla(char *,long);
 
 
 void dgelss( long m, long n, long nrhs, double a[], long lda,
-	    double b[], long ldb, double s[], double rcond,
-	    long *rank,double work[], long lwork, long *info )
+            double b[], long ldb, double s[], double rcond,
+            long *rank,double work[], long lwork, long *info )
 {
   /**
    *  -- LAPACK driver routine (version 1.1) --
@@ -243,20 +237,20 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
        **/
       mm = n;
       maxwrk = max( maxwrk, n+n*ilaenv( 1, "dgeqrf", " ", m, n,
-				       -1, -1 ) );
+                                       -1, -1 ) );
       maxwrk = max( maxwrk, n+nrhs*
-		   ilaenv( 1, "dormqr", "lt", m, nrhs, n, -1 ) );
+                   ilaenv( 1, "dormqr", "lt", m, nrhs, n, -1 ) );
     }
     if( m>=n ) {
       /**
        *           Path 1 - overdetermined or exactly determined
        **/
       maxwrk = max( maxwrk, 3*n+( mm+n )*
-		   ilaenv( 1, "dgebrd", " ", mm, n, -1, -1 ) );
+                   ilaenv( 1, "dgebrd", " ", mm, n, -1, -1 ) );
       maxwrk = max( maxwrk, 3*n+nrhs*
-		   ilaenv( 1, "dormbr", "qlt", mm, nrhs, n, -1 ) );
+                   ilaenv( 1, "dormbr", "qlt", mm, nrhs, n, -1 ) );
       maxwrk = max( maxwrk, 3*n+( n-1 )*
-		   ilaenv( 1, "dorgbr", "p", n, n, n, -1 ) );
+                   ilaenv( 1, "dorgbr", "p", n, n, n, -1 ) );
       maxwrk = max( maxwrk, 5*n-4 );
       maxwrk = max( maxwrk, n*nrhs );
       minwrk = max( max(3*n+mm, 3*n+nrhs), 5*n-4 );
@@ -264,37 +258,37 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
     if( n>m ) {
       minwrk = max( max(3*m+nrhs, 3*m+n), 5*m-4 );
       if( n>=mnthr ) {
-	/**
-	 *              Path 2a - underdetermined, with many more columns
-	 *              than rows
-	 **/
-	maxwrk = m + m*ilaenv( 1, "dgelqf", " ", m, n, -1, -1 );
-	maxwrk = max( maxwrk, m*m+4*m+2*m*
-		     ilaenv( 1, "dgebrd", " ", m, m, -1, -1 ) );
-	maxwrk = max( maxwrk, m*m+4*m+nrhs*
-		     ilaenv( 1, "dormbr", "qlt", m, nrhs, m, -1 ) );
-	maxwrk = max( maxwrk, m*m+4*m+( m-1 )*
-		     ilaenv( 1, "dorgbr", "p", m, m, m, -1 ) );
-	maxwrk = max( maxwrk, m*m+6*m-4 );
-	if( nrhs>1 ) {
-	  maxwrk = max( maxwrk, m*m+m+m*nrhs );
-	} else {
-	  maxwrk = max( maxwrk, m*m+2*m );
-	}
-	maxwrk = max( maxwrk, m+nrhs*
-		     ilaenv( 1, "dormlq", "lt", n, nrhs, m, -1 ) );
+        /**
+         *              Path 2a - underdetermined, with many more columns
+         *              than rows
+         **/
+        maxwrk = m + m*ilaenv( 1, "dgelqf", " ", m, n, -1, -1 );
+        maxwrk = max( maxwrk, m*m+4*m+2*m*
+                     ilaenv( 1, "dgebrd", " ", m, m, -1, -1 ) );
+        maxwrk = max( maxwrk, m*m+4*m+nrhs*
+                     ilaenv( 1, "dormbr", "qlt", m, nrhs, m, -1 ) );
+        maxwrk = max( maxwrk, m*m+4*m+( m-1 )*
+                     ilaenv( 1, "dorgbr", "p", m, m, m, -1 ) );
+        maxwrk = max( maxwrk, m*m+6*m-4 );
+        if( nrhs>1 ) {
+          maxwrk = max( maxwrk, m*m+m+m*nrhs );
+        } else {
+          maxwrk = max( maxwrk, m*m+2*m );
+        }
+        maxwrk = max( maxwrk, m+nrhs*
+                     ilaenv( 1, "dormlq", "lt", n, nrhs, m, -1 ) );
       } else {
-	/**
-	 *              Path 2 - underdetermined
-	 **/
-	maxwrk = 3*m + ( n+m )*ilaenv( 1, "dgebrd", " ", m, n,
-				      -1, -1 );
-	maxwrk = max( maxwrk, 3*m+nrhs*
-		     ilaenv( 1, "dormbr", "qlt", m, nrhs, m, -1 ) );
-	maxwrk = max( maxwrk, 3*m+m*
-		     ilaenv( 1, "dorgbr", "p", m, n, m, -1 ) );
-	maxwrk = max( maxwrk, 5*m-4 );
-	maxwrk = max( maxwrk, n*nrhs );
+        /**
+         *              Path 2 - underdetermined
+         **/
+        maxwrk = 3*m + ( n+m )*ilaenv( 1, "dgebrd", " ", m, n,
+                                      -1, -1 );
+        maxwrk = max( maxwrk, 3*m+nrhs*
+                     ilaenv( 1, "dormbr", "qlt", m, nrhs, m, -1 ) );
+        maxwrk = max( maxwrk, 3*m+m*
+                     ilaenv( 1, "dorgbr", "p", m, n, m, -1 ) );
+        maxwrk = max( maxwrk, 5*m-4 );
+        maxwrk = max( maxwrk, n*nrhs );
       }
     }
     minwrk = min( minwrk, maxwrk );
@@ -387,18 +381,18 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
        *           (Workspace: need 2*N, prefer N+N*NB)
        **/
       dgeqrf( m, n, a, lda, &work_1( itau ), &work_1( iwork ),
-	     lwork-iwork+1, info );
+             lwork-iwork+1, info );
       /**
        *           Multiply B by transpose(Q)
        *           (Workspace: need N+NRHS, prefer N+NRHS*NB)
        **/
       dormqr( 'l', 't', m, nrhs, n, a, lda, &work_1( itau ), b,
-	     ldb, &work_1( iwork ), lwork-iwork+1, info );
+             ldb, &work_1( iwork ), lwork-iwork+1, info );
       /**
        *           Zero out below R
        **/
       if( n>1 )
-	dlaset( 'l', n-1, n-1, zero, zero, &a_2( 2, 1 ), lda );
+        dlaset( 'l', n-1, n-1, zero, zero, &a_2( 2, 1 ), lda );
     }
 
     ie = 1;
@@ -410,20 +404,20 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need 3*N+MM, prefer 3*N+(MM+N)*NB)
      **/
     dgebrd( mm, n, a, lda, s, &work_1( ie ), &work_1( itauq ),
-	   &work_1( itaup ), &work_1( iwork ), lwork-iwork+1,
-	   info );
+           &work_1( itaup ), &work_1( iwork ), lwork-iwork+1,
+           info );
     /**
      *        Multiply B by transpose of left bidiagonalizing vectors of R
      *        (Workspace: need 3*N+NRHS, prefer 3*N+NRHS*NB)
      **/
     dormbr( 'q', 'l', 't', mm, nrhs, n, a, lda, &work_1( itauq ),
-	   b, ldb, &work_1( iwork ), lwork-iwork+1, info );
+           b, ldb, &work_1( iwork ), lwork-iwork+1, info );
     /**
      *        Generate right bidiagonalizing vectors of R in A
      *        (Workspace: need 4*N-1, prefer 3*N+(N-1)*NB)
      **/
     dorgbr( 'p', n, n, n, a, lda, &work_1( itaup ),
-	   &work_1( iwork ), lwork-iwork+1, info );
+           &work_1( iwork ), lwork-iwork+1, info );
     iwork = ie + n;
     /**
      *        Perform bidiagonal QR iteration
@@ -432,7 +426,7 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need 5*N-4)
      **/
     dbdsqr( 'u', n, n, 0, nrhs, s, &work_1( ie ), a, lda, vdum,
-	   1, b, ldb, &work_1( iwork ), info );
+           1, b, ldb, &work_1( iwork ), info );
     if( *info!=0 )
       goto L_70;
     /**
@@ -444,10 +438,10 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
     *rank = 0;
     for (i=1 ; i<=n ; i+=1) {
       if( s_1( i )>thr ) {
-	drscl( nrhs, s_1( i ), &b_2( i, 1 ), ldb );
-	*rank = *rank + 1;
+        drscl( nrhs, s_1( i ), &b_2( i, 1 ), ldb );
+        *rank = *rank + 1;
       } else {
-	dlaset( 'f', 1, nrhs, zero, zero, &b_2( i, 1 ), ldb );
+        dlaset( 'f', 1, nrhs, zero, zero, &b_2( i, 1 ), ldb );
       }
     }
     /**
@@ -455,31 +449,32 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need N, prefer N*NRHS)
      **/
     if( lwork>=ldb*nrhs && nrhs>1 ) {
-      ydgemm( 't', 'n', n, nrhs, n, one, a, lda, b, ldb, zero,
-	    work, ldb );
+      cblas_dgemm(CblasColMajor, CblasTrans, CblasNoTrans, n, nrhs, n,
+                  one, a, lda, b, ldb, zero, work, ldb );
       dlacpy( 'g', n, nrhs, work, ldb, b, ldb );
     } else if( nrhs>1 ) {
       chunk = lwork / n;
       for (i=1 ; chunk>0?i<=nrhs:i>=nrhs ; i+=chunk) {
-	bl = min( nrhs-i+1, chunk );
-	ydgemm( 't', 'n', n, bl, n, one, a, lda, b, ldb,
-	      zero, work, n );
-	dlacpy( 'g', n, bl, work, n, b, ldb );
+        bl = min( nrhs-i+1, chunk );
+        cblas_dgemm(CblasColMajor, CblasTrans, CblasNoTrans, n, bl, n,
+                    one, a, lda, b, ldb, zero, work, n );
+        dlacpy( 'g', n, bl, work, n, b, ldb );
       }
     } else {
-      ydgemv( 't', n, n, one, a, lda, b, 1, zero, work, 1 );
-      ydcopy( n, work, 1, b, 1 );
+      cblas_dgemv(CblasColMajor, CblasTrans, n, n, one, a, lda, b, 1, zero,
+                  work, 1 );
+      cblas_dcopy( n, work, 1, b, 1 );
     }
 
   } else if( n>=mnthr && lwork>=4*m+m*m+
-	    max( max(m, 2*m-4), max(nrhs, n-3*m) ) ) {
+            max( max(m, 2*m-4), max(nrhs, n-3*m) ) ) {
     /**
      *        Path 2a - underdetermined, with many more columns than rows
      *        and sufficient workspace for an efficient algorithm
      **/
     ldwork = m;
     if( lwork>=max( 4*m+m*lda+max( max(m, 2*m-4), max(nrhs, n-3*m) ),
-		   m*lda+m+m*nrhs ) )ldwork = lda;
+                   m*lda+m+m*nrhs ) )ldwork = lda;
     itau = 1;
     iwork = m + 1;
     /**
@@ -487,14 +482,14 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need 2*M, prefer M+M*NB)
      **/
     dgelqf( m, n, a, lda, &work_1( itau ), &work_1( iwork ),
-	   lwork-iwork+1, info );
+           lwork-iwork+1, info );
     il = iwork;
     /**
      *        Copy L to WORK(IL), zeroing out above it
      **/
     dlacpy( 'l', m, m, a, lda, &work_1( il ), ldwork );
     dlaset( 'u', m-1, m-1, zero, zero, &work_1( il+ldwork ),
-	   ldwork );
+           ldwork );
     ie = il + ldwork*m;
     itauq = ie + m;
     itaup = itauq + m;
@@ -504,21 +499,21 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need M*M+5*M, prefer M*M+4*M+2*M*NB)
      **/
     dgebrd( m, m, &work_1( il ), ldwork, s, &work_1( ie ),
-	   &work_1( itauq ), &work_1( itaup ), &work_1( iwork ),
-	   lwork-iwork+1, info );
+           &work_1( itauq ), &work_1( itaup ), &work_1( iwork ),
+           lwork-iwork+1, info );
     /**
      *        Multiply B by transpose of left bidiagonalizing vectors of L
      *        (Workspace: need M*M+4*M+NRHS, prefer M*M+4*M+NRHS*NB)
      **/
     dormbr( 'q', 'l', 't', m, nrhs, m, &work_1( il ), ldwork,
-	   &work_1( itauq ), b, ldb, &work_1( iwork ),
-	   lwork-iwork+1, info );
+           &work_1( itauq ), b, ldb, &work_1( iwork ),
+           lwork-iwork+1, info );
     /**
      *        Generate right bidiagonalizing vectors of R in WORK(IL)
      *        (Workspace: need M*M+5*M-1, prefer M*M+4*M+(M-1)*NB)
      **/
     dorgbr( 'p', m, m, m, &work_1( il ), ldwork, &work_1( itaup ),
-	   &work_1( iwork ), lwork-iwork+1, info );
+           &work_1( iwork ), lwork-iwork+1, info );
     iwork = ie + m;
     /**
      *        Perform bidiagonal QR iteration,
@@ -527,7 +522,7 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need M*M+6*M-4)
      **/
     dbdsqr( 'u', m, m, 0, nrhs, s, &work_1( ie ), &work_1( il ),
-	   ldwork, a, lda, b, ldb, &work_1( iwork ), info );
+           ldwork, a, lda, b, ldb, &work_1( iwork ), info );
     if( *info!=0 )
       goto L_70;
     /**
@@ -539,10 +534,10 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
     *rank = 0;
     for (i=1 ; i<=m ; i+=1) {
       if( s_1( i )>thr ) {
-	drscl( nrhs, s_1( i ), &b_2( i, 1 ), ldb );
-	*rank = *rank + 1;
+        drscl( nrhs, s_1( i ), &b_2( i, 1 ), ldb );
+        *rank = *rank + 1;
       } else {
-	dlaset( 'f', 1, nrhs, zero, zero, &b_2( i, 1 ), ldb );
+        dlaset( 'f', 1, nrhs, zero, zero, &b_2( i, 1 ), ldb );
       }
     }
     iwork = ie;
@@ -551,21 +546,23 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need M*M+2*M, prefer M*M+M+M*NRHS)
      **/
     if( lwork>=ldb*nrhs+iwork-1 && nrhs>1 ) {
-      ydgemm( 't', 'n', m, nrhs, m, one, &work_1( il ), ldwork,
-	    b, ldb, zero, &work_1( iwork ), ldb );
+      cblas_dgemm(CblasColMajor, CblasTrans, CblasNoTrans, m, nrhs, m,
+                  one, &work_1( il ), ldwork, b, ldb, zero,
+                  &work_1( iwork ), ldb );
       dlacpy( 'g', m, nrhs, &work_1( iwork ), ldb, b, ldb );
     } else if( nrhs>1 ) {
       chunk = ( lwork-iwork+1 ) / m;
       for (i=1 ; chunk>0?i<=nrhs:i>=nrhs ; i+=chunk) {
-	bl = min( nrhs-i+1, chunk );
-	ydgemm( 't', 'n', m, bl, m, one, &work_1( il ), ldwork,
-	      &b_2( 1, i ), ldb, zero, &work_1( iwork ), n );
-	dlacpy( 'g', m, bl, &work_1( iwork ), n, b, ldb );
+        bl = min( nrhs-i+1, chunk );
+        cblas_dgemm(CblasColMajor, CblasTrans, CblasNoTrans, m, bl, m,
+                    one, &work_1( il ), ldwork, &b_2( 1, i ), ldb, zero,
+                    &work_1( iwork ), n );
+        dlacpy( 'g', m, bl, &work_1( iwork ), n, b, ldb );
       }
     } else {
-      ydgemv( 't', m, m, one, &work_1( il ), ldwork, &b_2( 1, 1 ),
-	    1, zero, &work_1( iwork ), 1 );
-      ydcopy( m, &work_1( iwork ), 1, &b_2( 1, 1 ), 1 );
+      cblas_dgemv(CblasColMajor, CblasTrans, m, m, one, &work_1( il ),
+                  ldwork, &b_2( 1, 1 ), 1, zero, &work_1( iwork ), 1 );
+      cblas_dcopy( m, &work_1( iwork ), 1, &b_2( 1, 1 ), 1 );
     }
     /**
      *        Zero out below first M rows of B
@@ -577,7 +574,7 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need M+NRHS, prefer M+NRHS*NB)
      **/
     dormlq( 'l', 't', n, nrhs, m, a, lda, &work_1( itau ), b,
-	   ldb, &work_1( iwork ), lwork-iwork+1, info );
+           ldb, &work_1( iwork ), lwork-iwork+1, info );
 
   } else {
     /**
@@ -592,20 +589,20 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need 3*M+N, prefer 3*M+(M+N)*NB)
      **/
     dgebrd( m, n, a, lda, s, &work_1( ie ), &work_1( itauq ),
-	   &work_1( itaup ), &work_1( iwork ), lwork-iwork+1,
-	   info );
+           &work_1( itaup ), &work_1( iwork ), lwork-iwork+1,
+           info );
     /**
      *        Multiply B by transpose of left bidiagonalizing vectors
      *        (Workspace: need 3*M+NRHS, prefer 3*M+NRHS*NB)
      **/
     dormbr( 'q', 'l', 't', m, nrhs, n, a, lda, &work_1( itauq ),
-	   b, ldb, &work_1( iwork ), lwork-iwork+1, info );
+           b, ldb, &work_1( iwork ), lwork-iwork+1, info );
     /**
      *        Generate right bidiagonalizing vectors in A
      *        (Workspace: need 4*M, prefer 3*M+M*NB)
      **/
     dorgbr( 'p', m, n, m, a, lda, &work_1( itaup ),
-	   &work_1( iwork ), lwork-iwork+1, info );
+           &work_1( iwork ), lwork-iwork+1, info );
     iwork = ie + m;
     /**
      *        Perform bidiagonal QR iteration,
@@ -614,7 +611,7 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need 5*M-4)
      **/
     dbdsqr( 'l', m, n, 0, nrhs, s, &work_1( ie ), a, lda, vdum,
-	   1, b, ldb, &work_1( iwork ), info );
+           1, b, ldb, &work_1( iwork ), info );
     if( *info!=0 )
       goto L_70;
     /**
@@ -626,10 +623,10 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
     *rank = 0;
     for (i=1 ; i<=m ; i+=1) {
       if( s_1( i )>thr ) {
-	drscl( nrhs, s_1( i ), &b_2( i, 1 ), ldb );
-	*rank = *rank + 1;
+        drscl( nrhs, s_1( i ), &b_2( i, 1 ), ldb );
+        *rank = *rank + 1;
       } else {
-	dlaset( 'f', 1, nrhs, zero, zero, &b_2( i, 1 ), ldb );
+        dlaset( 'f', 1, nrhs, zero, zero, &b_2( i, 1 ), ldb );
       }
     }
     /**
@@ -637,20 +634,21 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
      *        (Workspace: need N, prefer N*NRHS)
      **/
     if( lwork>=ldb*nrhs && nrhs>1 ) {
-      ydgemm( 't', 'n', n, nrhs, m, one, a, lda, b, ldb, zero,
-	    work, ldb );
+      cblas_dgemm(CblasColMajor, CblasTrans, CblasNoTrans, n, nrhs, m,
+                  one, a, lda, b, ldb, zero, work, ldb );
       dlacpy( 'f', n, nrhs, work, ldb, b, ldb );
     } else if( nrhs>1 ) {
       chunk = lwork / n;
       for (i=1 ; chunk>0?i<=nrhs:i>=nrhs ; i+=chunk) {
-	bl = min( nrhs-i+1, chunk );
-	ydgemm( 't', 'n', n, bl, m, one, a, lda, &b_2( 1, i ),
-	      ldb, zero, work, n );
-	dlacpy( 'f', n, bl, work, n, &b_2( 1, i ), ldb );
+        bl = min( nrhs-i+1, chunk );
+        cblas_dgemm(CblasColMajor, CblasTrans, CblasNoTrans, n, bl, m, one,
+                    a, lda, &b_2( 1, i ), ldb, zero, work, n );
+        dlacpy( 'f', n, bl, work, n, &b_2( 1, i ), ldb );
       }
     } else {
-      ydgemv( 't', m, n, one, a, lda, b, 1, zero, work, 1 );
-      ydcopy( n, work, 1, b, 1 );
+      cblas_dgemv(CblasColMajor, CblasTrans, m, n, one, a, lda, b, 1, zero,
+                  work, 1 );
+      cblas_dcopy( n, work, 1, b, 1 );
     }
   }
   /**
@@ -659,11 +657,11 @@ void dgelss( long m, long n, long nrhs, double a[], long lda,
   if( iascl==1 ) {
     dlascl( 'g', 0, 0, anrm, smlnum, n, nrhs, b, ldb, info );
     dlascl( 'g', 0, 0, smlnum, anrm, minmn, 1, s, minmn,
-	   info );
+           info );
   } else if( iascl==2 ) {
     dlascl( 'g', 0, 0, anrm, bignum, n, nrhs, b, ldb, info );
     dlascl( 'g', 0, 0, bignum, anrm, minmn, 1, s, minmn,
-	   info );
+           info );
   }
   if( ibscl==1 ) {
     dlascl( 'g', 0, 0, smlnum, bnrm, n, nrhs, b, ldb, info );
