@@ -15,12 +15,13 @@
 #include "playu.h"
 #include <stdio.h>
 #include "ugetc.h"
+#include "pmin.h"
 
 static void u_fd0_ready(void *c);
-static int u_get(char *s, int size, FILE *stream);
+static void u_nowait(void);
 
 static FILE *u_stream = 0;
-static int u_fd0_init = 0;
+static FILE *u_fd0_init = 0;
 /* ARGSUSED */
 static
 void u_fd0_ready(void *c)
@@ -31,39 +32,67 @@ void u_fd0_ready(void *c)
 int
 u_getc(FILE *stream)
 {
-  return u_get((char *)0, 0, stream);
+  u_waitfor(stream);
+  return getc(stream);
 }
 
 char *
 u_fgets(char *s, int size, FILE *stream)
 {
-  return u_get(s, size, stream)? s : 0;
+  u_waitfor(stream);
+  return fgets(s, size, stream);
 }
 
-static int
-u_get(char *s, int size, FILE *stream)
+int
+u_waitfor(FILE *stream)
 {
-  if (!u_fd0_init) {
+  if (stream != u_fd0_init) {
+    u_nowait();
     u_event_src(fileno(stream), &u_fd0_ready, stream);
-    u_fd0_init = 1;
+    u_fd0_init = stream;
   }
 
+  u_stream = 0;
   while (!u_stream) u_waiter(1);
-
   stream = u_stream;
   u_stream = 0;
-  if (!s) return getc(stream);
+  return (stream != u_fd0_init);  /* 0 on success */
+}
 
-  return fgets(s, size, stream)!=0;
+static void
+u_nowait(void)
+{
+  if (u_fd0_init) {
+    u_event_src(fileno(u_fd0_init), (void (*)(void *c))0, u_fd0_init);
+    u_fd0_init = 0;
+  }
+}
+
+int
+p_wait_stdin(void)
+{
+  return u_waitfor(stdin);
 }
 
 void
-u_pending_events(void)
+p_pending_events(void)
 {
-  if (u_fd0_init) {
-    /* do not handle events on stdin -- just everything else */
-    u_event_src(0, (void (*)(void *c))0, stdin);
-    u_fd0_init = 0;
-  }
+  /* do not handle events on u_fd0_init -- just everything else */
+  u_nowait();
   while (u_waiter(0));
 }
+
+void
+p_wait_while(int *flag)
+{
+  p_pending_events();
+  while (*flag) u_waiter(1);
+}
+
+void
+p_xhandler(void (*abort_hook)(void),
+           void (*on_exception)(int signal, char *errmsg))
+{
+  u_abort_hook = abort_hook;   /* replaces p_abort */
+  u_exception = on_exception;  /* when u_waiter detects p_signalling */
+}
