@@ -32,23 +32,7 @@ static char *clip_text = 0;
 static HWND clip_owner = 0;
 static void clip_free(int force);
 
-LONG APIENTRY WndProc ( 
-    HWND         hWnd, 
-    UINT     iMessage, 
-    UINT         wParam, 
-    LONG         lParam) 
-{
-  PAINTSTRUCT ps;
-    switch (iMessage) {
-    case WM_PAINT:
-      BeginPaint(hWnd, &ps);
-      EndPaint(hWnd, &ps);
-      break;
-    default:
-      return DefWindowProc (hWnd, iMessage, wParam, lParam) ; 
-    }
-    return 0;
-}
+void (*p_on_connect)(int dis, int fd) = 0;
 
 p_scr *
 p_connect(char *server_name)
@@ -87,10 +71,10 @@ p_connect(char *server_name)
   w_screen.sys_colors[255-P_YELLOW] = RGB(255,255,0);
   w_screen.sys_colors[255-P_BG] = GetSysColor(COLOR_WINDOW);
   w_screen.sys_colors[255-P_FG] = GetSysColor(COLOR_WINDOWTEXT);
-  w_screen.sys_colors[255-P_GUI_BG] = GetSysColor(COLOR_BTNFACE);
-  w_screen.sys_colors[255-P_GUI_FG] = GetSysColor(COLOR_BTNTEXT);
-  w_screen.sys_colors[255-P_GUI_LO] = GetSysColor(COLOR_BTNSHADOW);
-  w_screen.sys_colors[255-P_GUI_HI] = GetSysColor(COLOR_BTNHILIGHT);
+  w_screen.sys_colors[255-P_GRAYD] = RGB(100,100,100);
+  w_screen.sys_colors[255-P_GRAYC] = RGB(150,150,150);
+  w_screen.sys_colors[255-P_GRAYB] = RGB(190,190,190);
+  w_screen.sys_colors[255-P_GRAYA] = RGB(214,214,214);
   w_screen.sys_colors[255-P_XOR] = 0xffffff;  /* really fg^bg, but unused */
   i = GetDeviceCaps(dc0, NUMRESERVED);
   if (w_screen.depth==8 && i>1 && i<=32 &&
@@ -188,6 +172,8 @@ p_connect(char *server_name)
     registered = 1;
   }
 
+  if (p_on_connect) p_on_connect(0, -1);
+
   return &w_screen;
 }
 
@@ -211,6 +197,7 @@ void
 p_disconnect(p_scr *s)
 {
   int i;
+  if (p_on_connect) p_on_connect(1, -1);
   for (i=0 ; i<W_FONTS_CACHED && s->font_cache[i].hfont ; i++) {
     DeleteObject(s->font_cache[i].hfont);
     s->font_cache[i].hfont = 0;
@@ -308,6 +295,14 @@ p_raise(p_win *w)
   BringWindowToTop(w->w);
 }
 
+int w_nwins = 0;
+
+int
+p_wincount(p_scr *s)
+{
+  return (s==&w_screen)? w_nwins : 0;
+}
+
 LRESULT CALLBACK
 w_winproc(HWND hwnd, UINT msg, WPARAM wp, LPARAM lp)
 {
