@@ -24,7 +24,7 @@
                                     the result not in the original array
     (7) +  or +:start:stop:step   - "marked index" is a special form for
                                     matrix multiplication, pushes the
-				    result index number onto the stack
+                                    result index number onto the stack
     (8) ..    - "rubber index" causes any subsequent indices to be right
                 justified, copying as many dimensions to the result as
                 required in order to do this
@@ -67,7 +67,7 @@ extern Operand *FormOperandDB(Symbol *owner, Operand *op);
       Count the dummy indices, accumulating the corresponding strides.
       The result of this operation is the static values:
           nDummy       - number of dimensions in dummy dimension list
-	  dims[]       - Dimension* for each dimension
+          dims[]       - Dimension* for each dimension
 
    2. EvalSetup
       Scan through the actual indices to set:
@@ -82,10 +82,10 @@ extern Operand *FormOperandDB(Symbol *owner, Operand *op);
           steps[]     - index increments for each actual index
           rangeFlags[] - range->nilFlags for each actual index
           indexLists[] - index list for each actual index
-	  Builder[]   - function to build result is one of
-	     BuildScalar  - long scalar (offsets)
-	     BuildList    - long array (offsets, indexLists)
-	     BuildRange   - min:max:inc  or  rf:min:max:inc
+          Builder[]   - function to build result is one of
+             BuildScalar  - long scalar (offsets)
+             BuildList    - long array (offsets, indexLists)
+             BuildRange   - min:max:inc  or  rf:min:max:inc
                             (offsets, numbers, steps, rangeFlags)
              The arrays actually used by each Builder are shown in
              parentheses.  BuildRange also uses strides from step 1.
@@ -103,7 +103,7 @@ extern Operand *FormOperandDB(Symbol *owner, Operand *op);
 
    3. ArrayStrides (called from BuildResult) or LValueStrides
       Compute the stride associated with each dummy index
-	  strides[]    - stride (in bytes) for each dimension
+          strides[]    - stride (in bytes) for each dimension
 
    4. loop on BuildScalar, BuildList, BuildRange (from BuildResult or EvalLV)
       Process the indices from fastest to slowest varying.  The resulting
@@ -130,7 +130,7 @@ static void ArrayStrides(long stride);
 static int LValueStrides(Strider *strider);
 static void DoRangeFuncs(Array *array);
 static void BuildResult(char *mem, StructDef *base,
-			Array *array, Symbol *stack, int n);
+                        Array *array, Symbol *stack, int n);
 
 /*--------------------------------------------------------------------------*/
 
@@ -146,8 +146,8 @@ static long strides[MAX_INDICES];        /* strides for dummy dimensions */
 static int overreach;
 static long overOrigin;                  /* maximum origin if overreach */
 static long offsets[MAX_INDICES];        /* offsets for actual indices
-					    used by scalars, ranges -- also
-					    index count for rubber index */
+                                            used by scalars, ranges -- also
+                                            index count for rubber index */
 static long numbers[MAX_INDICES];        /* numbers for actual indices */
 static long steps[MAX_INDICES];          /* ::steps for actual indices */
 static int rangeFlags[MAX_INDICES];      /* nilFlags for actual indices */
@@ -201,14 +201,14 @@ static int EvalSetup(Symbol *stack, int n)
     index.ops->Setup(&index);
     if (iDummy<0) { /* nullifier, e.g.- where(0) */
       Drop(n+1);
-      PushDataBlock(Ref(&nilDB));
+      PushDataBlock(RefNC(&nilDB));
       return 1;
     }
   }
   if (iDummy<nDummy && n>0) {
     if (index.ops==&voidOps) {
       /* pick up all remaining dummy indices, just as if final index
-	 had been .. instead of nil */
+         had been .. instead of nil */
       long number= numbers[--iActual];
       long na= offsets[iActual];
       DotdotScan(stack, 0);
@@ -216,8 +216,8 @@ static int EvalSetup(Symbol *stack, int n)
       numbers[iActual]*= number;
       offsets[iActual++]+= na;
     } /* else, should check that there wasn't a nil index followed by
-	 one or more pseudo index -- however, this error is rather
-	 expensive to detect, and I'm omitting the check for now.  */
+         one or more pseudo index -- however, this error is rather
+         expensive to detect, and I'm omitting the check for now.  */
   }
 
   /* make sure any references beyond index bounds are kosher */
@@ -404,7 +404,7 @@ static void DotdotScan(Symbol *stack, int singleIndex)
      indices to skip.  We only need to detect pseudo-indices, since
      these are the only type which break the one-one correspondence
      between actual and dummy indices.  */
-  int na= 0;			/* # remaining non-pseudo actuals */
+  int na= 0;                    /* # remaining non-pseudo actuals */
   long number, n;
 
   while (stack<sp) {
@@ -415,14 +415,14 @@ static void DotdotScan(Symbol *stack, int singleIndex)
     } else {
       int nilFlags= ((Range *)stack->value.db)->nilFlags;
       if (nilFlags & R_RUBBER)
-	YError("multiple rubber (.. or *) indices in one index list");
+        YError("multiple rubber (.. or *) indices in one index list");
       if ((nilFlags & R_PSEUDO)==0) na++;
     }
   }
 
   if (singleIndex && (iDummy<nDummy-na-1)) iRubber= iActual;
-  offsets[iActual]= na;		/* offset is actually 0, intentionally
-				   misused here and in BuildRange */
+  offsets[iActual]= na;         /* offset is actually 0, intentionally
+                                   misused here and in BuildRange */
   number= 1;
   while (iDummy < nDummy-na) {
     n= dims[iDummy]->number;
@@ -534,8 +534,8 @@ static int LValueStrides(Strider *strider)
       strides[iDummy]= stride;
       n= dims[iDummy++]->number;
       while (n<number) {
-	strides[iDummy]= stride*n;
-	n*= dims[iDummy++]->number;
+        strides[iDummy]= stride*n;
+        n*= dims[iDummy++]->number;
       }
     }
   }
@@ -566,25 +566,25 @@ static long BuildRange(LValue *result)
       Strider *strider= result->strider;
       long n= 1, total= number;
       for (; iDummy<nDummy-na ; iDummy++) {
-	if (n<total) {
-	  stride= strides[iDummy];
-	  number= dims[iDummy]->number;
-	  if (number>1) {  /* (See comments below.) */
-	    if (strider) {
-	      if (!strider->indexList &&
-		  strider->stride*strider->number == stride) {
-		strider->number*= number;
-	      } else {
-		result->strider= NewStrider(stride, number);
-		result->strider->next= strider;
-		strider= result->strider;
-	      }
-	    } else {
-	      result->strider= strider= NewStrider(stride, number);
-	    }
-	    n*= number;
-	  }
-	}
+        if (n<total) {
+          stride= strides[iDummy];
+          number= dims[iDummy]->number;
+          if (number>1) {  /* (See comments below.) */
+            if (strider) {
+              if (!strider->indexList &&
+                  strider->stride*strider->number == stride) {
+                strider->number*= number;
+              } else {
+                result->strider= NewStrider(stride, number);
+                result->strider->next= strider;
+                strider= result->strider;
+              }
+            } else {
+              result->strider= strider= NewStrider(stride, number);
+            }
+            n*= number;
+          }
+        }
       }
       return 0;
 
@@ -610,16 +610,16 @@ static long BuildRange(LValue *result)
     if (result->strider) {
       Strider *strider= result->strider;
       if (!strider->indexList &&
-	  strider->stride*strider->number == stride) {
-	/* If the current strider is not an index list, and its total
-	   span (stride*number) is the same as the current stride, then
-	   we can simply increment its number to include the current
-	   dimension.  */
-	strider->number*= number;
+          strider->stride*strider->number == stride) {
+        /* If the current strider is not an index list, and its total
+           span (stride*number) is the same as the current stride, then
+           we can simply increment its number to include the current
+           dimension.  */
+        strider->number*= number;
       } else {
-	/* Otherwise, we need a new strider.  */
-	result->strider= NewStrider(stride, number);
-	result->strider->next= strider;
+        /* Otherwise, we need a new strider.  */
+        result->strider= NewStrider(stride, number);
+        result->strider->next= strider;
       }
 
     } else {
@@ -656,10 +656,10 @@ static void DoRangeFuncs(Array *array)
   for (i=0 ; i<nRF ; i++) {
     if (rfs[i](array, rfIndices[i])) {
       /* This was a rank reducing operation, adjust the index numbering
-	 for any remaining range functions.  */
+         for any remaining range functions.  */
       for (j=i+1 ; j<nRF ; j++) rfIndices[j]--;
       /* Note: parser responsible for ensuring that range->rf==0
-	 whenever range->nilFlags&R_MARKED */
+         whenever range->nilFlags&R_MARKED */
       if (markedIndex>i) markedIndex--;
     }
     /* range function left result on top of stack */
@@ -672,7 +672,7 @@ static void DoRangeFuncs(Array *array)
 }
 
 static void BuildResult(char *mem, StructDef *base,
-			Array *array, Symbol *stack, int n)
+                        Array *array, Symbol *stack, int n)
 {
   LValue *result= PushDataBlock(NewLValueM(array, mem, base, tmpDims));
 
@@ -768,10 +768,10 @@ void EvalLV(Operand *op)
            will need the data)
        (3) Any actual index overreached its corresponding dummy index,
            and the LValue has strides (the overreached elements will
-	   not be at the expected address)
+           not be at the expected address)
        (4) The original LValue includes an index list (some of the
            actual indices may require extracting a subset of the index
-	   list, rather than a subset of the data array)
+           list, rather than a subset of the data array)
        (5) The original LValue references a sequential object in a
            disk file.
        (6) A rubber * index contracts two or more dimensions into one
@@ -790,9 +790,9 @@ void EvalLV(Operand *op)
     LValue *result;
 
     result= PushDataBlock(addressType?
-			  NewLValueD(lvalue->address.d, base, tmpDims) :
-			  NewLValueM(lvalue->owner, lvalue->address.m,
-				     base, tmpDims));
+                          NewLValueD(lvalue->address.d, base, tmpDims) :
+                          NewLValueM(lvalue->owner, lvalue->address.m,
+                                     base, tmpDims));
 
     if (!strider) ArrayStrides(base->size);
     /* build an appropriate LValue on top of stack */
