@@ -34,25 +34,25 @@
                            --this doesn't matter at yorick runtime
        Y_SITE         the directory where the i0/ directory can be
                            found.  This directory also contains
-			   a subdirectory i/ where distribution
-			   include files are kept.
+                           a subdirectory i/ where distribution
+                           include files are kept.
                            Codger records this directory in a data
                            statement.  However, Yorick will ignore the
                            compiled in value if a soft link called
-			   yorick.site is present in the directory
-			   in which its executable resides.
+                           yorick.site is present in the directory
+                           in which its executable resides.
        pkg.i [pkg2.i ...]  the package include file(s) for the code in
                            this development directory (see PKG-note)
        other.i [other2.i ... ]  package include file(s) for other
                            packages you would like built into this
-			   version of Yorick.
+                           version of Yorick.
        f_linkage
               FORTRAN linkage options.  Override the default FORTRAN
-	      linkage convention on this platform.  Possible values are
-	      f_linkage (lower case), F_LINKAGE (upper case), f_linkage_
-	      (lower case, trailing underscore), or F_LINKAGE_
-	      (upper case, trailing underscore).  This should be avoided,
-	      but your platform may have multiple linkage conventions.
+              linkage convention on this platform.  Possible values are
+              f_linkage (lower case), F_LINKAGE (upper case), f_linkage_
+              (lower case, trailing underscore), or F_LINKAGE_
+              (upper case, trailing underscore).  This should be avoided,
+              but your platform may have multiple linkage conventions.
 
     In addition to initializing the built-in functions, the Codger-
     generated data in ycode.c initializes the default path Yorick will
@@ -157,6 +157,7 @@ char lineBuf[MAX_LINE];
 char yorick_include[MAX_LINE];
 char yorick_contrib[MAX_LINE];
 char yorick_startup[MAX_LINE];
+char yorick_i0[MAX_LINE];
 
 /*--------------------------------------------------------------------------*/
 
@@ -201,32 +202,38 @@ int main(int argc, char *argv[])
   int i;
 
   /* crack the command line */
+  yorick_i0[0] = '\0';
   if (argc) { argc--; argv++; }
   while (argc-- && (arg= *argv++)) {
     if (arg[0]=='-') {
       arg++;
       if (!arg[0]) {
-	if (!yorick_site || !yorick_home) {
-	  fprintf(stderr, "codger: Y_HOME Y_SITE must precede - option\n");
-	  exit(1);
-	}
-	do_other= 1;
+        if (!yorick_site || !yorick_home) {
+          fprintf(stderr, "codger: Y_HOME Y_SITE must precede - option\n");
+          exit(1);
+        }
+        do_other= 1;
 
       } else if (arg[0]=='D') {
-	arg++;
-	if (strcmp(arg, "f_linkage")==0) FortranID= &LCFortran;
-	else if (strcmp(arg, "f_linkage_")==0) FortranID= &LC_Fortran;
-	else if (strcmp(arg, "F_LINKAGE")==0) FortranID= &UCFortran;
-	else if (strcmp(arg, "F_LINKAGE_")==0) FortranID= &UC_Fortran;
-	else {
-	  fprintf(stderr,
-		  "codger: unrecognized FORTRAN linkage -F%s\n", arg);
-	  exit(1);
-	}
+        arg++;
+        if (strcmp(arg, "f_linkage")==0) FortranID= &LCFortran;
+        else if (strcmp(arg, "f_linkage_")==0) FortranID= &LC_Fortran;
+        else if (strcmp(arg, "F_LINKAGE")==0) FortranID= &UCFortran;
+        else if (strcmp(arg, "F_LINKAGE_")==0) FortranID= &UC_Fortran;
+        else {
+          fprintf(stderr,
+                  "codger: unrecognized FORTRAN linkage -F%s\n", arg);
+          exit(1);
+        }
+
+      } else if (arg[0]=='i' && arg[1]=='0' && arg[2]=='=') {
+        strncat(yorick_i0, &arg[3], MAX_LINE-1);
+        i = strlen(yorick_i0);
+        if (yorick_i0[i-1] == DIR_SEP) yorick_i0[i-1] = '\0';
 
       } else {
-	fprintf(stderr, "codger: unrecognized option -%s\n", arg);
-	exit(1);
+        fprintf(stderr, "codger: unrecognized option -%s\n", arg);
+        exit(1);
       }
 
     } else if (!yorick_home) {
@@ -237,26 +244,26 @@ int main(int argc, char *argv[])
 
     } else if (!do_other) {
       if (n_pkg >= MAX_PACKAGES-1) {
-	fprintf(stderr,
-		"codger: exceeded limit of %d pkg.i files\n", MAX_PACKAGES);
-	exit(1);
+        fprintf(stderr,
+                "codger: exceeded limit of %d pkg.i files\n", MAX_PACKAGES);
+        exit(1);
       }
       /* this hack simplifies the Yorick Makefile */
       if (strcmp(arg,"std.i") && strcmp(arg,"graph.i"))
-	pkg_name[n_pkg++]= check_fallback(arg);
+        pkg_name[n_pkg++]= check_fallback(arg);
 
     } else {
       if (n_other >= MAX_OTHERS-1) {
-	fprintf(stderr,
-		"codger: exceeded limit of %d other.i files\n", MAX_OTHERS);
-	exit(1);
+        fprintf(stderr,
+                "codger: exceeded limit of %d other.i files\n", MAX_OTHERS);
+        exit(1);
       }
       other_name[n_other++]= check_fallback(arg);
     }
   }
   if (!yorick_site || !yorick_home) {
     fprintf(stderr, "codger: Usage\n"
-	   "        codger [-Df_linkage] home site [pkg.i [pkg2.i ...]]\n"
+           "        codger [-Df_linkage] home site [pkg.i [pkg2.i ...]]\n"
            "               [- other.i [other2.i ...]]\n");
     exit(1);
   }
@@ -278,22 +285,22 @@ int main(int argc, char *argv[])
     exit(1);
   }
   fprintf(ycode_file,
-	  "/* YCODE.C   generated by Codger to initialize Yorick */\n\n");
+          "/* YCODE.C   generated by Codger to initialize Yorick */\n\n");
   fprintf(ycode_file,
-	  "/* Package(s) specific to this version of Yorick:\n");
+          "/* Package(s) specific to this version of Yorick:\n");
   for (i=0 ; i<n_pkg ; i++)
     fprintf(ycode_file, "     (%d)  %s\n", i+1, pkg_name[i]);
   fprintf(ycode_file, " */\n");
   fprintf(ycode_file,
-	  "/* Other package(s) loaded into this version of Yorick:\n");
+          "/* Other package(s) loaded into this version of Yorick:\n");
   for (i=0 ; i<n_other ; i++)
     fprintf(ycode_file, "     (%d)  %s\n", i+1, other_name[i]);
   fprintf(ycode_file, " */\n");
   fprintf(ycode_file,
-	  "/* Yorick default Y_HOME directory:\n");
+          "/* Yorick default Y_HOME directory:\n");
   fprintf(ycode_file, "     %s\n */\n\n", yorick_home);
   fprintf(ycode_file,
-	  "/* Yorick default Y_SITE directory:\n");
+          "/* Yorick default Y_SITE directory:\n");
   fprintf(ycode_file, "     %s\n */\n\n", yorick_site);
   fprintf(ycode_file, "#include \"ydata.h\"\n\n");
 
@@ -374,10 +381,13 @@ void Process(char *name, int wrap)
   } else {
     file= OpenInput((char *)0, name);
     if (!file) {
-      file= OpenInput(yorick_startup, name);
+      if (yorick_i0[0]) file= OpenInput(yorick_i0, name);
       if (!file) {
-	file= OpenInput(yorick_contrib, name);
-	if (!file) file= OpenInput(FALLBACK_STARTUP, name);
+        file= OpenInput(yorick_startup, name);
+        if (!file) {
+          file= OpenInput(yorick_contrib, name);
+          if (!file) file= OpenInput(FALLBACK_STARTUP, name);
+        }
       }
     }
   }
@@ -472,8 +482,8 @@ void ScanInput(FILE *file, int wrap)
     line= SkipWhite(line);
     if (strncmp(line, "extern", 6L)==0) {
       /* "extern currentName" will cause the BuiltIn function Y_currentName
-	 to be declared in ycode.c, unless a subsequent reshape overrides
-	 this default behavior before the next extern */
+         to be declared in ycode.c, unless a subsequent reshape overrides
+         this default behavior before the next extern */
       line+= 6;
       if (line[0]==' ' || line[0]=='\t') SetNewName(line);
 
@@ -484,27 +494,27 @@ void ScanInput(FILE *file, int wrap)
 
     } else if (currentName[0]) {
       if (line[0]=='/' && line[1]=='*') {
-	line= SkipWhite(line+2);
-	if (wrap && strncmp(line, "PROTOTYPE", 9L)==0) {
-	  /* special PROTOTYPE comment generates wrapper code */
-	  if (MakeWrapper(line+9, file)) break;
-	} else if (strncmp(line, "EXTERNAL", 8L)==0) {
-	  MakeExternal(line+8);
-	}
+        line= SkipWhite(line+2);
+        if (wrap && strncmp(line, "PROTOTYPE", 9L)==0) {
+          /* special PROTOTYPE comment generates wrapper code */
+          if (MakeWrapper(line+9, file)) break;
+        } else if (strncmp(line, "EXTERNAL", 8L)==0) {
+          MakeExternal(line+8);
+        }
 
       } else if (strncmp(line, "reshape", 7L)==0) {
-	long len;
-	line= SkipWhite(line+7);
-	if (line[0]!=',') continue;
-	line= SkipWhite(line+1);
-	len= strlen(currentName);
-	if (strncmp(line, currentName, len)==0) {
-	  /* "reshape, currentName, type, dims" causes the variable
-	     y_currentName to be declared in ycode.c */
-	  line= SkipWhite(line+len);
-	  if (line[0]!=',') continue;
-	  MakeLValue(line+1);
-	}
+        long len;
+        line= SkipWhite(line+7);
+        if (line[0]!=',') continue;
+        line= SkipWhite(line+1);
+        len= strlen(currentName);
+        if (strncmp(line, currentName, len)==0) {
+          /* "reshape, currentName, type, dims" causes the variable
+             y_currentName to be declared in ycode.c */
+          line= SkipWhite(line+len);
+          if (line[0]!=',') continue;
+          MakeLValue(line+1);
+        }
       }
     }
   }
@@ -516,7 +526,8 @@ void ScanInput(FILE *file, int wrap)
 
 static char *SkipWhite(char *line)
 {
-  while (*line==' ' || *line=='\t' || *line=='\n') line++;
+  while (*line==' ' || *line=='\t' || *line=='\n' ||
+         *line=='\r' || *line=='\f') line++;
   return line;
 }
 
@@ -535,8 +546,8 @@ static void SetNewName(char *line)
 
   /* Find the end of the name token, then copy it to currentName.  */
   while ((c= *line) &&
-	 ((c>='a' && c<='z') || (c>='A' && c<='Z') ||
-	  (c>='0' && c<='9') || c=='_')) line++;
+         ((c>='a' && c<='z') || (c>='A' && c<='Z') ||
+          (c>='0' && c<='9') || c=='_')) line++;
   *line= '\0';
   strcpy(currentName, name);
 }
@@ -556,8 +567,8 @@ static void WriteExtern(int typeIndex, int dimsIndex)
        extern typeList[typeIndex] currentName dimsList[dimsIndex];   */
     int lvl= lVarList;
     fprintf(ycode_file, "\nextern %s %s%s;\n",
-	    typeList[typeIndex], currentName,
-	    dimsIndex>=0? dimsList[dimsIndex] : "");
+            typeList[typeIndex], currentName,
+            dimsIndex>=0? dimsList[dimsIndex] : "");
     AddString(&varList, &lvl, currentName);
     AddString(&varList2, &lVarList, currentName);
   }
@@ -656,12 +667,12 @@ static int AddBasic(char ***plist, int *plList, char *string)
     if (iType<0) {
       iType= AddString(plist, plList, string);
       if (i==I_COMPLEX) {
-	fprintf(ycode_file,
-		"typedef struct complex {double re, im;} complex;\n");
+        fprintf(ycode_file,
+                "typedef struct complex {double re, im;} complex;\n");
       } else if (i==I_STRING) {
-	fprintf(ycode_file, "typedef char *string;\n");
+        fprintf(ycode_file, "typedef char *string;\n");
       } else if (i==I_POINTER) {
-	fprintf(ycode_file, "typedef void *pointer;\n");
+        fprintf(ycode_file, "typedef void *pointer;\n");
       }
     }
   } else {
@@ -680,12 +691,12 @@ static void MakeLValue(char *line)
   /* Currently at location marked by ^ in source line:
         reshape, currentName,^ type, dims;               */
   int iType, iDims;
-  if (!(line= strtok(line, " \t\n,;")) ||
+  if (!(line= strtok(line, " \t\n\r\f,;")) ||
       ((iType= FindString(typeList, lTypeList, line))<0 &&
        (iType= AddBasic(&typeList, &lTypeList, line))<0)) {
     fprintf(stderr,
-	    "codger: **WARNING** variable %s has undefined type %s\n",
-	    currentName, line? line : "<garbled reshape>");
+            "codger: **WARNING** variable %s has undefined type %s\n",
+            currentName, line? line : "<garbled reshape>");
     return;
   }
 
@@ -699,7 +710,7 @@ static void MakeLValue(char *line)
 
 static int ReverseDims(char *dims)
 {
-  char *token= strtok((char *)0, " \t\n,;");
+  char *token= strtok((char *)0, " \t\n\r\f,;");
   if (token && token[0]!='/') {  /* terminates at open comment */
     ReverseDims(dims);
     sprintf(dims+strlen(dims), "[%s]", token);
@@ -721,6 +732,7 @@ static int MakeStruct(char *line, FILE *file)
 
   /* get struct name */
   for (mark=token ; *mark && *mark!=' ' && *mark!='\t' && *mark!='\n' &&
+                    *mark!='\r' && *mark!='\f' && 
                     *mark!='{' && *mark!='/' ; mark++);
   name[0]= '\0';
   strncat(name, token, mark-token);
@@ -729,13 +741,14 @@ static int MakeStruct(char *line, FILE *file)
   if (line && line[0]=='{') {
     AddString(&typeList, &lTypeList, name);
     fprintf(ycode_file, "\ntypedef struct %s %s;\nstruct %s {\n",
-	    name, name, name);
+            name, name, name);
     line= SkipComments(line+1, file);
 
     while (line && line[0]!='}') {
       /* get the data type for this member or member group */
       for (mark=line ;
-	   *mark && *mark!=' ' && *mark!='\t' && *mark!='\n' ; mark++);
+           *mark && *mark!=' ' && *mark!='\t' && *mark!='\n' &&
+             *mark!='\r' && *mark!='\f' ; mark++);
       *mark= '\0';
       if (strcmp(line, "string")==0) strcpy(type, "char*");
       else if (strcmp(line, "pointer")==0) strcpy(type, "void*");
@@ -743,19 +756,20 @@ static int MakeStruct(char *line, FILE *file)
       line= SkipWhite(mark+1);
 
       for (;;) {
-	/* get the name of this member */
-	for (mark=line ;
-	     *mark && *mark!=' ' && *mark!='\t' && *mark!='\n' &&
-	     *mark!=',' && *mark!=';' && *mark!='(' ; mark++);
-	name[0]= '\0';
-	strncat(name, line, mark-line);
-	fprintf(ycode_file, "  %s %s", type, name); /* start member */
-	line= SkipWhite(mark);
-	if (*line=='(') line= PutDimlist(line+1, file);
-	fprintf(ycode_file, ";\n");                 /* finish member */
-	if (!line || !(line= SkipComments(line, file)) ||
-	    line[0]!=',') break;
-	line= SkipComments(line+1, file);
+        /* get the name of this member */
+        for (mark=line ;
+             *mark && *mark!=' ' && *mark!='\t' && *mark!='\n' &&
+               *mark!='\r' && *mark!='\f' && 
+               *mark!=',' && *mark!=';' && *mark!='(' ; mark++);
+        name[0]= '\0';
+        strncat(name, line, mark-line);
+        fprintf(ycode_file, "  %s %s", type, name); /* start member */
+        line= SkipWhite(mark);
+        if (*line=='(') line= PutDimlist(line+1, file);
+        fprintf(ycode_file, ";\n");                 /* finish member */
+        if (!line || !(line= SkipComments(line, file)) ||
+            line[0]!=',') break;
+        line= SkipComments(line+1, file);
       }
 
       /* skip semicolon after member declaration, if present */
@@ -777,7 +791,7 @@ static char *PutDimlist(char *line, FILE *file)
 
   len= strtol(line, (char **)0, 0);
   while (*line && *line!=',' && *line!=')' && *line!=':' &&
-	 *line!='/') line++;
+         *line!='/') line++;
   if (!*line || *line=='/') line= SkipComments(line, file);
 
   if (line && *line==':') {
@@ -812,13 +826,13 @@ static char *SkipComments(char *line, FILE *file)
       /* first token begins comment -- skip to matching end */
       line+= 2;
       for (;;) {
-	while (!*line) {
-	  line= fgets(lineBuf, MAX_LINE, file);
-	  if (!line) return 0;
-	}
-	if (*line++=='*') {
-	  if (*line=='/') break;
-	}
+        while (!*line) {
+          line= fgets(lineBuf, MAX_LINE, file);
+          if (!line) return 0;
+        }
+        if (*line++=='*') {
+          if (*line=='/') break;
+        }
       }
       line++;
 
@@ -846,7 +860,7 @@ static void MakeExternal(char *line)
     isFortran= 0;
   }
 
-  name= strtok(line, " \t\n*;");
+  name= strtok(line, " \t\n\r\f*;");
   if (isFortran) {
     namewk[0]= '\0';
     strncat(namewk, name, 78L);
@@ -905,7 +919,7 @@ static int MakeWrapper(char *line, FILE *file)
       prevDelimiter=='(' || prevDelimiter==',' || prevDelimiter==')') {
   fail:
     fprintf(stderr,
-	    "codger: garbled PROTOTYPE comment for %s\n", currentName);
+            "codger: garbled PROTOTYPE comment for %s\n", currentName);
     exit(1);
   }
 
@@ -949,12 +963,12 @@ static int MakeWrapper(char *line, FILE *file)
   /* define the wrapper routine */
   if (nArgs>0) {
     fprintf(ycode_file, "void Y_%s(int nArgs)\n{\n  "
-	    "if (nArgs!=%d) YError(\"%s takes exactly %d arguments\");\n",
-	    currentName, nArgs, currentName, nArgs);
+            "if (nArgs!=%d) YError(\"%s takes exactly %d arguments\");\n",
+            currentName, nArgs, currentName, nArgs);
   } else {
     fprintf(ycode_file, "void Y_%s(int nArgs)\n{\n  "
-	    "if (nArgs>1) YError(\"%s takes at most one nil argument\");\n",
-	    currentName, currentName);
+            "if (nArgs>1) YError(\"%s takes at most one nil argument\");\n",
+            currentName, currentName);
   }
   if (type>0) fprintf(ycode_file, "  %s\n", pushRoutine[type]);
   fprintf(ycode_file, "  %s(", name);
@@ -991,12 +1005,12 @@ static char *NextProtok(char *line, FILE *file)
   }
   if (!beginScan || strncmp(beginScan, "*/", 2L)==0) {
     fprintf(stderr, "codger: PROTOTYPE comment for %s ends too soon\n",
-	    currentName);
+            currentName);
     exit(1);
   }
 
   token= beginScan;
-  len= strcspn(token, "(,) \t\n");
+  len= strcspn(token, "(,) \t\n\r\f");
   beginScan+= len;
   prevDelimiter= *beginScan;
   beginScan[0]= '\0';
@@ -1024,7 +1038,7 @@ static short TypeToken(char *token, FILE *file, int isArg)
        Could handle arbitrary types someday by passing typename */
   badt:
     fprintf(stderr, "codger: PROTOTYPE comment for %s uses illegal type\n",
-	    currentName);
+            currentName);
     exit(1);
   }
 
@@ -1035,12 +1049,12 @@ static short TypeToken(char *token, FILE *file, int isArg)
     token= NextProtok((char *)0, file);
     if (token[0]) {
       if (strcmp(token, "array")==0) {
-	if (type==0) goto badt;  /* void array illegal */
-	if (type&16) goto badt;
-	type|= 16;
+        if (type==0) goto badt;  /* void array illegal */
+        if (type&16) goto badt;
+        type|= 16;
       } else {
-	if (gotname) goto badt;
-	gotname= 1;
+        if (gotname) goto badt;
+        gotname= 1;
       }
     } else {
       break;
