@@ -15,9 +15,9 @@
 #include <string.h>
 
 extern int YpReCompare(Function *func,
-		       Symbol *consts, long nConsts, int nPos, int nKey,
-		       int nLocal, long hasPL, int maxStackDepth,
-		       Instruction *code, long codeSize);
+                       Symbol *consts, long nConsts, int nPos, int nKey,
+                       int nLocal, long hasPL, int maxStackDepth,
+                       Instruction *code, long codeSize);
 
 /* ------------------------------------------------------------------------ */
 
@@ -361,7 +361,7 @@ static int GetCString(char *q)
 }
 
 static Instruction *PrintInstruction(int iAction, int category,
-				     Instruction *pc, long ipc, int stack);
+                                     Instruction *pc, long ipc, int stack);
 
 void Y_disassemble(int nArgs)
 {
@@ -378,9 +378,9 @@ void Y_disassemble(int nArgs)
   if (!f || sp->ops!=&dataBlockSym || f->ops!=&functionOps) {
     if (!f || f->ops==&voidOps) {
       if (!HashFind(&globalTable, "*main*", 0L) ||
-	  globTab[hashIndex].ops!=&dataBlockSym ||
-	  (f= (Function *)globTab[hashIndex].value.db)->ops!=&functionOps)
-	YError("no *main* for disassemble");
+          globTab[hashIndex].ops!=&dataBlockSym ||
+          (f= (Function *)globTab[hashIndex].value.db)->ops!=&functionOps)
+        YError("no *main* for disassemble");
     } else {
       YError("disassemble argument is not a function");
     }
@@ -389,7 +389,7 @@ void Y_disassemble(int nArgs)
 
   if (CalledAsSubroutine()) {
     PrintInit(YputsOut);
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
   } else {
     PrintInit(&PutsAsArray);
     PushDataBlock(NewArray(&stringStruct, (Dimension *)0));
@@ -413,8 +413,8 @@ void Y_disassemble(int nArgs)
     pc= PrintInstruction(iAction, category, pc, ipc, stack);
     if (Action==&Branch && stack>0) {
       /* This must be ? ... <this branch>: ... construction.
-	 The stack is now one deeper than it was at the ? branch,
-	 so we need to decrement it here...  */
+         The stack is now one deeper than it was at the ? branch,
+         so we need to decrement it here...  */
       stack--;
     }
 
@@ -428,14 +428,14 @@ void Y_disassemble(int nArgs)
   } else {
     iAction= LookupAction(Action);
     sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	    vmMeaning[iAction].actionName);
+            vmMeaning[iAction].actionName);
     PrintFunc(lineBuf);
   }
   ForceNewline();
 }
 
 static Instruction *PrintInstruction(int iAction, int category,
-				     Instruction *pc, long ipc, int stack)
+                                     Instruction *pc, long ipc, int stack)
 {
   long displace;
   int flag;
@@ -445,55 +445,55 @@ static Instruction *PrintInstruction(int iAction, int category,
     if (SPECIAL_CATEGORY(category)==IS_ALT_FORM) {
       flag= (pc->Action==&Push0);
       sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	      vmMeaning[iAction].actionName, flag? "&&" : "||");
+              vmMeaning[iAction].actionName, flag? "&&" : "||");
     } else {
       sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	      vmMeaning[iAction].actionName);
+              vmMeaning[iAction].actionName);
     }
     break;
   case PC_INTEGER:
     sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	    vmMeaning[iAction].actionName, (pc++)->constant->value.l);
+            vmMeaning[iAction].actionName, (pc++)->constant->value.l);
     break;
   case PC_REAL:
     sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	    vmMeaning[iAction].actionName, (pc++)->constant->value.d);
+            vmMeaning[iAction].actionName, (pc++)->constant->value.d);
     break;
   case PC_STRING:
     flag= GetCString(((Array *)(pc++)->constant->value.db)->value.q[0]);
     sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	    vmMeaning[iAction].actionName, stringBuf, (flag? "..." : ""));
+            vmMeaning[iAction].actionName, stringBuf, (flag? "..." : ""));
     break;
   case PC_INDEX:
     if (SPECIAL_CATEGORY(category)==IS_ALT_FORM) {
       sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	      vmMeaning[iAction].actionName);
-      pc++;			/* index of *va* variable */
+              vmMeaning[iAction].actionName);
+      pc++;                     /* index of *va* variable */
     } else {
       sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	      vmMeaning[iAction].actionName,
-	      globalTable.names[(pc++)->index]);
+              vmMeaning[iAction].actionName,
+              globalTable.names[(pc++)->index]);
     }
     break;
   case PC_COUNT:
     if (SPECIAL_CATEGORY(category)==IS_ALT_FORM) {
       flag= (pc++)->count;
       sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	      vmMeaning[iAction].actionName,
-	      flag==R_MARKED? "+:" : flag==R_PSEUDO? "-:" : "..");
+              vmMeaning[iAction].actionName,
+              flag==R_MARKED? "+:" : flag==R_PSEUDO? "-:" : "..");
     } else {
       sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	      vmMeaning[iAction].actionName, (pc++)->count);
+              vmMeaning[iAction].actionName, (pc++)->count);
     }
     break;
   case PC_DISPLACE:
     displace= (pc++)->displace;
     sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	    vmMeaning[iAction].actionName, ipc+1+displace);
+            vmMeaning[iAction].actionName, ipc+1+displace);
     break;
   case PC_RF:
     sprintf(lineBuf, vmMeaning[iAction].fullFormat, ipc, stack,
-	    vmMeaning[iAction].actionName, GetRFName((pc++)->rf));
+            vmMeaning[iAction].actionName, GetRFName((pc++)->rf));
     break;
   }
 
@@ -512,9 +512,9 @@ extern int ypReMatch;
    As a side effect, the pc values (even elements) of ypReList are
    adjusted to reflect their values in the finished function.  */
 int YpReCompare(Function *func,
-		Symbol *consts, long nConsts, int nPos, int nKey,
-		int nLocal, long hasPL, int maxStackDepth,
-		Instruction *code, long codeSize)
+                Symbol *consts, long nConsts, int nPos, int nKey,
+                int nLocal, long hasPL, int maxStackDepth,
+                Instruction *code, long codeSize)
 {
   int match;
   long frameSize= 1+nPos+(hasPL&1)+nKey+nLocal;
@@ -527,8 +527,8 @@ int YpReCompare(Function *func,
   for (i=0 ; i<nYpReList ; i+=2) ypReList[i]+= frameSize;
 
   match= (func->nPos==nPos && func->nKey==nKey && func->nLocal==nLocal &&
-	  func->hasPosList==hasPL && func->nConstants==nConsts &&
-	  func->nReq==frameSize+maxStackDepth+2);
+          func->hasPosList==hasPL && func->nConstants==nConsts &&
+          func->nReq==frameSize+maxStackDepth+2);
 
   if (match) {
     codeSize-= frameSize-1;
@@ -551,16 +551,16 @@ int YpReCompare(Function *func,
     match= (match && ops==fconsts->ops);
     if (ops==&dataBlockSym) {
       if (match) {
-	char *q1= ((Array *)consts[i].value.db)->value.q[0];
-	char *q2= ((Array *)fconsts->value.db)->value.q[0];
-	match= (q1==0 || q2==0)? q1==q2 : strcmp(q1,q2)==0;
+        char *q1= ((Array *)consts[i].value.db)->value.q[0];
+        char *q2= ((Array *)fconsts->value.db)->value.q[0];
+        match= (q1==0 || q2==0)? q1==q2 : strcmp(q1,q2)==0;
       }
       Unref(consts[i].value.db);
     } else if (match) {
       if (ops==&longScalar)
-	match= (consts[i].value.l==fconsts->value.l);
+        match= (consts[i].value.l==fconsts->value.l);
       else if (ops==&doubleScalar)
-	match= (consts[i].value.d==fconsts->value.d);
+        match= (consts[i].value.d==fconsts->value.d);
     }
     if (match) fconsts++;
   }
@@ -577,7 +577,7 @@ struct DebugBlk {
   int references;      /* reference counter */
   Operations *ops;     /* virtual function table */
   Function *func;      /* the function being debugged --
-			  NO increment of func->references, since on stack */
+                          NO increment of func->references, since on stack */
   long pcerr;          /* pc at which error was detected */
   char *errFile;       /* full filename in which source resides */
   long *pcList;        /* list of pc values where stack is empty */
@@ -599,7 +599,7 @@ extern int yAutoDebug;
 extern char *MakeErrorLine(long lineNumber, const char *filename);
 
 extern DebugBlk *NewDebugBlk(Function *f, long pcerr, char *errFile,
-			     long lnum);
+                             long lnum);
 extern void FreeDebugBlk(void *dbug);
 
 static long FindErrLine(DebugBlk *dbg);
@@ -661,7 +661,7 @@ DebugBlk *NewDebugBlk(Function *f, long pcerr, char *errFile, long lnum)
 
   /* count number of logical lines (where stack drops to zero) */
   pcerr--;  /* also try to zero in on pc where error occurred --
-	       pc was incremented in YRun before calling Action */
+               pc was incremented in YRun before calling Action */
   n= 1;
   stack= 0;
   while ((Action= (pc++)->Action)) {
@@ -675,8 +675,8 @@ DebugBlk *NewDebugBlk(Function *f, long pcerr, char *errFile, long lnum)
     }
     if (Action==&Branch && stack>0) {
       /* This must be ? ... <this branch>: ... construction.
-	 The stack is now one deeper than it was at the ? branch,
-	 so we need to decrement it here...  */
+         The stack is now one deeper than it was at the ? branch,
+         so we need to decrement it here...  */
       stack--;
     }
   }
@@ -704,8 +704,8 @@ DebugBlk *NewDebugBlk(Function *f, long pcerr, char *errFile, long lnum)
     }
     if (Action==&Branch && stack>0) {
       /* This must be ? ... <this branch>: ... construction.
-	 The stack is now one deeper than it was at the ? branch,
-	 so we need to decrement it here...  */
+         The stack is now one deeper than it was at the ? branch,
+         so we need to decrement it here...  */
       stack--;
     }
   }
@@ -725,7 +725,7 @@ DebugBlk *NewDebugBlk(Function *f, long pcerr, char *errFile, long lnum)
     YputsErr(MakeErrorLine(FindErrLine(dbg), dbg->errFile));
   } else {
     sprintf(lineBuf, "now at pc= %ld (of %ld), failed at pc= %ld",
-	    dbg->pcList[dbg->iPClist], dbg->lenCode, dbg->pcerr);
+            dbg->pcList[dbg->iPClist], dbg->lenCode, dbg->pcerr);
     if (errFile)
       YputsErr("WARNING detailed line number information unavailable");
     else
@@ -781,7 +781,7 @@ static DebugBlk *FindDebugBlk(void)
 {
   Symbol *stack= sp;
   while (stack>spBottom &&
-	 (stack->ops!=&dataBlockSym || stack->value.db->ops!=&debugOps))
+         (stack->ops!=&dataBlockSym || stack->value.db->ops!=&debugOps))
     stack--;
   if (stack<=spBottom) return 0;
   return (DebugBlk *)stack->value.db;
@@ -791,14 +791,14 @@ static void AnnouncePC(DebugBlk *dbg, int dontPush)
 {
   if (dontPush==1) {
     PrintInit(YputsOut);
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
   } else if (dontPush==0) {
     PrintInit(&PutsAsArray);
     PushDataBlock(NewArray(&stringStruct, (Dimension *)0));
   }
 
   sprintf(lineBuf, "now at pc= %ld (of %ld)",
-	  dbg->pcList[dbg->iPClist], dbg->lenCode);
+          dbg->pcList[dbg->iPClist], dbg->lenCode);
   PrintFunc(lineBuf);
   ForceNewline();
   if (dbg->errFile && dbg->pcLine) {
@@ -859,7 +859,7 @@ void Y_dbret(int nArgs)
   DebugBlk *dbg= FindDebugBlk();
   if (!dbg) YError("dbret cannot find debug block");
   if (nArgs>1) YError("dbret takes 0 or 1 argument");
-  if (nArgs<1) PushDataBlock(Ref(&nilDB));
+  if (nArgs<1) PushDataBlock(RefNC(&nilDB));
 
   /* temporarily remove return value from top of stack --
      save pointer back to it as a failsafe */
@@ -938,7 +938,7 @@ void Y_dbinfo(int nArgs)
 
   if (CalledAsSubroutine()) {
     PrintInit(YputsOut);
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
   } else {
     PrintInit(&PutsAsArray);
     PushDataBlock(NewArray(&stringStruct, (Dimension *)0));
@@ -969,7 +969,7 @@ void Y_dbdis(int nArgs)
 
   if (CalledAsSubroutine()) {
     PrintInit(YputsOut);
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
   } else {
     PrintInit(&PutsAsArray);
     PushDataBlock(NewArray(&stringStruct, (Dimension *)0));
@@ -989,8 +989,8 @@ void Y_dbdis(int nArgs)
     if (stack<=0) lastPass= 1;
     if (Action==&Branch && stack>0) {
       /* This must be ? ... <this branch>: ... construction.
-	 The stack is now one deeper than it was at the ? branch,
-	 so we need to decrement it here...  */
+         The stack is now one deeper than it was at the ? branch,
+         so we need to decrement it here...  */
       stack--;
     }
 
