@@ -144,7 +144,7 @@ void PushNil(void)
 {
   Symbol *spp= sp+1;
   spp->ops= &dataBlockSym;
-  spp->value.db= Ref(&nilDB);
+  spp->value.db= RefNC(&nilDB);
   sp= spp;
 }
 
@@ -309,14 +309,14 @@ void Build(void)
       YError("non-array argument to build array operator [...]");
     if (i) {
       if (Conform(buildDims, buildOps[i].type.dims) & 4)
-	YError("non-conformable arguments to build array operator [...]");
+        YError("non-conformable arguments to build array operator [...]");
       FreeDimension(buildDims);
       buildDims= Ref(tmpDims);
       if (buildOps[i].type.base==base || ops->promoteID<=T_COMPLEX) {
-	if (ops->promoteID!=promoteID) needPromote= 1;
-	if (ops->promoteID>promoteID) promoteID= ops->promoteID;
+        if (ops->promoteID!=promoteID) needPromote= 1;
+        if (ops->promoteID>promoteID) promoteID= ops->promoteID;
       } else {
-	YError("mixed struct/pointer/string arguments to [...]");
+        YError("mixed struct/pointer/string arguments to [...]");
       }
     } else {
       FreeDimension(buildDims);
@@ -330,7 +330,7 @@ void Build(void)
   if (needPromote) {
     Operand phony;
     phony.ops= 0;   /* Promote will return this, but the result of Promote
-		       is dicarded here, so no need to properly initialize */
+                       is dicarded here, so no need to properly initialize */
     for (i=0 ; i<nArgs ; i++) {
       buildOps[i].ops->Promote[promoteID](&buildOps[i], &phony);
       first[i].ops->FormOperand(&first[i], &buildOps[i]);
@@ -339,7 +339,7 @@ void Build(void)
 
   /* create result array on top of stack */
   result= PushDataBlock(NewArray(buildOps[0].type.base,
-		  NewDimension(nArgs, 1L, Ref(buildDims))));
+                  NewDimension(nArgs, 1L, Ref(buildDims))));
   result->type.dims->references--;
 
   /* copy each component of result into place */
@@ -347,7 +347,7 @@ void Build(void)
   size= result->type.base->size*result->type.number/nArgs;
   for (i=0 ; i<nArgs ; i++) {
     Broadcast(rslt, buildDims, buildOps[i].value, buildOps[i].type.dims,
-	      buildOps[i].type.base);
+              buildOps[i].type.base);
     rslt+= size;
   }
 
@@ -462,25 +462,25 @@ void opname(Operand *lop, Operand *rop) \
   if (lx>1) { typd *dkji=dst; lx0=lx&3; mx*=jx; \
     for (i=0 ; i<ix ; i++,rv+=mx) { \
       for (j=0,lvj=lv,rvj=rv ; j<jx ; j++,rvj++,lvj=lv) { \
-	for (k=0 ; k<kx ; k++,dst=dkji) { \
-	  for (l=0 ; l<lx0 ; l++,dkji++) dkji[0]= 0; \
-	  for ( ; l<lx ; l+=4,dkji+=4) \
-	    dkji[0]= dkji[1]= dkji[2]= dkji[3]= 0; \
-	  for (mr=0,dkji=dst ; mr<mx ; mr+=jx) { \
-	    dkji= dst;  rv0= rvj[mr]; \
-	    for (l=0 ; l<lx0 ; l++,dkji++,lvj++) \
-	      dkji[0]+= lvj[0]*rv0; \
-	    for ( ; l<lx ; l+=4,dkji+=4,lvj+=4) { \
-	      dkji[0]+= lvj[0]*rv0;  dkji[1]+= lvj[1]*rv0; \
-	      dkji[2]+= lvj[2]*rv0;  dkji[3]+= lvj[3]*rv0; }}}}} \
+        for (k=0 ; k<kx ; k++,dst=dkji) { \
+          for (l=0 ; l<lx0 ; l++,dkji++) dkji[0]= 0; \
+          for ( ; l<lx ; l+=4,dkji+=4) \
+            dkji[0]= dkji[1]= dkji[2]= dkji[3]= 0; \
+          for (mr=0,dkji=dst ; mr<mx ; mr+=jx) { \
+            dkji= dst;  rv0= rvj[mr]; \
+            for (l=0 ; l<lx0 ; l++,dkji++,lvj++) \
+              dkji[0]+= lvj[0]*rv0; \
+            for ( ; l<lx ; l+=4,dkji+=4,lvj+=4) { \
+              dkji[0]+= lvj[0]*rv0;  dkji[1]+= lvj[1]*rv0; \
+              dkji[2]+= lvj[2]*rv0;  dkji[3]+= lvj[3]*rv0; }}}}} \
   } else { long mjx=jx*mx, jx2=jx+jx, jx3=jx2+jx; lx=jx3+jx; lx0=mx&3; \
     for (i=0 ; i<ix ; i++,rv+=mjx) { \
       for (j=0,lvj=lv,rvj=rv ; j<jx ; j++,rvj++,lvj=lv) { \
-	for (k=0 ; k<kx ; k++,dst++) { \
-	  rv0= 0; \
-	  for (mr=l=0 ; l<lx0 ; l++,mr+=jx,lvj++) rv0+= lvj[0]*rvj[mr]; \
-	  for ( ; l<mx ; l+=4,mr+=lx,lvj+=4) \
-	    rv0+= lvj[0]*rvj[mr]+lvj[1]*rvj[mr+jx]+ \
+        for (k=0 ; k<kx ; k++,dst++) { \
+          rv0= 0; \
+          for (mr=l=0 ; l<lx0 ; l++,mr+=jx,lvj++) rv0+= lvj[0]*rvj[mr]; \
+          for ( ; l<mx ; l+=4,mr+=lx,lvj+=4) \
+            rv0+= lvj[0]*rvj[mr]+lvj[1]*rvj[mr+jx]+ \
                   lvj[2]*rvj[mr+jx2]+lvj[3]*rvj[mr+jx3]; \
           dst[0]= rv0; }}}} \
   Popper(sp-3); }
@@ -504,26 +504,26 @@ void MatMultZ(Operand *lop, Operand *rop)
     mx*= jx;
     for (i=0 ; i<ix ; i++,rv+=mx) {
       for (j=0,lvj=lv,rvj=rv ; j<jx ; j+=2,rvj+=2,lvj=lv) {
-	for (k=0 ; k<kx ; k++,dst=dkji) {
-	  for (l=0 ; l<lx0 ; l++,dkji+=2) dkji[0]= dkji[1]= 0.0;
-	  for ( ; l<lx ; l+=4,dkji+=8)
-	    dkji[0]= dkji[1]= dkji[2]= dkji[3]=
-	      dkji[4]= dkji[5]= dkji[6]= dkji[7]= 0.0;
-	  for (mr=0 ; mr<mx ; mr+=jx) {
-	    dkji= dst;
-	    rv0= rvj[mr];  rv1= rvj[mr+1];
-	    for (l=0 ; l<lx0 ; l++,dkji+=2,lvj+=2) {
-	      dkji[0]+= lvj[0]*rv0 - lvj[1]*rv1;
-	      dkji[1]+= lvj[1]*rv0 + lvj[0]*rv1;
-	    }
-	    for ( ; l<lx ; l+=4,dkji+=8,lvj+=8) {
-	      dkji[0]+=lvj[0]*rv0-lvj[1]*rv1;  dkji[1]+=lvj[1]*rv0+lvj[0]*rv1;
-	      dkji[2]+=lvj[2]*rv0-lvj[3]*rv1;  dkji[3]+=lvj[3]*rv0+lvj[2]*rv1;
-	      dkji[4]+=lvj[4]*rv0-lvj[5]*rv1;  dkji[5]+=lvj[5]*rv0+lvj[4]*rv1;
-	      dkji[6]+=lvj[6]*rv0-lvj[7]*rv1;  dkji[7]+=lvj[7]*rv0+lvj[6]*rv1;
-	    }
-	  }
-	}
+        for (k=0 ; k<kx ; k++,dst=dkji) {
+          for (l=0 ; l<lx0 ; l++,dkji+=2) dkji[0]= dkji[1]= 0.0;
+          for ( ; l<lx ; l+=4,dkji+=8)
+            dkji[0]= dkji[1]= dkji[2]= dkji[3]=
+              dkji[4]= dkji[5]= dkji[6]= dkji[7]= 0.0;
+          for (mr=0 ; mr<mx ; mr+=jx) {
+            dkji= dst;
+            rv0= rvj[mr];  rv1= rvj[mr+1];
+            for (l=0 ; l<lx0 ; l++,dkji+=2,lvj+=2) {
+              dkji[0]+= lvj[0]*rv0 - lvj[1]*rv1;
+              dkji[1]+= lvj[1]*rv0 + lvj[0]*rv1;
+            }
+            for ( ; l<lx ; l+=4,dkji+=8,lvj+=8) {
+              dkji[0]+=lvj[0]*rv0-lvj[1]*rv1;  dkji[1]+=lvj[1]*rv0+lvj[0]*rv1;
+              dkji[2]+=lvj[2]*rv0-lvj[3]*rv1;  dkji[3]+=lvj[3]*rv0+lvj[2]*rv1;
+              dkji[4]+=lvj[4]*rv0-lvj[5]*rv1;  dkji[5]+=lvj[5]*rv0+lvj[4]*rv1;
+              dkji[6]+=lvj[6]*rv0-lvj[7]*rv1;  dkji[7]+=lvj[7]*rv0+lvj[6]*rv1;
+            }
+          }
+        }
       }
     }
   } else {
@@ -532,25 +532,25 @@ void MatMultZ(Operand *lop, Operand *rop)
     lx0= mx&3;
     for (i=0 ; i<ix ; i++,rv+=mx2) {
       for (j=0,lvj=lv,rvj=rv ; j<jx ; j+=2,rvj+=2,lvj=lv) {
-	for (k=0 ; k<kx ; k++,dst+=2) {
-	  rv0= rv1= 0;
-	  for (mr=l=0 ; l<lx0 ; l++,mr+=jx,lvj+=2) {
-	    rv0+= lvj[0]*rvj[mr]-lvj[1]*rvj[mr+1];
-	    rv1+= lvj[1]*rvj[mr]+lvj[0]*rvj[mr+1];
-	  }
-	  for ( ; l<mx ; l+=4,mr+=lx,lvj+=8) {
-	    rv0+= lvj[0]*rvj[mr]-lvj[1]*rvj[mr+1]+
-	          lvj[2]*rvj[mr+jx]-lvj[3]*rvj[mr+jx+1]+
+        for (k=0 ; k<kx ; k++,dst+=2) {
+          rv0= rv1= 0;
+          for (mr=l=0 ; l<lx0 ; l++,mr+=jx,lvj+=2) {
+            rv0+= lvj[0]*rvj[mr]-lvj[1]*rvj[mr+1];
+            rv1+= lvj[1]*rvj[mr]+lvj[0]*rvj[mr+1];
+          }
+          for ( ; l<mx ; l+=4,mr+=lx,lvj+=8) {
+            rv0+= lvj[0]*rvj[mr]-lvj[1]*rvj[mr+1]+
+                  lvj[2]*rvj[mr+jx]-lvj[3]*rvj[mr+jx+1]+
                   lvj[4]*rvj[mr+jx2]-lvj[5]*rvj[mr+jx2+1]+
-		  lvj[6]*rvj[mr+jx3]-lvj[7]*rvj[mr+jx3+1];
-	    rv1+= lvj[1]*rvj[mr]+lvj[0]*rvj[mr+1]+
-	          lvj[3]*rvj[mr+jx]+lvj[2]*rvj[mr+jx+1]+
+                  lvj[6]*rvj[mr+jx3]-lvj[7]*rvj[mr+jx3+1];
+            rv1+= lvj[1]*rvj[mr]+lvj[0]*rvj[mr+1]+
+                  lvj[3]*rvj[mr+jx]+lvj[2]*rvj[mr+jx+1]+
                   lvj[5]*rvj[mr+jx2]+lvj[4]*rvj[mr+jx2+1]+
-		  lvj[7]*rvj[mr+jx3]+lvj[6]*rvj[mr+jx3+1];
-	  }
+                  lvj[7]*rvj[mr+jx3]+lvj[6]*rvj[mr+jx3+1];
+          }
           dst[0]= rv0;
           dst[1]= rv1;
-	}
+        }
       }
     }
   }
@@ -630,9 +630,9 @@ void EvalSD(Operand *op)
     if (argOp.ops==&voidOps) {
       /* single void argument is same as zero */
       if (arg->ops==&dataBlockSym) {
-	arg->ops= &longScalar;
-	Unref(arg->value.db);
-	arg->value.l= 0;
+        arg->ops= &longScalar;
+        Unref(arg->value.db);
+        arg->value.l= 0;
       }
       argOp.ops= &longOps;
       argOp.references= 1;
@@ -649,64 +649,64 @@ void EvalSD(Operand *op)
     if (dataOps->promoteID>T_COMPLEX || argOp.ops->promoteID>T_COMPLEX) {
       int bad= 0;
       int argIsZero= (argOp.ops->promoteID<=T_LONG && !argOp.type.dims &&
-	((argOp.ops==&longOps && !((long*)argOp.value)[0]) ||
-	 (argOp.ops==&intOps && !((int*)argOp.value)[0]) ||
-	 (argOp.ops==&shortOps && !((short*)argOp.value)[0]) ||
-	 (argOp.ops==&charOps && !((char*)argOp.value)[0])));
+        ((argOp.ops==&longOps && !((long*)argOp.value)[0]) ||
+         (argOp.ops==&intOps && !((int*)argOp.value)[0]) ||
+         (argOp.ops==&shortOps && !((short*)argOp.value)[0]) ||
+         (argOp.ops==&charOps && !((char*)argOp.value)[0])));
 
       if (dataOps==&structOps && argOp.ops->isArray && argIsZero) {
-	/* initialize a zero-valued scalar instance */
-	Array *result= PushDataBlock(NewArray(base, (Dimension *)0));
-	if (base->Copy==&CopyX)
-	  memset(result->value.c, 0,
-		 result->type.number*result->type.base->size);
+        /* initialize a zero-valued scalar instance */
+        Array *result= PushDataBlock(NewArray(base, (Dimension *)0));
+        if (base->Copy==&CopyX)
+          memset(result->value.c, 0,
+                 result->type.number*result->type.base->size);
 
       } else if (argOp.ops==&structOps &&
-		 StructEqual(argOp.type.base, base)) {
-	/* equivalent but non-identical types just get copied */
-	Array *result= PushDataBlock(NewArray(base, argOp.type.dims));
-	base->Copy(base, result->value.c, argOp.value, argOp.type.number);
+                 StructEqual(argOp.type.base, base)) {
+        /* equivalent but non-identical types just get copied */
+        Array *result= PushDataBlock(NewArray(base, argOp.type.dims));
+        base->Copy(base, result->value.c, argOp.value, argOp.type.number);
 
       } else if (argIsZero &&
-		 (dataOps==&stringOps || dataOps==&pointerOps)) {
-	PushDataBlock(NewArray(base, argOp.type.dims));
+                 (dataOps==&stringOps || dataOps==&pointerOps)) {
+        PushDataBlock(NewArray(base, argOp.type.dims));
 
       } else if (dataOps==&stringOps && argOp.ops==&pointerOps) {
-	/* want to create string array from pointer array */
-	Array *result= PushDataBlock(NewArray(base, argOp.type.dims));
-	void **ptr= (void **)argOp.value;
-	char **str= result->value.q;
-	long i, n= argOp.type.number;
-	Array *array;
-	for (i=0 ; i<n ; i++) {
-	  if (ptr[i]) {
-	    array= Pointee(ptr[i]);
-	    if (array->ops!=&charOps)
-	      YError("only pointer to char can be converted to string");
-	    str[i]= p_strncat(0, ptr[i], array->type.number);
-	  }
-	}
+        /* want to create string array from pointer array */
+        Array *result= PushDataBlock(NewArray(base, argOp.type.dims));
+        void **ptr= (void **)argOp.value;
+        char **str= result->value.q;
+        long i, n= argOp.type.number;
+        Array *array;
+        for (i=0 ; i<n ; i++) {
+          if (ptr[i]) {
+            array= Pointee(ptr[i]);
+            if (array->ops!=&charOps)
+              YError("only pointer to char can be converted to string");
+            str[i]= p_strncat(0, ptr[i], array->type.number);
+          }
+        }
 
       } else if (dataOps==&pointerOps && argOp.ops==&stringOps) {
-	/* want to create pointer array from string array */
-	Array *result= PushDataBlock(NewArray(base, argOp.type.dims));
-	void **ptr= result->value.p;
-	char **str= (char **)argOp.value;
-	long len, i, n= argOp.type.number;
-	Array *array;
-	for (i=0 ; i<n ; i++) {
-	  if (str[i]) {
-	    len= strlen(str[i]);
-	    array= NewArray(&charStruct,
-			    NewDimension(len+1, 1L, (Dimension *)0));
-	    array->type.dims->references--;
-	    ptr[i]= array->value.c;
-	    strcpy(ptr[i], str[i]);
-	  }
-	}
+        /* want to create pointer array from string array */
+        Array *result= PushDataBlock(NewArray(base, argOp.type.dims));
+        void **ptr= result->value.p;
+        char **str= (char **)argOp.value;
+        long len, i, n= argOp.type.number;
+        Array *array;
+        for (i=0 ; i<n ; i++) {
+          if (str[i]) {
+            len= strlen(str[i]);
+            array= NewArray(&charStruct,
+                            NewDimension(len+1, 1L, (Dimension *)0));
+            array->type.dims->references--;
+            ptr[i]= array->value.c;
+            strcpy(ptr[i], str[i]);
+          }
+        }
 
       } else {
-	bad= 1;
+        bad= 1;
       }
       if (bad) YError("illegal data type conversion");
 
@@ -727,15 +727,15 @@ void EvalSD(Operand *op)
     char *address= result->value.c;
     if (base->Copy==&CopyX)
       memset(result->value.c, 0,
-	     result->type.number*result->type.base->size);
+             result->type.number*result->type.base->size);
     evalLV.ops= &lvalueOps;
 
     do {
       if (arg->ops)
-	YError("expecting keyword arguments to create struct instance");
+        YError("expecting keyword arguments to create struct instance");
       name= globalTable.names[arg->index];
       if (!HashFind(&base->table, name, 0L))
-	YError("keyword corresponds to no struct member name");
+        YError("keyword corresponds to no struct member name");
       index= hashIndex;  /* someday FormOperand might clobber this... */
 
       arg++;
