@@ -142,10 +142,10 @@ void Define(void)
     DataBlock *db= glob->value.db;
     if (db->ops==&lvalueOps) {
       /* Note that an explicit UnDefine operation is required in order
-	 for the interpreter to be able to ever get rid of a reference
-	 to an LValue in globTab.  This is provided as a part of a
-	 non-kernal Yorick package, since it is not a crucial feature
-	 of the language (see Y_reshape).  */
+         for the interpreter to be able to ever get rid of a reference
+         to an LValue in globTab.  This is provided as a part of a
+         non-kernal Yorick package, since it is not a crucial feature
+         of the language (see Y_reshape).  */
       DoAssign((LValue *)db, sp);
       return;
     } else {
@@ -160,7 +160,7 @@ void Define(void)
       Array *result= NewArray(array->type.base, array->type.dims);
       glob->value.db= (DataBlock *)result;
       array->type.base->Copy(array->type.base, result->value.c,
-			     array->value.c, array->type.number);
+                             array->value.c, array->type.number);
     } else {
       if (array->ops==&lvalueOps) FetchLValue(array, sp);
       glob->value.db= Ref(sp->value.db);
@@ -182,7 +182,7 @@ void OpenStruct(void)
   PushDataBlock(base);
   /* zap struct-building function */
   if (globTab[index].ops==&dataBlockSym) db= globTab[index].value.db;
-  globTab[index].value.db= Ref(&nilDB);
+  globTab[index].value.db= RefNC(&nilDB);
   globTab[index].ops= &dataBlockSym;
   Unref(db);
 }
@@ -213,36 +213,36 @@ void BuildDimList(Symbol *stack, int nArgs)
       Operand op;
       FormOperandDB(stack, &op);
       if (op.ops==&rangeOps) {
-	Range *range= op.value;
-	long len;
-	if (range->rf || range->nilFlags || range->inc!=1)
-	  YError("only min:max ranges allowed in dimension list");
-	len= range->max-range->min+1;
-	if (len<=0) goto badl;
-	tmpDims= NewDimension(len, range->min, tmpDims);
+        Range *range= op.value;
+        long len;
+        if (range->rf || range->nilFlags || range->inc!=1)
+          YError("only min:max ranges allowed in dimension list");
+        len= range->max-range->min+1;
+        if (len<=0) goto badl;
+        tmpDims= NewDimension(len, range->min, tmpDims);
 
       } else if (op.ops->promoteID<=T_LONG &&
-		 (!op.type.dims || !op.type.dims->next)) {
-	long len;
-	op.ops->ToLong(&op);
-	if (!op.type.dims) {
-	  len= *(long *)op.value;
-	  if (len<=0) goto badl;
-	  tmpDims= NewDimension(len, 1L, tmpDims);
-	} else {
-	  long *dim= op.value;
-	  long n= *dim++;
-	  if (n>10 || n>=op.type.number)
-	    YError("dimension list format [#dims, len1, len2, ...]");
-	  while (n--) {
-	    len= *dim++;
-	    if (len<=0) goto badl;
-	    tmpDims= NewDimension(len, 1L, tmpDims);
-	  }
-	}
+                 (!op.type.dims || !op.type.dims->next)) {
+        long len;
+        op.ops->ToLong(&op);
+        if (!op.type.dims) {
+          len= *(long *)op.value;
+          if (len<=0) goto badl;
+          tmpDims= NewDimension(len, 1L, tmpDims);
+        } else {
+          long *dim= op.value;
+          long n= *dim++;
+          if (n>10 || n>=op.type.number)
+            YError("dimension list format [#dims, len1, len2, ...]");
+          while (n--) {
+            len= *dim++;
+            if (len<=0) goto badl;
+            tmpDims= NewDimension(len, 1L, tmpDims);
+          }
+        }
 
       } else if (op.ops!=&voidOps) {
-	goto badl;
+        goto badl;
       }
     } else {
     badl:
@@ -305,7 +305,7 @@ int StructEqual(StructDef *l, StructDef *r)
      the same and all member types are equal */
   for (i=0 ; i<nItems ; i++)
     if (l->offsets[i]!=r->offsets[i] ||
-	!StructEqual(l->members[i].base, r->members[i].base)) return 0;
+        !StructEqual(l->members[i].base, r->members[i].base)) return 0;
   return 1;
 }
 
@@ -410,9 +410,9 @@ void Deref(void)
 
   if ((DataBlock *)pnte != &nilDB)
     sp->value.db= (DataBlock *)NewLValueM(pnte, pnte->value.c,
-					  pnte->type.base, pnte->type.dims);
+                                          pnte->type.base, pnte->type.dims);
   else
-    sp->value.db= Ref(&nilDB);
+    sp->value.db= RefNC(&nilDB);
   Unref(array);
 }
 
@@ -526,9 +526,9 @@ void GetMemberLV(Operand *op, char *name)
   else dims= Ref(lvalue->type.dims);
 
   result= PushDataBlock(addressType?
-			NewLValueD(lvalue->address.d, subbase, dims) :
-			NewLValueM(lvalue->owner, lvalue->address.m,
-				   subbase, dims));
+                        NewLValueD(lvalue->address.d, subbase, dims) :
+                        NewLValueM(lvalue->owner, lvalue->address.m,
+                                   subbase, dims));
   FreeDimension(dims);
   if (addressType) result->address.d+= offset;
   else result->address.m+= offset;
@@ -558,7 +558,7 @@ void GetMemberIO(Operand *op, char *name)
     HistoryInfo *history= file->history;
     IOStream *child= history->child;
     if (HashFind(&child->dataTable, name, 0L) &&
-	history->recNumber>=0 && history->recNumber<history->nRecords)
+        history->recNumber>=0 && history->recNumber<history->nRecords)
       file= child;
     else if (!HashFind(&file->dataTable, name, 0L))
       file= 0;
