@@ -19,9 +19,9 @@ extern void RecordSource(long index);  /* in yio.h */
 
 extern long YpLineNumber(void);
 extern int YpReCompare(Function *func,
-		       Symbol *consts, long nConsts, int nPos, int nKey,
-		       int nLocal, long hasPL, int maxStackDepth,
-		       Instruction *code, long codeSize);
+                       Symbol *consts, long nConsts, int nPos, int nKey,
+                       int nLocal, long hasPL, int maxStackDepth,
+                       Instruction *code, long codeSize);
 
 extern char *YpLitName(Literal);  /* hook for ScanForFunc in yorick.y */
 
@@ -125,7 +125,7 @@ static int loopDepth;   /* required to distinguish break/continue targets */
 typedef struct BreakStack BreakStack;
 struct BreakStack {
   int id;    /* (loopDepth<<1) & isBreak
-		tells which loop and whether break or continue */
+                tells which loop and whether break or continue */
   long pc;    /* pc of branch displacement in vmCode */
 };
 
@@ -322,7 +322,7 @@ static long LongConstant(long l)
   long i;
   for (i=0 ; i<nConstants ; i++) {
     if (constantTable[i].ops==&longScalar &&
-	constantTable[i].value.l==l) break;
+        constantTable[i].value.l==l) break;
   }
   if (i>=nConstants) {
     if (CheckConstSpace()) return 0;
@@ -340,7 +340,7 @@ static long DoubleConstant(double d)
   long i;
   for (i=0 ; i<nConstants ; i++) {
     if (constantTable[i].ops==&doubleScalar &&
-	constantTable[i].value.d==d) break;
+        constantTable[i].value.d==d) break;
   }
   if (i>=nConstants) {
     if (CheckConstSpace()) return 0;
@@ -407,7 +407,7 @@ static void WillPopStack(long n)
   int oops= 0;
   stackDepth-= n;
   while (nMatrixMarkers &&
-	 matrixMarkers[nMatrixMarkers-1].stackDepth>stackDepth) {
+         matrixMarkers[nMatrixMarkers-1].stackDepth>stackDepth) {
     nMatrixMarkers--;
     oops= 1;
   }
@@ -487,8 +487,8 @@ CodeBlock YpString(Quote q)
 static int IsPushConst(VMaction *a)
 {
   return (a==&PushChar || a==&PushShort || a==&PushInt || a==&PushLong ||
-	  a==&PushFloat || a==&PushDouble || a==&PushImaginary ||
-	  a==&PushString);
+          a==&PushFloat || a==&PushDouble || a==&PushImaginary ||
+          a==&PushString);
 }
 
 Literal YpName(char *name, long len)
@@ -544,10 +544,10 @@ void YpCheckRef(CodeBlock cb)
 }
 
 static char *rfNames[]= { "avg", "cum", "dif", "max", "min", "mnx", "mxx",
-		       "pcen", "psum", "ptp", "rms", "sum", "uncp", "zcen" };
+                       "pcen", "psum", "ptp", "rms", "sum", "uncp", "zcen" };
 
 static RangeFunc *RFs[]= { &RFavg,&RFcum,&RFdif,&RFmax,&RFmin,&RFmnx,&RFmxx,
-	              &RFpcen,&RFpsum,&RFptp,&RFrms,&RFsum,&RFuncp,&RFzcen };
+                      &RFpcen,&RFpsum,&RFptp,&RFrms,&RFsum,&RFuncp,&RFzcen };
 
 CodeBlock YpPushRF(int which)
 {
@@ -606,10 +606,10 @@ CodeBlock YpRangeFunc(int which, CodeBlock range)
     } else {
       int flag;
       if (which==14) {
-	flag= R_MARKED;
-	PushMarkStack(1);
+        flag= R_MARKED;
+        PushMarkStack(1);
       } else {
-	flag= R_PSEUDO;
+        flag= R_PSEUDO;
       }
       vmCode[nextPC++].Action= previousOp= &FormRangeFlag;
       vmCode[nextPC++].count= flag;
@@ -624,10 +624,10 @@ CodeBlock YpRangeFunc(int which, CodeBlock range)
     } else {
       int flag;
       if (which==14) {
-	flag= R_MARKED;
-	PushMarkStack(0);
+        flag= R_MARKED;
+        PushMarkStack(0);
       } else {
-	flag= R_PSEUDO;
+        flag= R_PSEUDO;
       }
       vmCode[nextPC++].Action= previousOp= &AddRangeFlag;
       vmCode[nextPC++].count= flag;
@@ -645,7 +645,7 @@ void YpEvalInit(CodeBlock obj)
   if (nMatrixMarkers) {
     int oops= 0;
     while (nMatrixMarkers &&
-	   matrixMarkers[nMatrixMarkers-1].stackDepth>=stackDepth) {
+           matrixMarkers[nMatrixMarkers-1].stackDepth>=stackDepth) {
       nMatrixMarkers--;
       oops= 1;
     }
@@ -674,14 +674,14 @@ CodeBlock YpEval(CodeBlock obj, int nArgs)
       int oops= (markDepth==objDepth);
       nMatrixMarkers--;
       if (matrixMarkers[nMatrixMarkers].evalled)
-	YpError("misuse of matrix multiply index marker (+)");
+        YpError("misuse of matrix multiply index marker (+)");
       while (nMatrixMarkers &&
-	     matrixMarkers[nMatrixMarkers-1].stackDepth>=objDepth) {
-	nMatrixMarkers--;
-	oops= 1;
+             matrixMarkers[nMatrixMarkers-1].stackDepth>=objDepth) {
+        nMatrixMarkers--;
+        oops= 1;
       }
       if (oops)
-	YpError("only one index may be marked (+) for matrix multiply");
+        YpError("only one index may be marked (+) for matrix multiply");
       matrixMarkers[nMatrixMarkers].stackDepth= objDepth+1;
       matrixMarkers[nMatrixMarkers++].evalled= 1;
       vmCode[nextPC-2].Action= previousOp= &Eval2;
@@ -763,7 +763,7 @@ CodeBlock YpPostfix(CBorLit lhs, int assop)
 }
 
 static VMaction *Unaries[]= { &Deref, &Address, 0, &Negate,
-			      &Complement, &Not };
+                              &Complement, &Not };
 
 CodeBlock YpUnop(int which, CodeBlock op)
 {
@@ -780,21 +780,21 @@ CodeBlock YpUnop(int which, CodeBlock op)
       long i= vmCode[nextPC-1].index;
       if (which<2) YpError("unary * or & cannot be applied to a constant");
       else if (constantTable[i].ops==&longScalar) {
-	SymbolValue value;
-	if (which==3) value.l= -constantTable[i].value.l;
-	else if (which==4) value.l= ~constantTable[i].value.l;
-	else value.l= !constantTable[i].value.l;
-	vmCode[nextPC-1].index= ReplaceConstant(i, value);
+        SymbolValue value;
+        if (which==3) value.l= -constantTable[i].value.l;
+        else if (which==4) value.l= ~constantTable[i].value.l;
+        else value.l= !constantTable[i].value.l;
+        vmCode[nextPC-1].index= ReplaceConstant(i, value);
       } else if (constantTable[i].ops==&doubleScalar) {
-	if (which==3) {
-	  SymbolValue value;
-	  value.d= -constantTable[i].value.d;
-	  vmCode[nextPC-1].index= ReplaceConstant(i, value);
-	} else {
-	  YpError("unary ~ or ! not allowed on float or double constant");
-	}
+        if (which==3) {
+          SymbolValue value;
+          value.d= -constantTable[i].value.d;
+          vmCode[nextPC-1].index= ReplaceConstant(i, value);
+        } else {
+          YpError("unary ~ or ! not allowed on float or double constant");
+        }
       } else {
-	YpError("unary -, ~, or ! not allowed on string constant");
+        YpError("unary -, ~, or ! not allowed on string constant");
       }
     } else {
       if (CheckCodeSpace(1)) return op;
@@ -848,16 +848,16 @@ CodeBlock YpMultop(CodeBlock lop)
     long rm= --nMatrixMarkers;
     long lm= nMatrixMarkers-1;
     if (matrixMarkers[rm].stackDepth==stackDepth &&
-	matrixMarkers[rm].evalled && lm>=0 &&
-	matrixMarkers[lm].stackDepth==stackDepth-2 &&
-	matrixMarkers[lm].evalled) {
+        matrixMarkers[rm].evalled && lm>=0 &&
+        matrixMarkers[lm].stackDepth==stackDepth-2 &&
+        matrixMarkers[lm].evalled) {
       nMatrixMarkers--;
       vmCode[nextPC++].Action= previousOp= &MatrixMult;
       WillPopStack(3L);
       if (matrixMarkers[lm].evalled==2) {
-	/* restore the deferred unary - operation */
-	if (CheckCodeSpace(1)) return lop;
-	vmCode[nextPC++].Action= previousOp= &Negate;
+        /* restore the deferred unary - operation */
+        if (CheckCodeSpace(1)) return lop;
+        vmCode[nextPC++].Action= previousOp= &Negate;
       }
     } else {
       YpError("both matrix multiply operands need an index marker (+)");
@@ -1118,13 +1118,13 @@ CodeBlock YpFor(CodeBlock init, CodeBlock test, CodeBlock body)
       long nLineNums= incCode[--nextInc].index;
       long size= nYpReList>0? ((nYpReList-1)&0xffffff00)+0x100 : 0;
       if (nYpReList+nLineNums > size) {
-	size= ((nYpReList+nLineNums-1)&0xffffff00)+0x100;
-	ypReList= p_realloc(ypReList, sizeof(long)*size);
+        size= ((nYpReList+nLineNums-1)&0xffffff00)+0x100;
+        ypReList= p_realloc(ypReList, sizeof(long)*size);
       }
       nextInc-= nLineNums;
       for (i=0 ; i<nLineNums ; i+=2) {
-	ypReList[nYpReList+i]= incCode[nextInc+i].index + delta;    /* pc */
-	ypReList[nYpReList+i+1]= incCode[nextInc+i+1].index;    /* line # */
+        ypReList[nYpReList+i]= incCode[nextInc+i].index + delta;    /* pc */
+        ypReList[nYpReList+i+1]= incCode[nextInc+i+1].index;    /* line # */
       }
       nYpReList+= nLineNums;
     }
@@ -1183,9 +1183,9 @@ CodeBlock YpReturn(CodeBlock value)
   if (CheckCodeSpace(1)) return value;
   vmCode[nextPC++].Action= previousOp= &Return;
   WillPopStack(1L);  /* Of course, the true effect on the VM stack is
-			complicated, but as far as the following
-			instruction is concerned, the stack is one shorter.
-			It is an error if stackDepth!=0 after this.  */
+                        complicated, but as far as the following
+                        instruction is concerned, the stack is one shorter.
+                        It is an error if stackDepth!=0 after this.  */
   return value;
 }
 
@@ -1362,14 +1362,14 @@ void YpStruct(CodeBlock name, int eol)
     /* guaranteed that name points to a PushVariable instruction --
        change to OpenStruct */
     vmCode[name].Action= &OpenStruct;  /* this leaves reference on stack
-					  for DeclareMember, cleaned off
-					  by CloseStruct... */
+                                          for DeclareMember, cleaned off
+                                          by CloseStruct... */
   }
 
   YpFunc(2, eol);  /* name of struct will temporarily be name of function
-		      which builds the StructDef -- this can automatically
-		      prevent self-reference, since until the CloseStruct,
-		      the name of the struct will NOT be a data type... */
+                      which builds the StructDef -- this can automatically
+                      prevent self-reference, since until the CloseStruct,
+                      the name of the struct will NOT be a data type... */
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1487,19 +1487,19 @@ void YpFunc(int isMain, int eol)
   if (isMain) {
     for (i=0 ; i<literalTable.nItems ; i++)
       if (literalTypes[i]&L_REFERENCE)
-	literalTypes[i]= Globalize(literalTable.names[i], 0L);
+        literalTypes[i]= Globalize(literalTable.names[i], 0L);
     vmCode[nextPC++].index=
       Globalize(isMain==1? "*main*" : literalTable.names[0], 0L);
   } else {
     for (i=0 ; i<literalTable.nItems ; i++) {
       /* Note that function name is first, then positional parameters,
-	 then optional *va* parameter, then keyword parameters.  */
+         then optional *va* parameter, then keyword parameters.  */
       if (literalTypes[i]&L_REFERENCE) {
-	if (literalTypes[i]&L_LOCAL)
-	  vmCode[nextPC++].index=
-	    literalTypes[i]= Globalize(literalTable.names[i], 0L);
-	else
-	  literalTypes[i]= Globalize(literalTable.names[i], 0L);
+        if (literalTypes[i]&L_LOCAL)
+          vmCode[nextPC++].index=
+            literalTypes[i]= Globalize(literalTable.names[i], 0L);
+        else
+          literalTypes[i]= Globalize(literalTable.names[i], 0L);
       }
     }
   }
@@ -1518,11 +1518,11 @@ void YpFunc(int isMain, int eol)
 
   if (!reparsing)
     parsedFunc= NewFunction(constantTable, nConstants, nPos, nKey, nLocal,
-			    hasPosList, maxStackDepth, vmCode, codeSize);
+                            hasPosList, maxStackDepth, vmCode, codeSize);
   else
     ypReMatch=
       YpReCompare(reparsing, constantTable, nConstants, nPos, nKey, nLocal,
-		  hasPosList, maxStackDepth, vmCode, codeSize);
+                  hasPosList, maxStackDepth, vmCode, codeSize);
   nConstants= maxConstants= 0;
   constantTable= 0;
 
@@ -1537,7 +1537,7 @@ void YpFunc(int isMain, int eol)
   /* A main function must be pushed onto the stack here;
      anything else (func or struct definitions) is recorded in
      the sourceList for the current include file (see also YpExtern).  */
-  if (isMain) ym_queue(parsedFunc);
+  if (isMain) PushTask(parsedFunc);
   else RecordSource(i);
 }
 
