@@ -67,12 +67,12 @@ extern Instruction *AbortReturn(void);
 extern long ypBeginLine;
 
 extern TextStream *NewTextStream(char *fullname,
-				 void *stream, int permissions,
-				 long line, long pos);
+                                 void *stream, int permissions,
+                                 long line, long pos);
 
 typedef struct DebugBlk DebugBlk;
 extern DebugBlk *NewDebugBlk(Function *f, long pcerr, char *errFile,
-			     long lnum);
+                             long lnum);
 
 /* stuff to implement catch */
 extern BuiltIn Y_catch;
@@ -105,6 +105,7 @@ Function *y_idler_function= 0;
 Instruction *pc= 0;
 
 static int ym_state= 0;
+static int ym_fatal = 0;
 extern int ym_dbenter;
 int ym_dbenter = 0;
 #define Y_QUITTING 1
@@ -199,72 +200,30 @@ ym_resume(Instruction *ipc)
 static Function **tasks= 0;
 static int nTasks= 0;
 static int maxTasks= 0;
-static int ym_immediate_mode = 0;
-
-static Function **ym_q = 0;
-static int ym_q_n = 0, ym_q_mx = 0, ym_q_i = 0;
 
 void ClearTasks(void)
 {
-  int i;
-  ym_immediate_mode = 0;
   while (nTasks) { nTasks--;  Unref(tasks[nTasks]); }
   if (maxTasks>16) {
     maxTasks= 0;
     p_free(tasks);
     tasks= 0;
   }
-  while (ym_q_n) {
-    ym_q_n--;
-    i = ym_q_i++;
-    if (ym_q_i >= ym_q_mx) ym_q_i = 0;
-    Unref(ym_q[i]);
-  }
-  if (ym_q_mx > 16) {
-    ym_q_mx = ym_q_i = 0;
-    p_free(ym_q);
-    ym_q = 0;
-  }
-}
-
-static void PushTask(Function *task);
-static void PushTask(Function *task)
-{
-  if (p_signalling) p_abort();
-  if (nTasks>=maxTasks) {
-    int newSize= maxTasks+16;
-    tasks= p_realloc(tasks, sizeof(Function *)*newSize);
-    maxTasks= newSize;
-  }
-  tasks[nTasks++]= Ref(task);  /* WARNING-- this is the reference for when
-				  DoTask pushes the task onto the stack--
-				  you are still giving your reference to the
-				  Function* away when you call PushTask */
 }
 
 void
-ym_queue(Function *task)
+PushTask(Function *task)
 {
-  if (!ym_immediate_mode) {
-    int j;
-    if (p_signalling) p_abort();
-    j = ym_q_i + ym_q_n;
-    if (ym_q_n >= ym_q_mx) {
-      int n = ym_q_mx + 16;
-      ym_q = p_realloc(ym_q, sizeof(Function *)*n);
-      ym_q_mx = n;
-      for (n=ym_q_mx-16 ; n<j ; n++) {
-        ym_q[n] = ym_q[n-ym_q_mx];
-        ym_q[n-ym_q_mx] = 0;
-      }
-      for ( ; n<ym_q_mx ; n++) ym_q[n] = 0;
-    }
-    if (j >= ym_q_mx) j -= ym_q_mx;
-    ym_q[j] = Ref(task); /* see note for PushTask */
-    ym_q_n++;
-  } else {
-    PushTask(task);
+  if (p_signalling) p_abort();
+  if (nTasks>=maxTasks) {
+    int newSize = maxTasks+16;
+    tasks = p_realloc(tasks, sizeof(Function *)*newSize);
+    maxTasks = newSize;
   }
+  tasks[nTasks++] = Ref(task);  /* WARNING-- this is the reference for when
+                                 * DoTask pushes the task onto the stack--
+                                 * you are still giving your reference to the
+                                 * Function* away when you call PushTask */
 }
 
 /* The task pseudo-code MUST be static, since YError may p_abort out
@@ -277,17 +236,10 @@ int DoTask(void)
   extern Operations debugOps;
   if (caughtTask) {
     caughtTask= 0;
-  } else if (nTasks>0 || ym_q_n>0) {
+  } else if (nTasks>0) {
     Function *task;
     if (p_signalling) p_abort();
-    if (nTasks > 0) {
-      task = tasks[--nTasks];
-    } else {
-      task = ym_q[ym_q_i];
-      ym_q[ym_q_i] = 0;
-      ym_q_n--;
-      if (++ym_q_i >= ym_q_mx) ym_q_i -= ym_q_mx;
-    }
+    task = tasks[--nTasks];
 
     CheckStack(1);
     (sp+1)->ops= &dataBlockSym;
@@ -304,7 +256,7 @@ int DoTask(void)
     /* actually, something is terribly wrong if this is not *main* */
     Drop(1);
   }
-  return nTasks+ym_q_n;
+  return nTasks;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -326,30 +278,42 @@ static int y_was_idle= 0;
 
 static void ym_prompter(void);
 extern char *y_read_prompt;     /* ascio.c */
-/*extern int yg_blocking;*/         /* graph.c */
+extern int yg_blocking;         /* graph.c */
+/* yp_did_prompt reset by y_on_stdin */
+extern int yp_did_prompt;
+int yp_did_prompt= 0;
 
 static void
 ym_prompter(void)
 {
-  extern void y_do_prompt(void);  /* yorick.c */
-  if (y_read_prompt) {
-    if (y_read_prompt[0]) p_stdout(y_read_prompt);
-  } else {
-    y_do_prompt();
+  if (!yp_did_prompt) {
+    if (y_read_prompt) {
+      if (y_read_prompt[0]) {
+        p_stdout(y_read_prompt);
+        yp_did_prompt = 1;
+      }
+    } else {
+      extern void y_do_prompt(void);  /* yorick.c */
+      if (!yg_blocking) {
+        y_do_prompt();
+        yp_did_prompt = 1;
+      }
+    }
   }
 }
 
 int
 y_on_idle(void)
 {
-  int more_work= 0;
+  int more_work = 0;
+  int pending_stdin = 0;
 
   if (!taskCodeInit) {
-    taskCode[0].Action= &Eval;
-    taskCode[1].count= 0;
-    taskCode[2].Action= &YHalt;
-    taskCode[3].index= 0;
-    taskCodeInit= 1;
+    taskCode[0].Action = &Eval;
+    taskCode[1].count = 0;
+    taskCode[2].Action = &YHalt;
+    taskCode[3].index = 0;
+    taskCodeInit = 1;
   }
 
   if (ym_state & Y_QUITTING) {
@@ -358,22 +322,26 @@ y_on_idle(void)
     p_quit();
     return 0;
   }
-  if (!(nTasks+ym_q_n+caughtTask)) {
+  if (!(nTasks+caughtTask)) {
+    extern int y_pending_stdin(void);  /* yinput.c */
     if (nYpIncludes || nYpInputs) {
-      ym_immediate_mode = 0;
       YpParse((void *)0);
-    } else if (y_idler_function) {
-      Function *f= y_idler_function;
-      y_idler_function= 0;
-      PushTask(f);
-      Unref(f);
+    } else {
+      pending_stdin = y_pending_stdin();
+      if (!(nTasks+caughtTask || nYpIncludes || nYpInputs) &&
+          y_idler_function) {
+        Function *f = y_idler_function;
+        y_idler_function = 0;
+        PushTask(f);
+        Unref(f);
+      }
     }
   }
 
-  if (nTasks+ym_q_n+caughtTask) DoTask();
+  if (nTasks+caughtTask) DoTask();
   if (ym_state & Y_QUITTING) goto die_now;
-  more_work= (nTasks+ym_q_n+caughtTask || nYpIncludes || nYpInputs ||
-              y_idler_function);
+  more_work = (nTasks+caughtTask || nYpIncludes || nYpInputs ||
+               pending_stdin || y_idler_function);
 
   /* non-0 return means we want to run again
    * -- need to prompt if nothing left to do, but want to check
@@ -382,7 +350,7 @@ y_on_idle(void)
    * but prompt and return 0 second consecutive time we are out */
   if (more_work)
     {
-      y_was_idle= 0;
+      y_was_idle = 0;
 
       /* probably incorrect -- any tasks created before the suspend
        * but not yet run will be blocked
@@ -401,7 +369,7 @@ y_on_idle(void)
     y_was_idle=0, ym_prompter();
   else
     y_was_idle = more_work = !yBatchMode;
-  if (!(nTasks+ym_q_n+caughtTask)) {
+  if (!(nTasks+caughtTask)) {
     extern void yg_before_wait(void);
     yg_before_wait();
   }
@@ -415,14 +383,17 @@ void Y_quit(int nArgs)
   YHalt();
 }
 
+static int did_cleanup = 0;
+
 int
 y_on_quit(void)
 {
-  return 0;
+  if (!did_cleanup) y_cleanup();
+  return ym_fatal;
 }
 
-static volatile int detectRecursion= 0;
-static IOStream *yclean_file= 0;
+static volatile int detectRecursion = 0;
+static IOStream *yclean_file = 0;
 
 void
 y_cleanup(void)
@@ -447,6 +418,7 @@ y_cleanup(void)
   }
 
   if (CleanUpForExit) CleanUpForExit();
+  did_cleanup = 1;
 }
 
 void RunTaskNow(Function *task)
@@ -456,9 +428,7 @@ void RunTaskNow(Function *task)
   if (ym_state & Y_SUSPENDED)
     YError("RunTaskNow called while suspended waiting for event");
   PushTask(Ref(task));
-  ym_immediate_mode = 1;
   while (nTasks>t0 && !(ym_state&(Y_QUITTING|Y_SUSPENDED))) DoTask();
-  ym_immediate_mode = 0;
   if (ym_state & Y_SUSPENDED)
     YError("(read, pause, wait=1, etc.) suspended during RunTaskNow");
   pc = pcHere;           /* may have been clobbered by DoTask */
@@ -472,15 +442,13 @@ void IncludeNow(void)
   int t0= nTasks;
   if (ym_state & Y_SUSPENDED)
     YError("IncludeNow called while suspended waiting for event");
-  ym_immediate_mode = 1;
   for (;;) {
     while (nTasks<=t0 && (nYpIncludes>i0 || (nYpIncludes==i0 &&
-	   ypIncludes[i0-1].file))) YpParse((void *)0);
+           ypIncludes[i0-1].file))) YpParse((void *)0);
     while (nTasks>t0 && !(ym_state&(Y_QUITTING|Y_SUSPENDED))) DoTask();
-    if ((ym_state&Y_QUITTING) || nYpIncludes<i0 ||
+    if ((ym_state&(Y_QUITTING|Y_SUSPENDED)) || nYpIncludes<i0 ||
         !ypIncludes[i0-1].file) break;
   }
-  ym_immediate_mode = 0;
   if (ym_state & Y_SUSPENDED)
     YError("(read, pause, wait=1, etc.) suspended during IncludeNow");
   pc= pcHere;           /* may have been clobbered by DoTask */
@@ -496,14 +464,16 @@ void Y_include(int nArgs)
   if (nArgs>1) now= YGetInteger(sp);
   else now= 0;
   name= YGetString(sp-nArgs+1);
-  if (now>=0 && !YpPushInclude(name))
-    YError("missing include file specified in include function");
-  else if (now<0)
-    YpPush(name);          /* defer until all pending input parsed */
+  if (name[0]) {  /* name=="" special hack cleans out pending includes */
+    if (now>=0 && !YpPushInclude(name))
+      YError("missing include file specified in include function");
+    else if (now<0)
+      YpPush(name);          /* defer until all pending input parsed */
+  }
   Drop(nArgs);
   if (now>0) IncludeNow(); /* parse and maybe execute file to be included
-			      -- without now, this won't happen until the
-			      next line is parsed naturally */
+                              -- without now, this won't happen until the
+                              next line is parsed naturally */
 }
 
 void Y_require(int nArgs)
@@ -656,6 +626,7 @@ YError(const char *msg)
   if (recursing>8 || yImpossible>8) {
     YputsErr("****FATAL**** YError looping -- quitting now");
     ym_state|= Y_QUITTING;
+    ym_fatal = 3;
     if (!no_abort) p_abort();
     return;
   }
@@ -701,14 +672,14 @@ YError(const char *msg)
   if (recursing<3) {
     p_qclear();
     ClearTasks();
-  } else if (nTasks+ym_q_n) {
+  } else if (nTasks) {
     YputsErr("WARNING unable to free task pointers in YError");
-    nTasks = ym_q_n = 0;
+    nTasks = 0;
   }
 
   /* Print error message, with name of current Yorick function prepended:
         ERROR (yorick_function) msg passed to YError
-	ERROR (VM idle or lost) msg passed to YError
+        ERROR (VM idle or lost) msg passed to YError
      The second form is used when the virtual machine is idle at the
      time of the error.  */
   if (!pcUp || recursing)
@@ -740,20 +711,20 @@ YError(const char *msg)
       name= includeFile;
     } else {
       char *mess= YpReparse(func);
-      if (nTasks+ym_q_n) ClearTasks();
+      if (nTasks) ClearTasks();
       if (mess[0]!='*') {
-	/* reparse succeeded, skip to filename */
-	name= 0;
-	while (mess[0] && mess[0]!=':') mess++;
-	if (mess[0]) do { mess++; } while (mess[0] && mess[0]!=':');
-	if (mess[0]) {
-	  mess++;
-	  if (mess[0]==' ') mess++;
-	  if (mess[0]) name= mess;
-	}
+        /* reparse succeeded, skip to filename */
+        name= 0;
+        while (mess[0] && mess[0]!=':') mess++;
+        if (mess[0]) do { mess++; } while (mess[0] && mess[0]!=':');
+        if (mess[0]) {
+          mess++;
+          if (mess[0]==' ') mess++;
+          if (mess[0]) name= mess;
+        }
       } else {
-	/* reparse failed */
-	name= 0;
+        /* reparse failed */
+        name= 0;
       }
       beginLine= 0;  /* used only for *main* from includeFile */
     }
@@ -771,10 +742,10 @@ YError(const char *msg)
 
     if (!yBatchMode && !pcUp && (!yAutoDebug || yDebugLevel>1)) {
       if (yDebugLevel>1) {
-	YputsErr(" To enter recursive debug level, type <RETURN> now");
+        YputsErr(" To enter recursive debug level, type <RETURN> now");
       } else {
-	YputsErr(" To enter debug mode, type <RETURN> now"
-		 " (then dbexit to get out)");
+        YputsErr(" To enter debug mode, type <RETURN> now"
+                 " (then dbexit to get out)");
       }
       ym_dbenter = 1;
     }
@@ -786,7 +757,7 @@ YError(const char *msg)
     if (recursing<5) ResetStack(y_read_prompt!=0);
     else {
       YputsErr("****SEVERE**** YError unable to reset stack -- "
-	       "probably lost variables");
+               "probably lost variables");
       sp= spBottom;
     }
     ym_state &= ~Y_SUSPENDED;
@@ -804,6 +775,7 @@ YError(const char *msg)
   if (yBatchMode || !strncmp(msg,"(FATAL)",7)) {
     if (yBatchMode) YputsErr("yorick: quitting on error in batch mode");
     else YputsErr("yorick: quitting on fatal error");
+    ym_fatal = yBatchMode? 1 : 2;
     ResetStack(0);
     ym_state|= Y_QUITTING;
   }
@@ -840,15 +812,15 @@ void Y_help(int nArgs)
       DataBlock *db= stack->value.db;
       Operations *ops= db->ops;
       if (ops==&functionOps) {
-	Function *f= (Function *)db;
-	index= f->code[0].index;
+        Function *f= (Function *)db;
+        index= f->code[0].index;
       } else if (ops==&structDefOps) {
-	StructDef *base= (StructDef *)db;
-	while (base->model) base= base->model;
-	index= Globalize(yStructTable.names[base->index], 0L);
+        StructDef *base= (StructDef *)db;
+        while (base->model) base= base->model;
+        index= Globalize(yStructTable.names[base->index], 0L);
       } else if (ops==&builtinOps) {
-	BIFunction *f= (BIFunction *)db;
-	index= f->index;
+        BIFunction *f= (BIFunction *)db;
+        index= f->index;
       }
     }
     Drop(nAbove);
@@ -857,7 +829,7 @@ void Y_help(int nArgs)
     /* no legal arguments, help function itself is target */
     BIFunction *f= (BIFunction *)(sp-nArgs)->value.db;
     index= f->index;
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
   }
 
   /* move help topic argument off stack into help_topic extern variable */
@@ -867,17 +839,17 @@ void Y_help(int nArgs)
   if (!help_worker) {
     long help_index= Globalize("help_worker", 0L);
     if (globTab[help_index].ops!=&dataBlockSym ||
-	(help_worker= (Function *)Ref(globTab[help_index].value.db))->ops
-	!=&functionOps)
+        (help_worker= (Function *)Ref(globTab[help_index].value.db))->ops
+        !=&functionOps)
       YError("(BUG) help_worker function not found -- help unavailable");
   }
 
   /* create help_file extern variable */
   if (index>=0 && (file= OpenSource(index)))
     PushDataBlock(NewTextStream(p_strcpy(ypIncludes[nYpIncludes-1].filename),
-				file, 1, ypBeginLine-1, p_ftell(file)));
+                                file, 1, ypBeginLine-1, p_ftell(file)));
   else
-    PushDataBlock(Ref(&nilDB));
+    PushDataBlock(RefNC(&nilDB));
   worker_arg= Globalize("help_file", 0L);
   PopTo(&globTab[worker_arg]);  /* help_file */
 
